@@ -40,8 +40,8 @@ $messages['qqq'] = array(
 See also:
 * {{msg-mw|Inputbox-error-bad-type}}',
 	'inputbox-error-bad-type' => '{{doc-important|"create", "comment", "search", "search2" and "fulltext" should not be translated.}}
-Used as error message.
-
+Used as error message. Parameters:
+* $1 - invalid type. Valid types are: "create", "comment", "commenttitle", "search", "fulltext", and "search2"
 See also:
 * {{msg-mw|Inputbox-error-no-type}}',
 	'tryexact' => 'Part of the "Inputbox" extension. This message is the text of the button to search the page you typed in the inputbox. If the page with the exact name exists, you will go directly to that page.',
@@ -51,8 +51,10 @@ See also:
 * {{msg-mw|Search}}
 * {{msg-mw|Accesskey-search-fulltext}}
 * {{msg-mw|Tooltip-search-fulltext}}',
-	'createarticle' => 'Part of the "Inputbox" extension. This message is the text of the button to create the page you typed in the inputbox.',
-	'inputbox-ns-main' => 'Probably refers to the main namespace.',
+	'createarticle' => 'Part of the "Inputbox" extension. This message is the text of the button to create the page you typed in the inputbox.
+{{Identical|Create page}}',
+	'inputbox-ns-main' => 'Probably refers to the main namespace.
+{{Identical|Main}}',
 );
 
 /** Afrikaans (Afrikaans)
@@ -127,7 +129,7 @@ $messages['arz'] = array(
 	'createarticle' => 'إنشاء صفحة',
 );
 
-/** Assamese (অসমীয়া)
+/** Assamese (অসমীয়া)
  * @author Bishnu Saikia
  * @author Chaipau
  * @author Gitartha.bordoloi
@@ -206,6 +208,21 @@ $messages['bcc'] = array(
 	'createarticle' => 'شرکتن صفحه',
 );
 
+/** Bikol Central (Bikol Central)
+ * @author Filipinayzd
+ * @author Geopoet
+ */
+$messages['bcl'] = array(
+	'inputbox-desc' => 'Minatugot na balihon an pangenot na pakahulugan kan mga porma nin HTML',
+	'inputbox-error-no-type' => 'Ika dae nagsasambit kan tipo nin palaogang kahon tanganing maimukna.',
+	'inputbox-error-bad-type' => 'An tipo kan palaogang kahon na "$1" bakong rekonosido.
+Pakisambit tabi an "magmukna", "komento", "hanapa" "hanapa2" o an "kabilogang teksto".',
+	'tryexact' => 'Prubaran an eksaktong katampadan',
+	'searchfulltext' => 'Hanapa an kabilogang teksto',
+	'createarticle' => 'Muknaon an pahina',
+	'inputbox-ns-main' => 'Kapamayuhanan',
+);
+
 /** Belarusian (беларуская)
  */
 $messages['be'] = array(
@@ -327,16 +344,20 @@ Especifiqueu-hi «create», «comment», «search», «search2» o «fulltext».
 );
 
 /** Min Dong Chinese (Mìng-dĕ̤ng-ngṳ̄)
+ * @author Yejianfei
  */
 $messages['cdo'] = array(
-	'createarticle' => 'Kŭi hiĕk',
+	'createarticle' => '開頁',
 );
 
 /** Chechen (нохчийн)
  * @author Sasan700
+ * @author Умар
  */
 $messages['ce'] = array(
 	'tryexact' => 'Леррина лахар',
+	'searchfulltext' => 'Дуьззина йозанца лахар',
+	'createarticle' => 'Яззам кхоллар',
 );
 
 /** Sorani Kurdish (کوردی)
@@ -658,8 +679,8 @@ $messages['frr'] = array(
 	'inputbox-desc' => 'Föörformatiaret HTML-fialen tuläät',
 	'inputbox-error-no-type' => 'Dü heest ei uunden, hün slach faan fial iinracht wurd skal.',
 	'inputbox-error-bad-type' => 'Di slach „$1“ as ei tuläät. Wees so gud an nem „create“, „comment“, „search“, „search2“ of „fulltext“.',
-	'tryexact' => 'Sjük genau',
-	'searchfulltext' => 'Sjük uun di hialer tekst',
+	'tryexact' => 'Schük genau',
+	'searchfulltext' => 'Schük uun di hialer tekst',
 	'createarticle' => 'Maage en nei sidj',
 	'inputbox-ns-main' => 'Sidjen',
 );
@@ -759,7 +780,7 @@ $messages['gv'] = array(
 	'createarticle' => 'Croo duillag',
 );
 
-/** Hakka (Hak-kâ-fa)
+/** Hakka (客家語/Hak-kâ-ngî)
  * @author Hakka
  */
 $messages['hak'] = array(
@@ -1095,14 +1116,15 @@ $messages['km'] = array(
  * @author Klutzy
  * @author Kwj2772
  * @author ToePeu
+ * @author 아라
  */
 $messages['ko'] = array(
-	'inputbox-desc' => '사전 정의된 HTML 폼을 포함할 수 있게 해 줌',
-	'inputbox-error-no-type' => 'type 속성을 정하지 않았습니다.',
-	'inputbox-error-bad-type' => '"$1"은(는) 사용할 수 없는 type 속성입니다.
-"create", "comment", "search", "search2", "fulltext" 중 하나를 사용하세요.',
-	'tryexact' => '정확한 이름으로 찾기',
-	'searchfulltext' => '전체 글 검색',
+	'inputbox-desc' => '사전 정의된 HTML 양식을 포함할 수 있습니다',
+	'inputbox-error-no-type' => '만드려는 입력 상자의 종류를 지정하지 않았습니다.',
+	'inputbox-error-bad-type' => '"$1" 입력 상자 종류는 정의되어 있지 않습니다.
+"create", "comment", "search", "search2"나 "fulltext" 중 하나를 지정하세요.',
+	'tryexact' => '일치하는 항목 찾기',
+	'searchfulltext' => '전체 글 찾기',
 	'createarticle' => '문서 만들기',
 	'inputbox-ns-main' => '문서',
 );
@@ -1208,6 +1230,14 @@ $messages['lo'] = array(
 	'createarticle' => 'ສ້າງບົດຄວາມ',
 );
 
+/** لوری (لوری)
+ * @author Mogoeilor
+ */
+$messages['lrc'] = array(
+	'createarticle' => 'راس كردن بلگه',
+	'inputbox-ns-main' => 'اصلی',
+);
+
 /** Lithuanian (lietuvių)
  * @author Vogone
  */
@@ -1385,7 +1415,7 @@ $messages['nan'] = array(
 	'searchfulltext' => 'Chhiau choan-bûn',
 );
 
-/** Neapolitan (Nnapulitano)
+/** Neapolitan (Napulitano)
  * @author Chelin
  * @author SabineCretella
  */
@@ -1394,7 +1424,7 @@ $messages['nap'] = array(
 	'createarticle' => 'Cria paggena',
 );
 
-/** Norwegian Bokmål (norsk (bokmål)‎)
+/** Norwegian Bokmål (norsk bokmål)
  * @author EivindJ
  */
 $messages['nb'] = array(
@@ -1421,7 +1451,7 @@ Geev een vun disse Typen an: „create“, „comment“, „search“, „searc
 	'createarticle' => 'Siet anleggen',
 );
 
-/** Nedersaksies (Nedersaksies)
+/** Low Saxon (Netherlands) (Nedersaksies)
  * @author Servien
  */
 $messages['nds-nl'] = array(
@@ -1465,7 +1495,7 @@ $messages['nl-informal'] = array(
 	'inputbox-error-no-type' => 'Je hebt het type invoerveld niet opgegeven.',
 );
 
-/** Norwegian Nynorsk (norsk (nynorsk)‎)
+/** Norwegian Nynorsk (norsk nynorsk)
  * @author Frokor
  * @author Harald Khan
  * @author Njardarlogar
@@ -1508,7 +1538,7 @@ Indicatz una opcion demest ''create'', ''comment'', ''search'' o ''searche2'' o
 	'inputbox-ns-main' => 'Principal',
 );
 
-/** Oriya (ଓଡ଼ିଆ)
+/** Oriya (ଓଡ଼ିଆ)
  * @author Odisha1
  * @author Psubhashish
  */
@@ -2060,10 +2090,11 @@ $messages['ts'] = array(
 );
 
 /** Tuvinian (тыва дыл)
+ * @author Agilight
  * @author Sborsody
  */
 $messages['tyv'] = array(
-	'createarticle' => 'Арынны чаяары',
+	'createarticle' => 'Арын чаяар',
 	'inputbox-ns-main' => 'Кол',
 );
 
