@@ -102,13 +102,13 @@ $magicWords['ce'] = array(
 
 /** Czech (česky) */
 $magicWords['cs'] = array(
-	'expr' => array( 0, 'výraz', 'expr' ),
-	'if' => array( 0, 'když', 'if' ),
-	'ifexist' => array( 0, 'kdyžexist', 'ifexist' ),
-	'time' => array( 0, 'čas', 'time' ),
-	'len' => array( 0, 'délka', 'len' ),
-	'count' => array( 0, 'počet', 'count' ),
-	'replace' => array( 0, 'nahradit', 'replace' ),
+	'expr' => array( 0, 'výraz' ),
+	'if' => array( 0, 'když' ),
+	'ifexist' => array( 0, 'kdyžexist' ),
+	'time' => array( 0, 'čas' ),
+	'len' => array( 0, 'délka' ),
+	'count' => array( 0, 'počet' ),
+	'replace' => array( 0, 'nahradit' ),
 );
 
 /** German (Deutsch) */
@@ -120,6 +120,12 @@ $magicWords['de'] = array(
 	'urldecode' => array( 0, 'URLDEKODIERT:' ),
 );
 
+/** Zazaki (Zazaki) */
+$magicWords['diq'] = array(
+	'if' => array( 0, 'se' ),
+	'ifeq' => array( 0, 'sek' ),
+);
+
 /** Esperanto (Esperanto) */
 $magicWords['eo'] = array(
 	'expr' => array( 0, 'espr', 'esprimo' ),
@@ -174,6 +180,30 @@ $magicWords['fa'] = array(
 	'urldecode' => array( 0, 'نشانی‌بی‌کد' ),
 );
 
+/** French (français) */
+$magicWords['fr'] = array(
+	'expr' => array( 0, 'expr' ),
+	'if' => array( 0, 'si' ),
+	'ifeq' => array( 0, 'si=' ),
+	'ifexpr' => array( 0, 'siexpr' ),
+	'iferror' => array( 0, 'sierreur' ),
+	'switch' => array( 0, 'selon' ),
+	'default' => array( 0, '#défaut' ),
+	'ifexist' => array( 0, 'siexiste' ),
+	'time' => array( 0, 'heure' ),
+	'timel' => array( 0, 'heurel' ),
+	'rel2abs' => array( 0, 'relenabs' ),
+	'titleparts' => array( 0, 'partiestitre' ),
+	'len' => array( 0, 'nbcar' ),
+	'pos' => array( 0, 'pos' ),
+	'rpos' => array( 0, 'posr' ),
+	'sub' => array( 0, 'stxt' ),
+	'count' => array( 0, 'nb' ),
+	'replace' => array( 0, 'remplacer' ),
+	'explode' => array( 0, 'exploser' ),
+	'urldecode' => array( 0, 'décoderurl', 'decodeurl' ),
+);
+
 /** Hebrew (עברית) */
 $magicWords['he'] = array(
 	'expr' => array( 0, 'חשב' ),
@@ -208,17 +238,17 @@ $magicWords['hu'] = array(
 
 /** Indonesian (Bahasa Indonesia) */
 $magicWords['id'] = array(
-	'expr' => array( 0, 'hitung', 'expr' ),
-	'if' => array( 0, 'jika', 'if' ),
-	'ifeq' => array( 0, 'jikasama', 'ifeq' ),
-	'ifexpr' => array( 0, 'jikahitung', 'ifexpr' ),
-	'iferror' => array( 0, 'jikasalah', 'iferror' ),
-	'switch' => array( 0, 'pilih', 'switch' ),
-	'default' => array( 0, '#baku', '#default' ),
-	'ifexist' => array( 0, 'jikaada', 'ifexist' ),
-	'time' => array( 0, 'waktu', 'time' ),
-	'timel' => array( 0, 'waktu1', 'timel' ),
-	'titleparts' => array( 0, 'bagianjudul', 'titleparts' ),
+	'expr' => array( 0, 'hitung' ),
+	'if' => array( 0, 'jika' ),
+	'ifeq' => array( 0, 'jikasama' ),
+	'ifexpr' => array( 0, 'jikahitung' ),
+	'iferror' => array( 0, 'jikasalah' ),
+	'switch' => array( 0, 'pilih' ),
+	'default' => array( 0, '#baku' ),
+	'ifexist' => array( 0, 'jikaada' ),
+	'time' => array( 0, 'waktu' ),
+	'timel' => array( 0, 'waktu1' ),
+	'titleparts' => array( 0, 'bagianjudul' ),
 );
 
 /** Igbo (Igbo) */
@@ -343,6 +373,7 @@ $magicWords['mk'] = array(
 
 /** Malayalam (മലയാളം) */
 $magicWords['ml'] = array(
+	'expr' => array( 0, 'ദ്യോതകം' ),
 	'if' => array( 0, 'എങ്കിൽ' ),
 	'ifeq' => array( 0, 'സമെമെങ്കിൽ' ),
 	'ifexpr' => array( 0, 'എക്സ്പ്രെഷനെങ്കിൽ' ),
@@ -352,10 +383,14 @@ $magicWords['ml'] = array(
 	'ifexist' => array( 0, 'ഉണ്ടെങ്കിൽ' ),
 	'time' => array( 0, 'സമയം' ),
 	'timel' => array( 0, 'സമയം|' ),
+	'len' => array( 0, 'നീളം' ),
+	'pos' => array( 0, 'സ്ഥാനം' ),
+	'rpos' => array( 0, 'ആപേക്ഷികസ്ഥാനം' ),
 	'sub' => array( 0, 'ഉപം' ),
 	'count' => array( 0, 'എണ്ണുക' ),
 	'replace' => array( 0, 'മാറ്റിച്ചേർക്കുക' ),
 	'explode' => array( 0, 'വിസ്ഫോടനം' ),
+	'urldecode' => array( 0, 'വിലാസഗൂഢീകരണമൊഴിവാക്കൽ' ),
 );
 
 /** Marathi (मराठी) */
@@ -382,15 +417,15 @@ $magicWords['mr'] = array(
 
 /** Low Saxon (Netherlands) (Nedersaksies) */
 $magicWords['nds-nl'] = array(
-	'if' => array( 0, 'as', 'als' ),
-	'ifeq' => array( 0, 'asgelieke', 'alsgelijk' ),
-	'ifexpr' => array( 0, 'asexpressie', 'alsexpressie' ),
-	'iferror' => array( 0, 'asfout', 'alsfout' ),
-	'default' => array( 0, '#standard', '#standaard' ),
-	'ifexist' => array( 0, 'asbesteet', 'alsbestaat' ),
-	'time' => array( 0, 'tied', 'tijd' ),
-	'timel' => array( 0, 'tiedl', 'tijdl' ),
-	'rel2abs' => array( 0, 'relatiefnaorabseluut', 'relatiefnaarabsoluut' ),
+	'if' => array( 0, 'as' ),
+	'ifeq' => array( 0, 'asgelieke' ),
+	'ifexpr' => array( 0, 'asexpressie' ),
+	'iferror' => array( 0, 'asfout' ),
+	'default' => array( 0, '#standard' ),
+	'ifexist' => array( 0, 'asbesteet' ),
+	'time' => array( 0, 'tied' ),
+	'timel' => array( 0, 'tiedl' ),
+	'rel2abs' => array( 0, 'relatiefnaorabseluut' ),
 );
 
 /** Dutch (Nederlands) */
@@ -415,10 +450,10 @@ $magicWords['nl'] = array(
 
 /** Norwegian Nynorsk (norsk nynorsk) */
 $magicWords['nn'] = array(
-	'expr' => array( 0, 'uttrykk' ),
+	'expr' => array( 0, 'uttrykk', 'uttr' ),
 	'if' => array( 0, 'om' ),
 	'ifeq' => array( 0, 'omlik' ),
-	'ifexpr' => array( 0, 'omuttrykk' ),
+	'ifexpr' => array( 0, 'omuttrykk', 'omuttr' ),
 	'iferror' => array( 0, 'omfeil' ),
 	'switch' => array( 0, 'byt' ),
 	'ifexist' => array( 0, 'omfinst' ),
@@ -427,7 +462,7 @@ $magicWords['nn'] = array(
 	'rel2abs' => array( 0, 'reltilabs' ),
 	'titleparts' => array( 0, 'titteldelar' ),
 	'len' => array( 0, 'lengd' ),
-	'replace' => array( 0, 'erstatt' ),
+	'replace' => array( 0, 'byt_ut', 'erstatt' ),
 );
 
 /** Oriya (ଓଡ଼ିଆ) */
@@ -449,14 +484,14 @@ $magicWords['ps'] = array(
 
 /** Portuguese (português) */
 $magicWords['pt'] = array(
-	'if' => array( 0, 'se', 'if' ),
-	'ifeq' => array( 0, 'seigual', 'ifeq' ),
-	'ifexpr' => array( 0, 'seexpr', 'ifexpr' ),
-	'iferror' => array( 0, 'seerro', 'iferror' ),
-	'default' => array( 0, '#padrão', '#padrao', '#default' ),
-	'ifexist' => array( 0, 'seexiste', 'ifexist' ),
-	'titleparts' => array( 0, 'partesdotítulo', 'partesdotitulo', 'titleparts' ),
-	'len' => array( 0, 'comprimento', 'len' ),
+	'if' => array( 0, 'se' ),
+	'ifeq' => array( 0, 'seigual' ),
+	'ifexpr' => array( 0, 'seexpr' ),
+	'iferror' => array( 0, 'seerro' ),
+	'default' => array( 0, '#padrão', '#padrao' ),
+	'ifexist' => array( 0, 'seexiste' ),
+	'titleparts' => array( 0, 'partesdotítulo', 'partesdotitulo' ),
+	'len' => array( 0, 'comprimento' ),
 );
 
 /** Russian (русский) */
@@ -593,4 +628,11 @@ $magicWords['zh'] = array(
 	'count' => array( 0, '计数' ),
 	'replace' => array( 0, '替换' ),
 	'explode' => array( 0, '爆炸', '炸开' ),
+);
+
+/** Simplified Chinese (中文（简体）‎) */
+$magicWords['zh-hans'] = array(
+	'ifeq' => array( 0, '若相等', '如果相等' ),
+	'default' => array( 0, '#默认' ),
+	'ifexist' => array( 0, '若有', '如果存在' ),
 );
\ No newline at end of file
