@@ -78,7 +78,7 @@ $messages['arz'] = array(
 	'geshi.css' => '/* CSS المحطوطة هنا ح تتطبق على تظليل سينتاكس الGeSHi */',
 );
 
-/** Assamese (অসমীয়া)
+/** Assamese (অসমীয়া)
  * @author Bishnu Saikia
  */
 $messages['as'] = array(
@@ -199,9 +199,11 @@ $messages['ca'] = array(
 
 /** Chechen (нохчийн)
  * @author Sasan700
+ * @author Умар
  */
 $messages['ce'] = array(
-	'geshi.css' => '/* CSS-ишар, кху чу хlоттайахь, оцо болх бийра бу сизашдо беснашна хlокхуньца GeSHI */',
+	'syntaxhighlight-supported' => 'Ловш долу меттанаш:',
+	'geshi.css' => '/* CSS-код, кху чу хlоттайахь, оцо болх бийра бу сизашдо беснашна хlокхуньца GeSHI */',
 );
 
 /** Czech (česky)
@@ -218,10 +220,16 @@ $messages['cs'] = array(
 );
 
 /** Danish (dansk)
+ * @author Christian List
  * @author Sarrus
  */
 $messages['da'] = array(
+	'syntaxhighlight-desc' => 'Giver syntaksfremhævning <code>&lt;syntaxhighlight&gt;</code> ved brug af [http://qbnz.com/highlighter/ GeSHi - Generic Syntax Highlighter]',
+	'syntaxhighlight-specify' => 'Du skal angive et sprog, sådan her:',
+	'syntaxhighlight-supported' => 'Understøttede sprog for syntaksfremhævning:',
+	'syntaxhighlight-err-loading' => '(fejl ved indlæsning af listen af understøttede sprog)',
 	'syntaxhighlight-err-language' => 'Ugyldigt sprog.',
+	'geshi.css' => '/* CSS placeret her vil blive anvendt til GeSHi syntaksfremhævning */',
 );
 
 /** German (Deutsch)
@@ -314,7 +322,7 @@ $messages['et'] = array(
 	'syntaxhighlight-specify' => 'Sa pead täpsustama keelt nõnda:',
 	'syntaxhighlight-supported' => 'Süntaksi esiletoomise on toetatud järgnevates keeltes:',
 	'syntaxhighlight-err-loading' => '(toetatud keelte loetelu laadimisel esines viga)',
-	'syntaxhighlight-err-language' => 'antud keel on mittekehtiv',
+	'syntaxhighlight-err-language' => 'Vigane keel.',
 	'geshi.css' => '/* CSS mis on asetatud siia, määrab GeSHi süntaksi esiletoomise stiili */',
 );
 
@@ -335,7 +343,7 @@ $messages['fa'] = array(
 	'syntaxhighlight-specify' => 'شما باید به این شکل زبانی را مشخص کنید:',
 	'syntaxhighlight-supported' => 'زبان‌های پشتیبانی‌شده برای رنگین‌کردن دستورات:',
 	'syntaxhighlight-err-loading' => '(خطا در بارگذاری فهرست زبان‌های پشتیبانی‌شده)',
-	'syntaxhighlight-err-language' => 'زبان غیرمجاز.',
+	'syntaxhighlight-err-language' => 'زبان نامجاز.',
 	'geshi.css' => '/* دستورات CSS اینجا توسط سامانه رنگین‌کردن دستورات GeSHi به کار گرفته می‌شوند */',
 );
 
@@ -657,10 +665,10 @@ $messages['km'] = array(
  * @author 아라
  */
 $messages['ko'] = array(
-	'syntaxhighlight-desc' => '<code>&lt;syntaxhighlight&gt;</code> 태그로 [http://qbnz.com/highlighter/ GeSHi Highlighter]를 이용해 문법 강조 기능을 지원합니다.',
-	'syntaxhighlight-specify' => '오른쪽과 같이 언어를 설정해야 합니다:',
-	'syntaxhighlight-supported' => '문법 강조가 지원되는 언어 목록',
-	'syntaxhighlight-err-loading' => '(지원하는 언어 목록을 불러오는 중 오류 발생)',
+	'syntaxhighlight-desc' => '[http://qbnz.com/highlighter/ GeSHi Highlighter]를 사용해 <code>&lt;syntaxhighlight&gt;</code>로 문법 강조를 제공합니다',
+	'syntaxhighlight-specify' => '다음과 같이 언어를 지정해야 합니다:',
+	'syntaxhighlight-supported' => '문법 강조가 지원되는 언어 목록:',
+	'syntaxhighlight-err-loading' => '(지원되는 언어 목록을 불러오는 중 오류)',
 	'syntaxhighlight-err-language' => '잘못된 언어입니다.',
 	'geshi.css' => '/* 이 문서에서 설정한 CSS는 GeSHi에 적용됩니다. */',
 );
@@ -790,7 +798,7 @@ $messages['nah'] = array(
 	'syntaxhighlight-err-language' => 'Âmò kualli tlâtòlli',
 );
 
-/** Norwegian Bokmål (norsk (bokmål)‎)
+/** Norwegian Bokmål (norsk bokmål)
  */
 $messages['nb'] = array(
 	'syntaxhighlight-desc' => 'Gir syntaks som framhever <code>&lt;syntaxhighlight&gt;</code> ved hjelp av [http://qbnz.com/highlighter/ GeSHi Highlighter]',
@@ -813,7 +821,7 @@ $messages['nds'] = array(
 	'geshi.css' => '/* CSS in disse MediaWiki-Systemnaricht warrt för dat GeSHi-Syntaxrutheven bruukt */',
 );
 
-/** Nedersaksies (Nedersaksies)
+/** Low Saxon (Netherlands) (Nedersaksies)
  * @author Servien
  */
 $messages['nds-nl'] = array(
@@ -833,7 +841,7 @@ $messages['nl'] = array(
 	'geshi.css' => '/* Hier geplaatste CSS wordt toegepast op GeSHi Syntax Highlighting */',
 );
 
-/** Norwegian Nynorsk (norsk (nynorsk)‎)
+/** Norwegian Nynorsk (norsk nynorsk)
  * @author Frokor
  */
 $messages['nn'] = array(
@@ -909,7 +917,7 @@ $messages['pms'] = array(
  * @author Ahmed-Najib-Biabani-Ibrahimkhel
  */
 $messages['ps'] = array(
-	'syntaxhighlight-specify' => 'بايد تاسې يوه ژبه په دې توګه ځانګړې کړی:',
+	'syntaxhighlight-specify' => 'بايد تاسې يوه ژبه په دې توگه ځانگړې کړۍ:',
 	'syntaxhighlight-err-language' => 'ناسمه ژبه.',
 );
 
