@@ -1,6 +1,21 @@
 <?php
 /**
- * Native CDB file reader and writer
+ * Native CDB file reader and writer.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * http://www.gnu.org/copyleft/gpl.html
  *
  * @file
  */
@@ -13,6 +28,10 @@
 abstract class CdbReader {
 	/**
 	 * Open a file and return a subclass instance
+	 *
+	 * @param $fileName string
+	 *
+	 * @return CdbReader
 	 */
 	public static function open( $fileName ) {
 		if ( self::haveExtension() ) {
@@ -25,6 +44,8 @@ abstract class CdbReader {
 
 	/**
 	 * Returns true if the native extension is available
+	 *
+	 * @return bool
 	 */
 	public static function haveExtension() {
 		if ( !function_exists( 'dba_handlers' ) ) {
@@ -49,6 +70,8 @@ abstract class CdbReader {
 
 	/**
 	 * Get a value with a given key. Only string values are supported.
+	 *
+	 * @param $key string
 	 */
 	abstract public function get( $key );
 }
@@ -61,6 +84,10 @@ abstract class CdbWriter {
 	/**
 	 * Open a writer and return a subclass instance.
 	 * The user must have write access to the directory, for temporary file creation.
+	 *
+	 * @param $fileName string
+	 *
+	 * @return CdbWriter_DBA|CdbWriter_PHP
 	 */
 	public static function open( $fileName ) {
 		if ( CdbReader::haveExtension() ) {
@@ -73,11 +100,15 @@ abstract class CdbWriter {
 
 	/**
 	 * Create the object and open the file
+	 *
+	 * @param $fileName string
 	 */
 	abstract function __construct( $fileName );
 
 	/**
 	 * Set a key to a given value. The value will be converted to string.
+	 * @param $key string
+	 * @param $value string
 	 */
 	abstract public function set( $key, $value );
 
@@ -88,7 +119,6 @@ abstract class CdbWriter {
 	abstract public function close();
 }
 
-
 /**
  * Reader class which uses the DBA extension
  */
@@ -103,8 +133,9 @@ class CdbReader_DBA {
 	}
 
 	function close() {
-		if( isset($this->handle) )
+		if ( isset( $this->handle ) ) {
 			dba_close( $this->handle );
+		}
 		unset( $this->handle );
 	}
 
@@ -113,7 +144,6 @@ class CdbReader_DBA {
 	}
 }
 
-
 /**
  * Writer class which uses the DBA extension
  */
@@ -134,8 +164,9 @@ class CdbWriter_DBA {
 	}
 
 	function close() {
-		if( isset($this->handle) )
+		if ( isset( $this->handle ) ) {
 			dba_close( $this->handle );
+		}
 		if ( wfIsWindows() ) {
 			unlink( $this->realFileName );
 		}
@@ -151,4 +182,3 @@ class CdbWriter_DBA {
 		}
 	}
 }
-
