@@ -84,43 +84,3 @@ function wfIsConfiguredProxy( $ip ) {
 		in_array( $ip, $wgSquidServersNoPurge );
 	return $trusted;
 }
-
-/**
- * Forks processes to scan the originating IP for an open proxy server
- * MemCached can be used to skip IPs that have already been scanned
- */
-function wfProxyCheck() {
-	global $wgBlockOpenProxies, $wgProxyPorts, $wgProxyScriptPath;
-	global $wgMemc, $wgProxyMemcExpiry, $wgRequest;
-	global $wgProxyKey;
-
-	if ( !$wgBlockOpenProxies ) {
-		return;
-	}
-
-	$ip = $wgRequest->getIP();
-
-	# Get MemCached key
-	$mcKey = wfMemcKey( 'proxy', 'ip', $ip );
-	$mcValue = $wgMemc->get( $mcKey );
-	$skip = (bool)$mcValue;
-
-	# Fork the processes
-	if ( !$skip ) {
-		$title = SpecialPage::getTitleFor( 'Blockme' );
-		$iphash = md5( $ip . $wgProxyKey );
-		$url = wfExpandUrl( $title->getFullURL( 'ip=' . $iphash ), PROTO_HTTP );
-
-		foreach ( $wgProxyPorts as $port ) {
-			$params = implode( ' ', array(
-						escapeshellarg( $wgProxyScriptPath ),
-						escapeshellarg( $ip ),
-						escapeshellarg( $port ),
-						escapeshellarg( $url )
-						));
-			exec( "php $params >" . wfGetNull() . " 2>&1 &" );
-		}
-		# Set MemCached key
-		$wgMemc->set( $mcKey, 1, $wgProxyMemcExpiry );
-	}
-}
