@@ -1,11 +1,31 @@
 <?php
+/**
+ * Accessors and mutators for the site-wide statistics.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * http://www.gnu.org/copyleft/gpl.html
+ *
+ * @file
+ */
 
 /**
  * Static accessor class for site_stats and related things
  */
 class SiteStats {
 	static $row, $loaded = false;
-	static $admins, $jobs;
+	static $jobs;
 	static $pageCount = array();
 	static $groupMemberCounts = array();
 
@@ -28,8 +48,7 @@ class SiteStats {
 			# Update schema
 			$u = new SiteStatsUpdate( 0, 0, 0 );
 			$u->doUpdate();
-			$dbr = wfGetDB( DB_SLAVE );
-			self::$row = $dbr->selectRow( 'site_stats', '*', false, __METHOD__ );
+			self::$row = self::doLoad( wfGetDB( DB_SLAVE ) );
 		}
 
 		self::$loaded = true;
@@ -42,13 +61,13 @@ class SiteStats {
 		wfDebug( __METHOD__ . ": reading site_stats from slave\n" );
 		$row = self::doLoad( wfGetDB( DB_SLAVE ) );
 
-		if( !self::isSane( $row ) ) {
+		if ( !self::isSane( $row ) ) {
 			// Might have just been initialized during this request? Underflow?
 			wfDebug( __METHOD__ . ": site_stats damaged or missing on slave\n" );
 			$row = self::doLoad( wfGetDB( DB_MASTER ) );
 		}
 
-		if( !self::isSane( $row ) ) {
+		if ( !self::isSane( $row ) ) {
 			// Normally the site_stats table is initialized at install time.
 			// Some manual construction scenarios may leave the table empty or
 			// broken, however, for instance when importing from a dump into a
@@ -60,7 +79,7 @@ class SiteStats {
 			$row = self::doLoad( wfGetDB( DB_MASTER ) );
 		}
 
-		if( !self::isSane( $row ) ) {
+		if ( !self::isSane( $row ) ) {
 			wfDebug( __METHOD__ . ": site_stats persistently nonsensical o_O\n" );
 		}
 		return $row;
@@ -71,7 +90,16 @@ class SiteStats {
 	 * @return Bool|ResultWrapper
 	 */
 	static function doLoad( $db ) {
-		return $db->selectRow( 'site_stats', '*', false, __METHOD__ );
+		return $db->selectRow( 'site_stats', array(
+				'ss_row_id',
+				'ss_total_views',
+				'ss_total_edits',
+				'ss_good_articles',
+				'ss_total_pages',
+				'ss_users',
+				'ss_active_users',
+				'ss_images',
+			), false, __METHOD__ );
 	}
 
 	/**
@@ -132,7 +160,7 @@ class SiteStats {
 
 	/**
 	 * Find the number of users in a given user group.
-	 * @param $group String: name of group
+	 * @param string $group name of group
 	 * @return Integer
 	 */
 	static function numberingroup( $group ) {
@@ -161,7 +189,7 @@ class SiteStats {
 	static function jobs() {
 		if ( !isset( self::$jobs ) ) {
 			$dbr = wfGetDB( DB_SLAVE );
-			self::$jobs = $dbr->estimateRowCount( 'job' );
+			self::$jobs = array_sum( JobQueueGroup::singleton()->getQueueSizes() );
 			/* Zero rows still do single row read for row that doesn't exist, but people are annoyed by that */
 			if ( self::$jobs == 1 ) {
 				self::$jobs = 0;
@@ -177,7 +205,7 @@ class SiteStats {
 	 */
 	static function pagesInNs( $ns ) {
 		wfProfileIn( __METHOD__ );
-		if( !isset( self::$pageCount[$ns] ) ) {
+		if ( !isset( self::$pageCount[$ns] ) ) {
 			$dbr = wfGetDB( DB_SLAVE );
 			self::$pageCount[$ns] = (int)$dbr->selectField(
 				'page',
@@ -198,20 +226,24 @@ class SiteStats {
 	 * @return bool
 	 */
 	private static function isSane( $row ) {
-		if(
-			$row === false
+		if ( $row === false
 			|| $row->ss_total_pages < $row->ss_good_articles
 			|| $row->ss_total_edits < $row->ss_total_pages
+			|| $row->ss_users < $row->ss_active_users
 		) {
 			return false;
 		}
 		// Now check for underflow/overflow
-		foreach( array( 'total_views', 'total_edits', 'good_articles',
-		'total_pages', 'users', 'admins', 'images' ) as $member ) {
-			if(
-				$row->{"ss_$member"} > 2000000000
-				|| $row->{"ss_$member"} < 0
-			) {
+		foreach ( array(
+			'ss_total_views',
+			'ss_total_edits',
+			'ss_good_articles',
+			'ss_total_pages',
+			'ss_users',
+			'ss_active_users',
+			'ss_images',
+		) as $member ) {
+			if ( $row->$member > 2000000000 || $row->$member < 0 ) {
 				return false;
 			}
 		}
@@ -220,57 +252,101 @@ class SiteStats {
 }
 
 /**
- *
+ * Class for handling updates to the site_stats table
  */
-class SiteStatsUpdate {
-
-	var $mViews, $mEdits, $mGood, $mPages, $mUsers;
+class SiteStatsUpdate implements DeferrableUpdate {
+	protected $views = 0;
+	protected $edits = 0;
+	protected $pages = 0;
+	protected $articles = 0;
+	protected $users = 0;
+	protected $images = 0;
 
+	// @todo deprecate this constructor
 	function __construct( $views, $edits, $good, $pages = 0, $users = 0 ) {
-		$this->mViews = $views;
-		$this->mEdits = $edits;
-		$this->mGood = $good;
-		$this->mPages = $pages;
-		$this->mUsers = $users;
+		$this->views = $views;
+		$this->edits = $edits;
+		$this->articles = $good;
+		$this->pages = $pages;
+		$this->users = $users;
 	}
 
 	/**
-	 * @param $sql
-	 * @param $field
-	 * @param $delta
+	 * @param $deltas Array
+	 * @return SiteStatsUpdate
 	 */
-	function appendUpdate( &$sql, $field, $delta ) {
-		if ( $delta ) {
-			if ( $sql ) {
-				$sql .= ',';
-			}
-			if ( $delta < 0 ) {
-				$sql .= "$field=$field-1";
-			} else {
-				$sql .= "$field=$field+1";
+	public static function factory( array $deltas ) {
+		$update = new self( 0, 0, 0 );
+
+		$fields = array( 'views', 'edits', 'pages', 'articles', 'users', 'images' );
+		foreach ( $fields as $field ) {
+			if ( isset( $deltas[$field] ) && $deltas[$field] ) {
+				$update->$field = $deltas[$field];
 			}
 		}
+
+		return $update;
+	}
+
+	public function doUpdate() {
+		global $wgSiteStatsAsyncFactor;
+
+		$rate = $wgSiteStatsAsyncFactor; // convenience
+		// If set to do so, only do actual DB updates 1 every $rate times.
+		// The other times, just update "pending delta" values in memcached.
+		if ( $rate && ( $rate < 0 || mt_rand( 0, $rate - 1 ) != 0 ) ) {
+			$this->doUpdatePendingDeltas();
+		} else {
+			// Need a separate transaction because this a global lock
+			wfGetDB( DB_MASTER )->onTransactionIdle( array( $this, 'tryDBUpdateInternal' ) );
+		}
 	}
 
-	function doUpdate() {
+	/**
+	 * Do not call this outside of SiteStatsUpdate
+	 *
+	 * @return void
+	 */
+	public function tryDBUpdateInternal() {
+		global $wgSiteStatsAsyncFactor;
+
 		$dbw = wfGetDB( DB_MASTER );
+		$lockKey = wfMemcKey( 'site_stats' ); // prepend wiki ID
+		if ( $wgSiteStatsAsyncFactor ) {
+			// Lock the table so we don't have double DB/memcached updates
+			if ( !$dbw->lockIsFree( $lockKey, __METHOD__ )
+				|| !$dbw->lock( $lockKey, __METHOD__, 1 ) // 1 sec timeout
+			) {
+				$this->doUpdatePendingDeltas();
+				return;
+			}
+			$pd = $this->getPendingDeltas();
+			// Piggy-back the async deltas onto those of this stats update....
+			$this->views += ( $pd['ss_total_views']['+'] - $pd['ss_total_views']['-'] );
+			$this->edits += ( $pd['ss_total_edits']['+'] - $pd['ss_total_edits']['-'] );
+			$this->articles += ( $pd['ss_good_articles']['+'] - $pd['ss_good_articles']['-'] );
+			$this->pages += ( $pd['ss_total_pages']['+'] - $pd['ss_total_pages']['-'] );
+			$this->users += ( $pd['ss_users']['+'] - $pd['ss_users']['-'] );
+			$this->images += ( $pd['ss_images']['+'] - $pd['ss_images']['-'] );
+		}
 
+		// Build up an SQL query of deltas and apply them...
 		$updates = '';
+		$this->appendUpdate( $updates, 'ss_total_views', $this->views );
+		$this->appendUpdate( $updates, 'ss_total_edits', $this->edits );
+		$this->appendUpdate( $updates, 'ss_good_articles', $this->articles );
+		$this->appendUpdate( $updates, 'ss_total_pages', $this->pages );
+		$this->appendUpdate( $updates, 'ss_users', $this->users );
+		$this->appendUpdate( $updates, 'ss_images', $this->images );
+		if ( $updates != '' ) {
+			$dbw->update( 'site_stats', array( $updates ), array(), __METHOD__ );
+		}
 
-		$this->appendUpdate( $updates, 'ss_total_views', $this->mViews );
-		$this->appendUpdate( $updates, 'ss_total_edits', $this->mEdits );
-		$this->appendUpdate( $updates, 'ss_good_articles', $this->mGood );
-		$this->appendUpdate( $updates, 'ss_total_pages', $this->mPages );
-		$this->appendUpdate( $updates, 'ss_users', $this->mUsers );
-
-		if ( $updates ) {
-			$site_stats = $dbw->tableName( 'site_stats' );
-			$sql = "UPDATE $site_stats SET $updates";
-
-			# Need a separate transaction because this a global lock
-			$dbw->begin();
-			$dbw->query( $sql, __METHOD__ );
-			$dbw->commit();
+		if ( $wgSiteStatsAsyncFactor ) {
+			// Decrement the async deltas now that we applied them
+			$this->removePendingDeltas( $pd );
+			// Commit the updates and unlock the table
+			$dbw->unlock( $lockKey, __METHOD__ );
 		}
 	}
 
@@ -289,8 +365,8 @@ class SiteStatsUpdate {
 			array(
 				'rc_user != 0',
 				'rc_bot' => 0,
-				"rc_log_type != 'newusers' OR rc_log_type IS NULL",
-				"rc_timestamp >= '{$dbw->timestamp( wfTimestamp( TS_UNIX ) - $wgActiveUserDays*24*3600 )}'",
+				'rc_log_type != ' . $dbr->addQuotes( 'newusers' ) . ' OR rc_log_type IS NULL',
+				'rc_timestamp >= ' . $dbr->addQuotes( $dbr->timestamp( wfTimestamp( TS_UNIX ) - $wgActiveUserDays * 24 * 3600 ) ),
 			),
 			__METHOD__
 		);
@@ -302,6 +378,102 @@ class SiteStatsUpdate {
 		);
 		return $activeUsers;
 	}
+
+	protected function doUpdatePendingDeltas() {
+		$this->adjustPending( 'ss_total_views', $this->views );
+		$this->adjustPending( 'ss_total_edits', $this->edits );
+		$this->adjustPending( 'ss_good_articles', $this->articles );
+		$this->adjustPending( 'ss_total_pages', $this->pages );
+		$this->adjustPending( 'ss_users', $this->users );
+		$this->adjustPending( 'ss_images', $this->images );
+	}
+
+	/**
+	 * @param $sql string
+	 * @param $field string
+	 * @param $delta integer
+	 */
+	protected function appendUpdate( &$sql, $field, $delta ) {
+		if ( $delta ) {
+			if ( $sql ) {
+				$sql .= ',';
+			}
+			if ( $delta < 0 ) {
+				$sql .= "$field=$field-" . abs( $delta );
+			} else {
+				$sql .= "$field=$field+" . abs( $delta );
+			}
+		}
+	}
+
+	/**
+	 * @param $type string
+	 * @param string $sign ('+' or '-')
+	 * @return string
+	 */
+	private function getTypeCacheKey( $type, $sign ) {
+		return wfMemcKey( 'sitestatsupdate', 'pendingdelta', $type, $sign );
+	}
+
+	/**
+	 * Adjust the pending deltas for a stat type.
+	 * Each stat type has two pending counters, one for increments and decrements
+	 * @param $type string
+	 * @param $delta integer Delta (positive or negative)
+	 * @return void
+	 */
+	protected function adjustPending( $type, $delta ) {
+		global $wgMemc;
+
+		if ( $delta < 0 ) { // decrement
+			$key = $this->getTypeCacheKey( $type, '-' );
+		} else { // increment
+			$key = $this->getTypeCacheKey( $type, '+' );
+		}
+
+		$magnitude = abs( $delta );
+		if ( !$wgMemc->incr( $key, $magnitude ) ) { // not there?
+			if ( !$wgMemc->add( $key, $magnitude ) ) { // race?
+				$wgMemc->incr( $key, $magnitude );
+			}
+		}
+	}
+
+	/**
+	 * Get pending delta counters for each stat type
+	 * @return Array Positive and negative deltas for each type
+	 * @return void
+	 */
+	protected function getPendingDeltas() {
+		global $wgMemc;
+
+		$pending = array();
+		foreach ( array( 'ss_total_views', 'ss_total_edits',
+			'ss_good_articles', 'ss_total_pages', 'ss_users', 'ss_images' ) as $type )
+		{
+			// Get pending increments and pending decrements
+			$pending[$type]['+'] = (int)$wgMemc->get( $this->getTypeCacheKey( $type, '+' ) );
+			$pending[$type]['-'] = (int)$wgMemc->get( $this->getTypeCacheKey( $type, '-' ) );
+		}
+
+		return $pending;
+	}
+
+	/**
+	 * Reduce pending delta counters after updates have been applied
+	 * @param array $pd Result of getPendingDeltas(), used for DB update
+	 * @return void
+	 */
+	protected function removePendingDeltas( array $pd ) {
+		global $wgMemc;
+
+		foreach ( $pd as $type => $deltas ) {
+			foreach ( $deltas as $sign => $magnitude ) {
+				// Lower the pending counter now that we applied these changes
+				$wgMemc->decr( $this->getTypeCacheKey( $type, $sign ), $magnitude );
+			}
+		}
+	}
 }
 
 /**
@@ -407,12 +579,12 @@ class SiteStatsInit {
 
 	/**
 	 * Do all updates and commit them. More or less a replacement
-	 * for the original initStats, but without the calls to wfOut()
+	 * for the original initStats, but without output.
 	 *
-	 * @param $database Boolean or DatabaseBase:
+	 * @param $database DatabaseBase|bool
 	 * - Boolean: whether to use the master DB
 	 * - DatabaseBase: database connection to use
-	 * @param $options Array of options, may contain the following values
+	 * @param array $options of options, may contain the following values
 	 * - update Boolean: whether to update the current stats (true) or write fresh (false) (default: false)
 	 * - views Boolean: when true, do not update the number of page views (default: true)
 	 * - activeUsers Boolean: whether to update the number of active users (default: false)
@@ -430,19 +602,19 @@ class SiteStatsInit {
 		$counter->files();
 
 		// Only do views if we don't want to not count them
-		if( $options['views'] ) {
+		if ( $options['views'] ) {
 			$counter->views();
 		}
 
 		// Update/refresh
-		if( $options['update'] ) {
+		if ( $options['update'] ) {
 			$counter->update();
 		} else {
 			$counter->refresh();
 		}
 
 		// Count active users if need be
-		if( $options['activeUsers'] ) {
+		if ( $options['activeUsers'] ) {
 			SiteStatsUpdate::cacheUpdate( wfGetDB( DB_MASTER ) );
 		}
 	}
