@@ -78,7 +78,6 @@ class SpecialPageFactory {
 		'Allpages'                  => 'SpecialAllpages',
 		'Prefixindex'               => 'SpecialPrefixindex',
 		'Categories'                => 'SpecialCategories',
-		'Disambiguations'           => 'DisambiguationsPage',
 		'Listredirects'             => 'ListredirectsPage',
 		'PagesWithProp'             => 'SpecialPagesWithProp',
 
@@ -94,6 +93,7 @@ class SpecialPageFactory {
 		'PasswordReset'             => 'SpecialPasswordReset',
 		'DeletedContributions'      => 'DeletedContributionsPage',
 		'Preferences'               => 'SpecialPreferences',
+		'ResetTokens'               => 'SpecialResetTokens',
 		'Contributions'             => 'SpecialContributions',
 		'Listgrouprights'           => 'SpecialListGroupRights',
 		'Listusers'                 => 'SpecialListUsers',
@@ -130,6 +130,7 @@ class SpecialPageFactory {
 		// Redirecting special pages
 		'LinkSearch'                => 'LinkSearchPage',
 		'Randompage'                => 'Randompage',
+		'RandomInCategory'          => 'SpecialRandomInCategory',
 		'Randomredirect'            => 'SpecialRandomredirect',
 
 		// High use pages
@@ -154,14 +155,15 @@ class SpecialPageFactory {
 
 		// Unlisted / redirects
 		'Blankpage'                 => 'SpecialBlankpage',
-		'Blockme'                   => 'SpecialBlockme',
 		'Emailuser'                 => 'SpecialEmailUser',
 		'Movepage'                  => 'MovePageForm',
 		'Mycontributions'           => 'SpecialMycontributions',
 		'Mypage'                    => 'SpecialMypage',
 		'Mytalk'                    => 'SpecialMytalk',
 		'Myuploads'                 => 'SpecialMyuploads',
+		'AllMyUploads'              => 'SpecialAllMyUploads',
 		'PermanentLink'             => 'SpecialPermanentLink',
+		'Redirect'                  => 'SpecialRedirect',
 		'Revisiondelete'            => 'SpecialRevisionDelete',
 		'Specialpages'              => 'SpecialSpecialpages',
 		'Userlogout'                => 'SpecialUserlogout',
@@ -200,7 +202,7 @@ class SpecialPageFactory {
 				self::$mList['ChangeEmail'] = 'SpecialChangeEmail';
 			}
 
-			if( $wgEnableJavaScriptTest ) {
+			if ( $wgEnableJavaScriptTest ) {
 				self::$mList['JavaScriptTest'] = 'SpecialJavaScriptTest';
 			}
 
@@ -286,7 +288,7 @@ class SpecialPageFactory {
 	 *
 	 * @param $page Mixed: SpecialPage or string
 	 * @param $group String
-	 * @deprecated 1.21 Override SpecialPage::getGroupName
+	 * @deprecated since 1.21 Override SpecialPage::getGroupName
 	 */
 	public static function setGroup( $page, $group ) {
 		wfDeprecated( __METHOD__, '1.21' );
@@ -301,7 +303,7 @@ class SpecialPageFactory {
 	 *
 	 * @param $page SpecialPage
 	 * @return String
-	 * @deprecated 1.21 Use SpecialPage::getFinalGroupName
+	 * @deprecated since 1.21 Use SpecialPage::getFinalGroupName
 	 */
 	public static function getGroup( &$page ) {
 		wfDeprecated( __METHOD__, '1.21' );
@@ -464,9 +466,8 @@ class SpecialPageFactory {
 			if ( $name != $page->getLocalName() && !$context->getRequest()->wasPosted() ) {
 				$query = $context->getRequest()->getQueryValues();
 				unset( $query['title'] );
-				$query = wfArrayToCgi( $query );
 				$title = $page->getTitle( $par );
-				$url = $title->getFullUrl( $query );
+				$url = $title->getFullURL( $query );
 				$context->getOutput()->redirect( $url );
 				wfProfileOut( __METHOD__ );
 				return $title;
