@@ -4,7 +4,7 @@
  *
  * Created on May 13, 2007
  *
- * Copyright © 2006 Yuri Astrakhan <Firstname><Lastname>@gmail.com
+ * Copyright © 2006 Yuri Astrakhan "<Firstname><Lastname>@gmail.com"
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,11 +24,6 @@
  * @file
  */
 
-if ( !defined( 'MEDIAWIKI' ) ) {
-	// Eclipse helper - will be ignored in production
-	require_once( "ApiQueryBase.php" );
-}
-
 /**
  * A query module to enumerate categories the set of pages belong to.
  *
@@ -54,11 +49,10 @@ class ApiQueryCategories extends ApiQueryGeneratorBase {
 
 	/**
 	 * @param $resultPageSet ApiPageSet
-	 * @return
 	 */
 	private function run( $resultPageSet = null ) {
 		if ( $this->getPageSet()->getGoodTitleCount() == 0 ) {
-			return;	// nothing to do
+			return; // nothing to do
 		}
 
 		$params = $this->extractRequestParams();
@@ -80,7 +74,7 @@ class ApiQueryCategories extends ApiQueryGeneratorBase {
 			foreach ( $params['categories'] as $cat ) {
 				$title = Title::newFromText( $cat );
 				if ( !$title || $title->getNamespace() != NS_CATEGORY ) {
-					$this->setWarning( "``$cat'' is not a category" );
+					$this->setWarning( "\"$cat\" is not a category" );
 				} else {
 					$cats[] = $title->getDBkey();
 				}
@@ -90,16 +84,14 @@ class ApiQueryCategories extends ApiQueryGeneratorBase {
 
 		if ( !is_null( $params['continue'] ) ) {
 			$cont = explode( '|', $params['continue'] );
-			if ( count( $cont ) != 2 ) {
-				$this->dieUsage( "Invalid continue param. You should pass the " .
-					"original value returned by the previous query", "_badcontinue" );
-			}
+			$this->dieContinueUsageIf( count( $cont ) != 2 );
+			$op = $params['dir'] == 'descending' ? '<' : '>';
 			$clfrom = intval( $cont[0] );
-			$clto = $this->getDB()->strencode( $this->titleToKey( $cont[1] ) );
+			$clto = $this->getDB()->addQuotes( $cont[1] );
 			$this->addWhere(
-				"cl_from > $clfrom OR " .
+				"cl_from $op $clfrom OR " .
 				"(cl_from = $clfrom AND " .
-				"cl_to >= '$clto')"
+				"cl_to $op= $clto)"
 			);
 		}
 
@@ -127,11 +119,16 @@ class ApiQueryCategories extends ApiQueryGeneratorBase {
 		}
 
 		$this->addOption( 'USE INDEX', array( 'categorylinks' => 'cl_from' ) );
+
+		$sort = ( $params['dir'] == 'descending' ? ' DESC' : '' );
 		// Don't order by cl_from if it's constant in the WHERE clause
 		if ( count( $this->getPageSet()->getGoodTitles() ) == 1 ) {
-			$this->addOption( 'ORDER BY', 'cl_to' );
+			$this->addOption( 'ORDER BY', 'cl_to' . $sort );
 		} else {
-			$this->addOption( 'ORDER BY', "cl_from, cl_to" );
+			$this->addOption( 'ORDER BY', array(
+						'cl_from' . $sort,
+						'cl_to' . $sort
+			));
 		}
 
 		$res = $this->select( __METHOD__ );
@@ -142,8 +139,7 @@ class ApiQueryCategories extends ApiQueryGeneratorBase {
 				if ( ++$count > $params['limit'] ) {
 					// We've reached the one extra which shows that
 					// there are additional pages to be had. Stop here...
-					$this->setContinueEnumParameter( 'continue', $row->cl_from .
-							'|' . $this->keyToTitle( $row->cl_to ) );
+					$this->setContinueEnumParameter( 'continue', $row->cl_from . '|' . $row->cl_to );
 					break;
 				}
 
@@ -163,8 +159,7 @@ class ApiQueryCategories extends ApiQueryGeneratorBase {
 
 				$fit = $this->addPageSubItem( $row->cl_from, $vals );
 				if ( !$fit ) {
-					$this->setContinueEnumParameter( 'continue', $row->cl_from .
-							'|' . $this->keyToTitle( $row->cl_to ) );
+					$this->setContinueEnumParameter( 'continue', $row->cl_from . '|' . $row->cl_to );
 					break;
 				}
 			}
@@ -174,12 +169,11 @@ class ApiQueryCategories extends ApiQueryGeneratorBase {
 				if ( ++$count > $params['limit'] ) {
 					// We've reached the one extra which shows that
 					// there are additional pages to be had. Stop here...
-					$this->setContinueEnumParameter( 'continue', $row->cl_from .
-							'|' . $this->keyToTitle( $row->cl_to ) );
+					$this->setContinueEnumParameter( 'continue', $row->cl_from . '|' . $row->cl_to );
 					break;
 				}
 
-				$titles[] = Title :: makeTitle( NS_CATEGORY, $row->cl_to );
+				$titles[] = Title::makeTitle( NS_CATEGORY, $row->cl_to );
 			}
 			$resultPageSet->populateFromTitles( $titles );
 		}
@@ -189,7 +183,7 @@ class ApiQueryCategories extends ApiQueryGeneratorBase {
 		return array(
 			'prop' => array(
 				ApiBase::PARAM_ISMULTI => true,
-				ApiBase::PARAM_TYPE => array (
+				ApiBase::PARAM_TYPE => array(
 					'sortkey',
 					'timestamp',
 					'hidden',
@@ -213,6 +207,13 @@ class ApiQueryCategories extends ApiQueryGeneratorBase {
 			'categories' => array(
 				ApiBase::PARAM_ISMULTI => true,
 			),
+			'dir' => array(
+				ApiBase::PARAM_DFLT => 'ascending',
+				ApiBase::PARAM_TYPE => array(
+					'ascending',
+					'descending'
+				)
+			),
 		);
 	}
 
@@ -228,6 +229,26 @@ class ApiQueryCategories extends ApiQueryGeneratorBase {
 			'show' => 'Which kind of categories to show',
 			'continue' => 'When more results are available, use this to continue',
 			'categories' => 'Only list these categories. Useful for checking whether a certain page is in a certain category',
+			'dir' => 'The direction in which to list',
+		);
+	}
+
+	public function getResultProperties() {
+		return array(
+			'' => array(
+				'ns' => 'namespace',
+				'title' => 'string'
+			),
+			'sortkey' => array(
+				'sortkey' => 'string',
+				'sortkeyprefix' => 'string'
+			),
+			'timestamp' => array(
+				'timestamp' => 'timestamp'
+			),
+			'hidden' => array(
+				'hidden' => 'boolean'
+			)
 		);
 	}
 
@@ -241,20 +262,14 @@ class ApiQueryCategories extends ApiQueryGeneratorBase {
 		) );
 	}
 
-	protected function getExamples() {
+	public function getExamples() {
 		return array(
-			'Get a list of categories [[Albert Einstein]] belongs to:',
-			'  api.php?action=query&prop=categories&titles=Albert%20Einstein',
-			'Get information about all categories used in the [[Albert Einstein]]:',
-			'  api.php?action=query&generator=categories&titles=Albert%20Einstein&prop=info'
+			'api.php?action=query&prop=categories&titles=Albert%20Einstein' => 'Get a list of categories [[Albert Einstein]] belongs to',
+			'api.php?action=query&generator=categories&titles=Albert%20Einstein&prop=info' => 'Get information about all categories used in the [[Albert Einstein]]',
 		);
 	}
 
 	public function getHelpUrls() {
 		return 'https://www.mediawiki.org/wiki/API:Properties#categories_.2F_cl';
 	}
-
-	public function getVersion() {
-		return __CLASS__ . ': $Id: ApiQueryCategories.php 104449 2011-11-28 15:52:04Z reedy $';
-	}
 }
