@@ -185,4 +185,8 @@ class ApiQueryRandom extends ApiQueryGeneratorBase {
 	public function getExamples() {
 		return 'api.php?action=query&list=random&rnnamespace=0&rnlimit=2';
 	}
+
+	public function getHelpUrls() {
+		return 'https://www.mediawiki.org/wiki/API:Random';
+	}
 }
