@@ -48,6 +48,11 @@ class ApiTokens extends ApiBase {
 	}
 
 	private function getTokenTypes() {
+		// If we're in JSON callback mode, no tokens can be obtained
+		if ( !is_null( $this->getMain()->getRequest()->getVal( 'callback' ) ) ) {
+			return array();
+		}
+
 		static $types = null;
 		if ( $types ) {
 			return $types;
