@@ -1,6 +1,21 @@
 <?php
 /**
- * Generator of database load balancing objects
+ * Generator of database load balancing objects.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * http://www.gnu.org/copyleft/gpl.html
  *
  * @file
  * @ingroup Database
@@ -11,6 +26,10 @@
  * @ingroup Database
  */
 abstract class LBFactory {
+
+	/**
+	 * @var LBFactory
+	 */
 	static $instance;
 
 	/**
@@ -22,16 +41,10 @@ abstract class LBFactory {
 		self::$instance = new LBFactory_Fake( $wgLBFactoryConf );
 	}
 
-	/**
-	 * Resets the singleton for use if it's been disabled. Does nothing otherwise
-	 */
-	public static function enableBackend() {
-		if( self::$instance instanceof LBFactory_Fake )
-			self::$instance = null;
-	}
-
 	/**
 	 * Get an LBFactory instance
+	 *
+	 * @return LBFactory
 	 */
 	static function &singleton() {
 		if ( is_null( self::$instance ) ) {
@@ -44,7 +57,6 @@ abstract class LBFactory {
 
 	/**
 	 * Shut down, close connections and destroy the cached instance.
-	 *
 	 */
 	static function destroyInstance() {
 		if ( self::$instance ) {
@@ -56,6 +68,8 @@ abstract class LBFactory {
 
 	/**
 	 * Set the instance to be the given object
+	 *
+	 * @param $instance LBFactory
 	 */
 	static function setInstance( $instance ) {
 		self::destroyInstance();
@@ -64,6 +78,7 @@ abstract class LBFactory {
 
 	/**
 	 * Construct a factory based on a configuration array (typically from $wgLBFactoryConf)
+	 * @param $conf
 	 */
 	abstract function __construct( $conf );
 
@@ -71,7 +86,7 @@ abstract class LBFactory {
 	 * Create a new load balancer object. The resulting object will be untracked,
 	 * not chronology-protected, and the caller is responsible for cleaning it up.
 	 *
-	 * @param $wiki String: wiki ID, or false for the current wiki
+	 * @param string $wiki wiki ID, or false for the current wiki
 	 * @return LoadBalancer
 	 */
 	abstract function newMainLB( $wiki = false );
@@ -79,26 +94,30 @@ abstract class LBFactory {
 	/**
 	 * Get a cached (tracked) load balancer object.
 	 *
-	 * @param $wiki String: wiki ID, or false for the current wiki
+	 * @param string $wiki wiki ID, or false for the current wiki
 	 * @return LoadBalancer
 	 */
 	abstract function getMainLB( $wiki = false );
 
-	/*
+	/**
 	 * Create a new load balancer for external storage. The resulting object will be
 	 * untracked, not chronology-protected, and the caller is responsible for
 	 * cleaning it up.
 	 *
-	 * @param $cluster String: external storage cluster, or false for core
-	 * @param $wiki String: wiki ID, or false for the current wiki
+	 * @param string $cluster external storage cluster, or false for core
+	 * @param string $wiki wiki ID, or false for the current wiki
+	 *
+	 * @return LoadBalancer
 	 */
 	abstract function newExternalLB( $cluster, $wiki = false );
 
-	/*
+	/**
 	 * Get a cached (tracked) load balancer for external storage
 	 *
-	 * @param $cluster String: external storage cluster, or false for core
-	 * @param $wiki String: wiki ID, or false for the current wiki
+	 * @param string $cluster external storage cluster, or false for core
+	 * @param string $wiki wiki ID, or false for the current wiki
+	 *
+	 * @return LoadBalancer
 	 */
 	abstract function &getExternalLB( $cluster, $wiki = false );
 
@@ -106,6 +125,8 @@ abstract class LBFactory {
 	 * Execute a function for each tracked load balancer
 	 * The callback is called with the load balancer as the first parameter,
 	 * and $params passed as the subsequent parameters.
+	 * @param $callback string|array
+	 * @param array $params
 	 */
 	abstract function forEachLB( $callback, $params = array() );
 
@@ -113,10 +134,13 @@ abstract class LBFactory {
 	 * Prepare all tracked load balancers for shutdown
 	 * STUB
 	 */
-	function shutdown() {}
+	function shutdown() {
+	}
 
 	/**
 	 * Call a method of each tracked load balancer
+	 * @param $methodName string
+	 * @param $args array
 	 */
 	function forEachLBCallMethod( $methodName, $args = array() ) {
 		$this->forEachLB( array( $this, 'callMethod' ), array( $methodName, $args ) );
@@ -124,6 +148,9 @@ abstract class LBFactory {
 
 	/**
 	 * Private helper for forEachLBCallMethod
+	 * @param $loadBalancer
+	 * @param $methodName string
+	 * @param $args
 	 */
 	function callMethod( $loadBalancer, $methodName, $args ) {
 		call_user_func_array( array( $loadBalancer, $methodName ), $args );
@@ -141,6 +168,10 @@ abstract class LBFactory {
  * A simple single-master LBFactory that gets its configuration from the b/c globals
  */
 class LBFactory_Simple extends LBFactory {
+
+	/**
+	 * @var LoadBalancer
+	 */
 	var $mainLB;
 	var $extLBs = array();
 
@@ -151,20 +182,34 @@ class LBFactory_Simple extends LBFactory {
 		$this->chronProt = new ChronologyProtector;
 	}
 
+	/**
+	 * @param $wiki
+	 * @return LoadBalancer
+	 */
 	function newMainLB( $wiki = false ) {
 		global $wgDBservers, $wgMasterWaitTimeout;
 		if ( $wgDBservers ) {
 			$servers = $wgDBservers;
 		} else {
 			global $wgDBserver, $wgDBuser, $wgDBpassword, $wgDBname, $wgDBtype, $wgDebugDumpSql;
-			$servers = array(array(
+			global $wgDBssl, $wgDBcompress;
+
+			$flags = ( $wgDebugDumpSql ? DBO_DEBUG : 0 ) | DBO_DEFAULT;
+			if ( $wgDBssl ) {
+				$flags |= DBO_SSL;
+			}
+			if ( $wgDBcompress ) {
+				$flags |= DBO_COMPRESS;
+			}
+
+			$servers = array( array(
 				'host' => $wgDBserver,
 				'user' => $wgDBuser,
 				'password' => $wgDBpassword,
 				'dbname' => $wgDBname,
 				'type' => $wgDBtype,
 				'load' => 1,
-				'flags' => ($wgDebugDumpSql ? DBO_DEBUG : 0) | DBO_DEFAULT
+				'flags' => $flags
 			));
 		}
 
@@ -174,6 +219,10 @@ class LBFactory_Simple extends LBFactory {
 		));
 	}
 
+	/**
+	 * @param $wiki
+	 * @return LoadBalancer
+	 */
 	function getMainLB( $wiki = false ) {
 		if ( !isset( $this->mainLB ) ) {
 			$this->mainLB = $this->newMainLB( $wiki );
@@ -183,20 +232,32 @@ class LBFactory_Simple extends LBFactory {
 		return $this->mainLB;
 	}
 
+	/**
+	 * @throws MWException
+	 * @param $cluster
+	 * @param $wiki
+	 * @return LoadBalancer
+	 */
 	function newExternalLB( $cluster, $wiki = false ) {
 		global $wgExternalServers;
 		if ( !isset( $wgExternalServers[$cluster] ) ) {
-			throw new MWException( __METHOD__.": Unknown cluster \"$cluster\"" );
+			throw new MWException( __METHOD__ . ": Unknown cluster \"$cluster\"" );
 		}
 		return new LoadBalancer( array(
 			'servers' => $wgExternalServers[$cluster]
 		));
 	}
 
+	/**
+	 * @param $cluster
+	 * @param $wiki
+	 * @return array
+	 */
 	function &getExternalLB( $cluster, $wiki = false ) {
 		if ( !isset( $this->extLBs[$cluster] ) ) {
 			$this->extLBs[$cluster] = $this->newExternalLB( $cluster, $wiki );
 			$this->extLBs[$cluster]->parentInfo( array( 'id' => "ext-$cluster" ) );
+			$this->chronProt->initLB( $this->extLBs[$cluster] );
 		}
 		return $this->extLBs[$cluster];
 	}
@@ -205,6 +266,8 @@ class LBFactory_Simple extends LBFactory {
 	 * Execute a function for each tracked load balancer
 	 * The callback is called with the load balancer as the first parameter,
 	 * and $params passed as the subsequent parameters.
+	 * @param $callback
+	 * @param $params array
 	 */
 	function forEachLB( $callback, $params = array() ) {
 		if ( isset( $this->mainLB ) ) {
@@ -219,6 +282,9 @@ class LBFactory_Simple extends LBFactory {
 		if ( $this->mainLB ) {
 			$this->chronProt->shutdownLB( $this->mainLB );
 		}
+		foreach ( $this->extLBs as $extLB ) {
+			$this->chronProt->shutdownLB( $extLB );
+		}
 		$this->chronProt->shutdown();
 		$this->commitMasterChanges();
 	}
@@ -231,21 +297,27 @@ class LBFactory_Simple extends LBFactory {
  * LBFactory::enableBackend() to return to normal behavior
  */
 class LBFactory_Fake extends LBFactory {
-	function __construct( $conf ) {}
+	function __construct( $conf ) {
+	}
 
-	function newMainLB( $wiki = false) {
+	function newMainLB( $wiki = false ) {
 		throw new DBAccessError;
 	}
+
 	function getMainLB( $wiki = false ) {
 		throw new DBAccessError;
 	}
+
 	function newExternalLB( $cluster, $wiki = false ) {
 		throw new DBAccessError;
 	}
+
 	function &getExternalLB( $cluster, $wiki = false ) {
 		throw new DBAccessError;
 	}
-	function forEachLB( $callback, $params = array() ) {}
+
+	function forEachLB( $callback, $params = array() ) {
+	}
 }
 
 /**
@@ -256,76 +328,3 @@ class DBAccessError extends MWException {
 		parent::__construct( "Mediawiki tried to access the database via wfGetDB(). This is not allowed." );
 	}
 }
-
-/**
- * Class for ensuring a consistent ordering of events as seen by the user, despite replication.
- * Kind of like Hawking's [[Chronology Protection Agency]].
- */
-class ChronologyProtector {
-	var $startupPos;
-	var $shutdownPos = array();
-
-	/**
-	 * Initialise a LoadBalancer to give it appropriate chronology protection.
-	 *
-	 * @param $lb LoadBalancer
-	 */
-	function initLB( $lb ) {
-		if ( $this->startupPos === null ) {
-			if ( !empty( $_SESSION[__CLASS__] ) ) {
-				$this->startupPos = $_SESSION[__CLASS__];
-			}
-		}
-		if ( !$this->startupPos ) {
-			return;
-		}
-		$masterName = $lb->getServerName( 0 );
-
-		if ( $lb->getServerCount() > 1 && !empty( $this->startupPos[$masterName] ) ) {
-			$info = $lb->parentInfo();
-			$pos = $this->startupPos[$masterName];
-			wfDebug( __METHOD__.": LB " . $info['id'] . " waiting for master pos $pos\n" );
-			$lb->waitFor( $this->startupPos[$masterName] );
-		}
-	}
-
-	/**
-	 * Notify the ChronologyProtector that the LoadBalancer is about to shut
-	 * down. Saves replication positions.
-	 *
-	 * @param $lb LoadBalancer
-	 */
-	function shutdownLB( $lb ) {
-		// Don't start a session, don't bother with non-replicated setups
-		if ( strval( session_id() ) == '' || $lb->getServerCount() <= 1 ) {
-			return;
-		}
-		$masterName = $lb->getServerName( 0 );
-		if ( isset( $this->shutdownPos[$masterName] ) ) {
-			// Already done
-			return;
-		}
-		// Only save the position if writes have been done on the connection
-		$db = $lb->getAnyOpenConnection( 0 );
-		$info = $lb->parentInfo();
-		if ( !$db || !$db->doneWrites() ) {
-			wfDebug( __METHOD__.": LB {$info['id']}, no writes done\n" );
-			return;
-		}
-		$pos = $db->getMasterPos();
-		wfDebug( __METHOD__.": LB {$info['id']} has master pos $pos\n" );
-		$this->shutdownPos[$masterName] = $pos;
-	}
-
-	/**
-	 * Notify the ChronologyProtector that the LBFactory is done calling shutdownLB() for now.
-	 * May commit chronology data to persistent storage.
-	 */
-	function shutdown() {
-		if ( session_id() != '' && count( $this->shutdownPos ) ) {
-			wfDebug( __METHOD__.": saving master pos for " .
-				count( $this->shutdownPos ) . " master(s)\n" );
-			$_SESSION[__CLASS__] = $this->shutdownPos;
-		}
-	}
-}
