@@ -59,11 +59,12 @@ class ForeignDBRepo extends LocalRepo {
 			$this->dbConn = DatabaseBase::factory( $this->dbType,
 				array(
 					'host' => $this->dbServer,
-					'user'   => $this->dbUser,
+					'user' => $this->dbUser,
 					'password' => $this->dbPassword,
 					'dbname' => $this->dbName,
 					'flags' => $this->dbFlags,
-					'tablePrefix' => $this->tablePrefix
+					'tablePrefix' => $this->tablePrefix,
+					'foreign' => true,
 				)
 			);
 		}
