@@ -2,6 +2,21 @@
 /**
  * Core installer web interface.
  *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * http://www.gnu.org/copyleft/gpl.html
+ *
  * @file
  * @ingroup Deployment
  */
@@ -41,10 +56,11 @@ class WebInstaller extends Installer {
 
 	/**
 	 * The main sequence of page names. These will be displayed in turn.
-	 * To add one:
-	 *    * Add it here
-	 *    * Add a config-page-<name> message
-	 *    * Add a WebInstaller_<name> class
+	 *
+	 * To add a new installer page:
+	 *    * Add it to this WebInstaller::$pageSequence property
+	 *    * Add a "config-page-<name>" message
+	 *    * Add a "WebInstaller_<name>" class
 	 * @var array
 	 */
 	public $pageSequence = array(
@@ -124,7 +140,7 @@ class WebInstaller extends Installer {
 	/**
 	 * Main entry point.
 	 *
-	 * @param $session Array: initial session array
+	 * @param array $session initial session array
 	 *
 	 * @return Array: new session array
 	 */
@@ -138,28 +154,30 @@ class WebInstaller extends Installer {
 		$this->exportVars();
 		$this->setupLanguage();
 
-		if( ( $this->getVar( '_InstallDone' ) || $this->getVar( '_UpgradeDone' ) )
-			&& $this->request->getVal( 'localsettings' ) )
-		{
+		if ( ( $this->getVar( '_InstallDone' ) || $this->getVar( '_UpgradeDone' ) )
+			&& $this->request->getVal( 'localsettings' )
+		) {
 			$this->request->response()->header( 'Content-type: application/x-httpd-php' );
 			$this->request->response()->header(
 				'Content-Disposition: attachment; filename="LocalSettings.php"'
 			);
 
-			$ls = new LocalSettingsGenerator( $this );
+			$ls = InstallerOverrides::getLocalSettingsGenerator( $this );
 			$rightsProfile = $this->rightsProfiles[$this->getVar( '_RightsProfile' )];
-			foreach( $rightsProfile as $group => $rightsArr ) {
+			foreach ( $rightsProfile as $group => $rightsArr ) {
 				$ls->setGroupRights( $group, $rightsArr );
 			}
 			echo $ls->getText();
+
 			return $this->session;
 		}
 
 		$cssDir = $this->request->getVal( 'css' );
-		if( $cssDir ) {
+		if ( $cssDir ) {
 			$cssDir = ( $cssDir == 'rtl' ? 'rtl' : 'ltr' );
 			$this->request->response()->header( 'Content-type: text/css' );
 			echo $this->output->getCSS( $cssDir );
+
 			return $this->session;
 		}
 
@@ -183,6 +201,7 @@ class WebInstaller extends Installer {
 			$this->output->useShortHeader();
 			$this->output->allowFrames();
 			$page->submitCC();
+
 			return $this->finish();
 		}
 
@@ -191,6 +210,7 @@ class WebInstaller extends Installer {
 			$this->output->useShortHeader();
 			$this->output->allowFrames();
 			$this->output->addHTML( $page->getCCDoneBox() );
+
 			return $this->finish();
 		}
 
@@ -234,12 +254,13 @@ class WebInstaller extends Installer {
 				do {
 					$nextPageId--;
 					$nextPage = $this->pageSequence[$nextPageId];
-				} while( isset( $this->skippedPages[$nextPage] ) );
+				} while ( isset( $this->skippedPages[$nextPage] ) );
 			} else {
 				$nextPage = $this->pageSequence[$lowestUnhappy];
 			}
 
 			$this->output->redirect( $this->getUrl( array( 'page' => $nextPage ) ) );
+
 			return $this->finish();
 		}
 
@@ -247,6 +268,10 @@ class WebInstaller extends Installer {
 		$this->currentPageName = $page->getName();
 		$this->startPageWrapper( $pageName );
 
+		if ( $page->isSlow() ) {
+			$this->disableTimeLimit();
+		}
+
 		$result = $page->execute();
 
 		$this->endPageWrapper();
@@ -300,9 +325,11 @@ class WebInstaller extends Installer {
 
 	/**
 	 * Start the PHP session. This may be called before execute() to start the PHP session.
+	 *
+	 * @return bool
 	 */
 	public function startSession() {
-		if( wfIniGetBool( 'session.auto_start' ) || session_id() ) {
+		if ( wfIniGetBool( 'session.auto_start' ) || session_id() ) {
 			// Done already
 			return true;
 		}
@@ -314,6 +341,7 @@ class WebInstaller extends Installer {
 
 		if ( $this->phpErrors ) {
 			$this->showError( 'config-session-error', $this->phpErrors[0] );
+
 			return false;
 		}
 
@@ -325,11 +353,13 @@ class WebInstaller extends Installer {
 	 *
 	 * This is used by mw-config/index.php to prevent multiple installations of MW
 	 * on the same cookie domain from interfering with each other.
+	 *
+	 * @return string
 	 */
 	public function getFingerprint() {
 		// Get the base URL of the installation
 		$url = $this->request->getFullRequestURL();
-		if ( preg_match( '!^(.*\?)!', $url, $m) ) {
+		if ( preg_match( '!^(.*\?)!', $url, $m ) ) {
 			// Trim query string
 			$url = $m[1];
 		}
@@ -338,26 +368,30 @@ class WebInstaller extends Installer {
 			// the /mw-config/index.php. Kinda scary though?
 			$url = $m[1];
 		}
+
 		return md5( serialize( array(
-			'local path' => dirname( dirname( __FILE__ ) ),
+			'local path' => dirname( __DIR__ ),
 			'url' => $url,
 			'version' => $GLOBALS['wgVersion']
 		) ) );
 	}
 
 	/**
-	 * Show an error message in a box. Parameters are like wfMsg().
+	 * Show an error message in a box. Parameters are like wfMessage().
+	 * @param $msg
 	 */
 	public function showError( $msg /*...*/ ) {
 		$args = func_get_args();
 		array_shift( $args );
 		$args = array_map( 'htmlspecialchars', $args );
-		$msg = wfMsgReal( $msg, $args, false, false, false );
+		$msg = wfMessage( $msg, $args )->useDatabase( false )->plain();
 		$this->output->addHTML( $this->getErrorBox( $msg ) );
 	}
 
 	/**
 	 * Temporary error handler for session start debugging.
+	 * @param $errno
+	 * @param $errstr string
 	 */
 	public function errorHandler( $errno, $errstr ) {
 		$this->phpErrors[] = $errstr;
@@ -390,7 +424,7 @@ class WebInstaller extends Installer {
 	/**
 	 * Get a URL for submission back to the same script.
 	 *
-	 * @param $query: Array
+	 * @param $query array
 	 * @return string
 	 */
 	public function getUrl( $query = array() ) {
@@ -399,7 +433,7 @@ class WebInstaller extends Installer {
 		$url = preg_replace( '/\?.*$/', '', $url );
 
 		if ( $query ) {
-			$url .= '?' . wfArrayToCGI( $query );
+			$url .= '?' . wfArrayToCgi( $query );
 		}
 
 		return $url;
@@ -412,9 +446,6 @@ class WebInstaller extends Installer {
 	 * @return WebInstallerPage
 	 */
 	public function getPageByName( $pageName ) {
-		// Totally lame way to force autoload of WebInstallerPage.php
-		class_exists( 'WebInstallerPage' );
-
 		$pageClass = 'WebInstaller_' . $pageName;
 
 		return new $pageClass( $this );
@@ -425,6 +456,7 @@ class WebInstaller extends Installer {
 	 *
 	 * @param $name String
 	 * @param $default
+	 * @return null
 	 */
 	public function getSession( $name, $default = null ) {
 		if ( !isset( $this->session[$name] ) ) {
@@ -436,7 +468,7 @@ class WebInstaller extends Installer {
 
 	/**
 	 * Set a session variable.
-	 * @param $name String key for the variable
+	 * @param string $name key for the variable
 	 * @param $value Mixed
 	 */
 	public function setSession( $name, $value ) {
@@ -464,7 +496,6 @@ class WebInstaller extends Installer {
 			$this->setVar( '_UserLang', $wgLanguageCode );
 		} else {
 			$wgLanguageCode = $this->getVar( 'wgLanguageCode' );
-			$wgLang = Language::factory( $this->getVar( '_UserLang' ) );
 			$wgContLang = Language::factory( $wgLanguageCode );
 		}
 	}
@@ -477,7 +508,7 @@ class WebInstaller extends Installer {
 	public function getAcceptLanguage() {
 		global $wgLanguageCode, $wgRequest;
 
-		$mwLanguages = Language::getLanguageNames();
+		$mwLanguages = Language::fetchLanguageNames();
 		$headerLanguages = array_keys( $wgRequest->getAcceptLang() );
 
 		foreach ( $headerLanguages as $lang ) {
@@ -492,7 +523,7 @@ class WebInstaller extends Installer {
 	/**
 	 * Called by execute() before page output starts, to show a page list.
 	 *
-	 * @param $currentPageName String
+	 * @param $currentPageName string
 	 */
 	private function startPageWrapper( $currentPageName ) {
 		$s = "<div class=\"config-page-wrapper\">\n";
@@ -515,9 +546,16 @@ class WebInstaller extends Installer {
 
 		$s .= "</ul><br/><ul>\n";
 		$s .= $this->getPageListItem( 'Restart', true, $currentPageName );
-		$s .= "</ul></div>\n"; // end list pane
+		// End list pane
+		$s .= "</ul></div>\n";
+
+		// Messages:
+		// config-page-language, config-page-welcome, config-page-dbconnect, config-page-upgrade,
+		// config-page-dbsettings, config-page-name, config-page-options, config-page-install,
+		// config-page-complete, config-page-restart, config-page-readme, config-page-releasenotes,
+		// config-page-copying, config-page-upgradedoc, config-page-existingwiki
 		$s .= Html::element( 'h2', array(),
-				wfMsg( 'config-page-' . strtolower( $currentPageName ) ) );
+			wfMessage( 'config-page-' . strtolower( $currentPageName ) )->text() );
 
 		$this->output->addHTMLNoFlush( $s );
 	}
@@ -525,15 +563,21 @@ class WebInstaller extends Installer {
 	/**
 	 * Get a list item for the page list.
 	 *
-	 * @param $pageName String
-	 * @param $enabled Boolean
-	 * @param $currentPageName String
+	 * @param $pageName string
+	 * @param $enabled boolean
+	 * @param $currentPageName string
 	 *
 	 * @return string
 	 */
 	private function getPageListItem( $pageName, $enabled, $currentPageName ) {
 		$s = "<li class=\"config-page-list-item\">";
-		$name = wfMsg( 'config-page-' . strtolower( $pageName ) );
+
+		// Messages:
+		// config-page-language, config-page-welcome, config-page-dbconnect, config-page-upgrade,
+		// config-page-dbsettings, config-page-name, config-page-options, config-page-install,
+		// config-page-complete, config-page-restart, config-page-readme, config-page-releasenotes,
+		// config-page-copying, config-page-upgradedoc, config-page-existingwiki
+		$name = wfMessage( 'config-page-' . strtolower( $pageName ) )->text();
 
 		if ( $enabled ) {
 			$query = array( 'page' => $pageName );
@@ -577,16 +621,18 @@ class WebInstaller extends Installer {
 	 */
 	private function endPageWrapper() {
 		$this->output->addHTMLNoFlush(
-					"<div class=\"visualClear\"></div>\n" .
-				"</div>\n" .
-				"<div class=\"visualClear\"></div>\n" .
+			"<div class=\"visualClear\"></div>\n" .
+			"</div>\n" .
+			"<div class=\"visualClear\"></div>\n" .
 			"</div>" );
 	}
 
 	/**
 	 * Get HTML for an error box with an icon.
 	 *
-	 * @param $text String: wikitext, get this with wfMsgNoTrans()
+	 * @param string $text wikitext, get this with wfMessage()->plain()
+	 *
+	 * @return string
 	 */
 	public function getErrorBox( $text ) {
 		return $this->getInfoBox( $text, 'critical-32.png', 'config-error-box' );
@@ -595,7 +641,9 @@ class WebInstaller extends Installer {
 	/**
 	 * Get HTML for a warning box with an icon.
 	 *
-	 * @param $text String: wikitext, get this with wfMsgNoTrans()
+	 * @param string $text wikitext, get this with wfMessage()->plain()
+	 *
+	 * @return string
 	 */
 	public function getWarningBox( $text ) {
 		return $this->getInfoBox( $text, 'warning-32.png', 'config-warning-box' );
@@ -604,50 +652,46 @@ class WebInstaller extends Installer {
 	/**
 	 * Get HTML for an info box with an icon.
 	 *
-	 * @param $text String: wikitext, get this with wfMsgNoTrans()
-	 * @param $icon String: icon name, file in skins/common/images
-	 * @param $class String: additional class name to add to the wrapper div
+	 * @param string $text wikitext, get this with wfMessage()->plain()
+	 * @param string $icon icon name, file in skins/common/images
+	 * @param string $class additional class name to add to the wrapper div
+	 *
+	 * @return string
 	 */
-	public function getInfoBox( $text, $icon = 'info-32.png', $class = false ) {
-		$s =
-			"<div class=\"config-info $class\">\n" .
-				"<div class=\"config-info-left\">\n" .
-				Html::element( 'img',
-					array(
-						'src' => '../skins/common/images/' . $icon,
-						'alt' => wfMsg( 'config-information' ),
-					)
-				) . "\n" .
-				"</div>\n" .
-				"<div class=\"config-info-right\">\n" .
-					$this->parse( $text, true ) . "\n" .
-				"</div>\n" .
-				"<div style=\"clear: left;\"></div>\n" .
-			"</div>\n";
-		return $s;
+	public function getInfoBox( $text, $icon = false, $class = false ) {
+		$text = $this->parse( $text, true );
+		$icon = ( $icon == false ) ?
+			'../skins/common/images/info-32.png' :
+			'../skins/common/images/' . $icon;
+		$alt = wfMessage( 'config-information' )->text();
+
+		return Html::infoBox( $text, $icon, $alt, $class, false );
 	}
 
 	/**
 	 * Get small text indented help for a preceding form field.
-	 * Parameters like wfMsg().
+	 * Parameters like wfMessage().
+	 *
+	 * @param $msg
+	 * @return string
 	 */
 	public function getHelpBox( $msg /*, ... */ ) {
 		$args = func_get_args();
 		array_shift( $args );
 		$args = array_map( 'htmlspecialchars', $args );
-		$text = wfMsgReal( $msg, $args, false, false, false );
-		$html = htmlspecialchars( $text );
+		$text = wfMessage( $msg, $args )->useDatabase( false )->plain();
 		$html = $this->parse( $text, true );
 
 		return "<div class=\"mw-help-field-container\">\n" .
-			   "<span class=\"mw-help-field-hint\">" . wfMsgHtml( 'config-help' ) . "</span>\n" .
-			   "<span class=\"mw-help-field-data\">" . $html . "</span>\n" .
-			   "</div>\n";
+			"<span class=\"mw-help-field-hint\">" . wfMessage( 'config-help' )->escaped() .
+			"</span>\n" .
+			"<span class=\"mw-help-field-data\">" . $html . "</span>\n" .
+			"</div>\n";
 	}
 
 	/**
 	 * Output a help box.
-	 * @param $msg String key for wfMsg()
+	 * @param string $msg key for wfMessage()
 	 */
 	public function showHelpBox( $msg /*, ... */ ) {
 		$args = func_get_args();
@@ -665,7 +709,7 @@ class WebInstaller extends Installer {
 		$args = func_get_args();
 		array_shift( $args );
 		$html = '<div class="config-message">' .
-			$this->parse( wfMsgReal( $msg, $args, false, false, false ) ) .
+			$this->parse( wfMessage( $msg, $args )->useDatabase( false )->plain() ) .
 			"</div>\n";
 		$this->output->addHTML( $html );
 	}
@@ -674,23 +718,27 @@ class WebInstaller extends Installer {
 	 * @param $status Status
 	 */
 	public function showStatusMessage( Status $status ) {
-		$text = $status->getWikiText();
-		$this->output->addWikiText(
-			"<div class=\"config-message\">\n" .
-			$text .
-			"</div>"
-		);
+		$errors = array_merge( $status->getErrorsArray(), $status->getWarningsArray() );
+		foreach ( $errors as $error ) {
+			call_user_func_array( array( $this, 'showMessage' ), $error );
+		}
 	}
 
 	/**
 	 * Label a control by wrapping a config-input div around it and putting a
 	 * label before it.
+	 *
+	 * @param $msg
+	 * @param $forId
+	 * @param $contents
+	 * @param $helpData string
+	 * @return string
 	 */
 	public function label( $msg, $forId, $contents, $helpData = "" ) {
 		if ( strval( $msg ) == '' ) {
 			$labelText = '&#160;';
 		} else {
-			$labelText = wfMsgHtml( $msg );
+			$labelText = wfMessage( $msg )->escaped();
 		}
 
 		$attributes = array( 'class' => 'config-label' );
@@ -699,16 +747,16 @@ class WebInstaller extends Installer {
 			$attributes['for'] = $forId;
 		}
 
-		return
-			"<div class=\"config-block\">\n" .
+		return "<div class=\"config-block\">\n" .
 			"  <div class=\"config-block-label\">\n" .
 			Xml::tags( 'label',
 				$attributes,
-				$labelText ) . "\n" .
-				$helpData .
+				$labelText
+			) . "\n" .
+			$helpData .
 			"  </div>\n" .
 			"  <div class=\"config-block-elements\">\n" .
-				$contents .
+			$contents .
 			"  </div>\n" .
 			"</div>\n";
 	}
@@ -718,12 +766,14 @@ class WebInstaller extends Installer {
 	 *
 	 * @param $params Array
 	 *    Parameters are:
-	 *      var:        The variable to be configured (required)
-	 *      label:      The message name for the label (required)
-	 *      attribs:    Additional attributes for the input element (optional)
+	 *      var:         The variable to be configured (required)
+	 *      label:       The message name for the label (required)
+	 *      attribs:     Additional attributes for the input element (optional)
 	 *      controlName: The name for the input element (optional)
-	 *      value:      The current value of the variable (optional)
-	 *      help:		The html for the help text (optional)
+	 *      value:       The current value of the variable (optional)
+	 *      help:        The html for the help text (optional)
+	 *
+	 * @return string
 	 */
 	public function getTextBox( $params ) {
 		if ( !isset( $params['controlName'] ) ) {
@@ -740,22 +790,22 @@ class WebInstaller extends Installer {
 		if ( !isset( $params['help'] ) ) {
 			$params['help'] = "";
 		}
-		return
-			$this->label(
-				$params['label'],
+
+		return $this->label(
+			$params['label'],
+			$params['controlName'],
+			Xml::input(
 				$params['controlName'],
-				Xml::input(
-					$params['controlName'],
-					30, // intended to be overridden by CSS
-					$params['value'],
-					$params['attribs'] + array(
-						'id' => $params['controlName'],
-						'class' => 'config-input-text',
-						'tabindex' => $this->nextTabIndex()
-					)
-				),
-				$params['help']
-			);
+				30, // intended to be overridden by CSS
+				$params['value'],
+				$params['attribs'] + array(
+					'id' => $params['controlName'],
+					'class' => 'config-input-text',
+					'tabindex' => $this->nextTabIndex()
+				)
+			),
+			$params['help']
+		);
 	}
 
 	/**
@@ -763,12 +813,14 @@ class WebInstaller extends Installer {
 	 *
 	 * @param $params Array
 	 *    Parameters are:
-	 *      var:        The variable to be configured (required)
-	 *      label:      The message name for the label (required)
-	 *      attribs:    Additional attributes for the input element (optional)
+	 *      var:         The variable to be configured (required)
+	 *      label:       The message name for the label (required)
+	 *      attribs:     Additional attributes for the input element (optional)
 	 *      controlName: The name for the input element (optional)
-	 *      value:      The current value of the variable (optional)
-	 *      help:		The html for the help text (optional)
+	 *      value:       The current value of the variable (optional)
+	 *      help:        The html for the help text (optional)
+	 *
+	 * @return string
 	 */
 	public function getTextArea( $params ) {
 		if ( !isset( $params['controlName'] ) ) {
@@ -785,23 +837,23 @@ class WebInstaller extends Installer {
 		if ( !isset( $params['help'] ) ) {
 			$params['help'] = "";
 		}
-		return
-			$this->label(
-				$params['label'],
+
+		return $this->label(
+			$params['label'],
+			$params['controlName'],
+			Xml::textarea(
 				$params['controlName'],
-				Xml::textarea(
-					$params['controlName'],
-					$params['value'],
-					30,
-					5,
-					$params['attribs'] + array(
-						'id' => $params['controlName'],
-						'class' => 'config-input-text',
-						'tabindex' => $this->nextTabIndex()
-					)
-				),
-				$params['help']
-			);
+				$params['value'],
+				30,
+				5,
+				$params['attribs'] + array(
+					'id' => $params['controlName'],
+					'class' => 'config-input-text',
+					'tabindex' => $this->nextTabIndex()
+				)
+			),
+			$params['help']
+		);
 	}
 
 	/**
@@ -810,12 +862,14 @@ class WebInstaller extends Installer {
 	 * Implements password hiding
 	 * @param $params Array
 	 *    Parameters are:
-	 *      var:        The variable to be configured (required)
-	 *      label:      The message name for the label (required)
-	 *      attribs:    Additional attributes for the input element (optional)
+	 *      var:         The variable to be configured (required)
+	 *      label:       The message name for the label (required)
+	 *      attribs:     Additional attributes for the input element (optional)
 	 *      controlName: The name for the input element (optional)
-	 *      value:      The current value of the variable (optional)
-	 *      help:		The html for the help text (optional)
+	 *      value:       The current value of the variable (optional)
+	 *      help:        The html for the help text (optional)
+	 *
+	 * @return string
 	 */
 	public function getPasswordBox( $params ) {
 		if ( !isset( $params['value'] ) ) {
@@ -837,12 +891,14 @@ class WebInstaller extends Installer {
 	 *
 	 * @param $params Array
 	 *    Parameters are:
-	 *      var:        The variable to be configured (required)
-	 *      label:      The message name for the label (required)
-	 *      attribs:    Additional attributes for the input element (optional)
+	 *      var:         The variable to be configured (required)
+	 *      label:       The message name for the label (required)
+	 *      attribs:     Additional attributes for the input element (optional)
 	 *      controlName: The name for the input element (optional)
-	 *      value:      The current value of the variable (optional)
-	 *      help:		The html for the help text (optional)
+	 *      value:       The current value of the variable (optional)
+	 *      help:        The html for the help text (optional)
+	 *
+	 * @return string
 	 */
 	public function getCheckBox( $params ) {
 		if ( !isset( $params['controlName'] ) ) {
@@ -859,14 +915,15 @@ class WebInstaller extends Installer {
 		if ( !isset( $params['help'] ) ) {
 			$params['help'] = "";
 		}
-		if( isset( $params['rawtext'] ) ) {
+		if ( isset( $params['rawtext'] ) ) {
 			$labelText = $params['rawtext'];
+		} elseif ( isset( $params['label'] ) ) {
+			$labelText = $this->parse( wfMessage( $params['label'] )->text() );
 		} else {
-			$labelText = $this->parse( wfMsg( $params['label'] ) );
+			$labelText = "";
 		}
 
-		return
-			"<div class=\"config-input-check\">\n" .
+		return "<div class=\"config-input-check\">\n" .
 			$params['help'] .
 			"<label>\n" .
 			Xml::check(
@@ -887,18 +944,20 @@ class WebInstaller extends Installer {
 	 *
 	 * @param $params Array
 	 *    Parameters are:
-	 *      var:            The variable to be configured (required)
-	 *      label:          The message name for the label (required)
+	 *      var:             The variable to be configured (required)
+	 *      label:           The message name for the label (required)
 	 *      itemLabelPrefix: The message name prefix for the item labels (required)
-	 *      values:         List of allowed values (required)
-	 *      itemAttribs     Array of attribute arrays, outer key is the value name (optional)
-	 *      commonAttribs   Attribute array applied to all items
-	 *      controlName:    The name for the input element (optional)
-	 *      value:          The current value of the variable (optional)
-	 *      help:		The html for the help text (optional)
+	 *      values:          List of allowed values (required)
+	 *      itemAttribs:     Array of attribute arrays, outer key is the value name (optional)
+	 *      commonAttribs:   Attribute array applied to all items
+	 *      controlName:     The name for the input element (optional)
+	 *      value:           The current value of the variable (optional)
+	 *      help:            The html for the help text (optional)
+	 *
+	 * @return string
 	 */
 	public function getRadioSet( $params ) {
-		if ( !isset( $params['controlName']  ) ) {
+		if ( !isset( $params['controlName'] ) ) {
 			$params['controlName'] = 'config_' . $params['var'];
 		}
 
@@ -936,7 +995,7 @@ class WebInstaller extends Installer {
 				Xml::radio( $params['controlName'], $value, $checked, $itemAttribs ) .
 				'&#160;' .
 				Xml::tags( 'label', array( 'for' => $id ), $this->parse(
-					wfMsgNoTrans( $params['itemLabelPrefix'] . strtolower( $value ) )
+					wfMessage( $params['itemLabelPrefix'] . strtolower( $value ) )->plain()
 				) ) .
 				"</li>\n";
 		}
@@ -948,12 +1007,14 @@ class WebInstaller extends Installer {
 
 	/**
 	 * Output an error or warning box using a Status object.
+	 *
+	 * @param $status Status
 	 */
 	public function showStatusBox( $status ) {
-		if( !$status->isGood() ) {
+		if ( !$status->isGood() ) {
 			$text = $status->getWikiText();
 
-			if( $status->isOk() ) {
+			if ( $status->isOk() ) {
 				$box = $this->getWarningBox( $text );
 			} else {
 				$box = $this->getErrorBox( $text );
@@ -969,7 +1030,9 @@ class WebInstaller extends Installer {
 	 * fake) passwords.
 	 *
 	 * @param $varNames Array
-	 * @param $prefix String: the prefix added to variables to obtain form names
+	 * @param string $prefix the prefix added to variables to obtain form names
+	 *
+	 * @return array
 	 */
 	public function setVarsFromRequest( $varNames, $prefix = 'config_' ) {
 		$newValues = array();
@@ -995,6 +1058,9 @@ class WebInstaller extends Installer {
 
 	/**
 	 * Helper for Installer::docLink()
+	 *
+	 * @param $page
+	 * @return string
 	 */
 	protected function getDocUrl( $page ) {
 		$url = "{$_SERVER['PHP_SELF']}?page=" . urlencode( $page );
@@ -1008,19 +1074,29 @@ class WebInstaller extends Installer {
 
 	/**
 	 * Extension tag hook for a documentation link.
+	 *
+	 * @param $linkText
+	 * @param $attribs
+	 * @param $parser
+	 * @return string
 	 */
 	public function docLink( $linkText, $attribs, $parser ) {
 		$url = $this->getDocUrl( $attribs['href'] );
+
 		return '<a href="' . htmlspecialchars( $url ) . '">' .
 			htmlspecialchars( $linkText ) .
 			'</a>';
 	}
-	
+
 	/**
 	 * Helper for "Download LocalSettings" link on WebInstall_Complete
+	 *
+	 * @param $text
+	 * @param $attribs
+	 * @param $parser
 	 * @return String Html for download link
 	 */
-	public function downloadLinkHook( $text, $attribs, $parser  ) {
+	public function downloadLinkHook( $text, $attribs, $parser ) {
 		$img = Html::element( 'img', array(
 			'src' => '../skins/common/images/download-32.png',
 			'width' => '32',
@@ -1028,7 +1104,37 @@ class WebInstaller extends Installer {
 		) );
 		$anchor = Html::rawElement( 'a',
 			array( 'href' => $this->getURL( array( 'localsettings' => 1 ) ) ),
-			$img . ' ' . wfMsgHtml( 'config-download-localsettings' ) );
+			$img . ' ' . wfMessage( 'config-download-localsettings' )->parse() );
+
 		return Html::rawElement( 'div', array( 'class' => 'config-download-link' ), $anchor );
 	}
+
+	/**
+	 * @return bool
+	 */
+	public function envCheckPath() {
+		// PHP_SELF isn't available sometimes, such as when PHP is CGI but
+		// cgi.fix_pathinfo is disabled. In that case, fall back to SCRIPT_NAME
+		// to get the path to the current script... hopefully it's reliable. SIGH
+		$path = false;
+		if ( !empty( $_SERVER['PHP_SELF'] ) ) {
+			$path = $_SERVER['PHP_SELF'];
+		} elseif ( !empty( $_SERVER['SCRIPT_NAME'] ) ) {
+			$path = $_SERVER['SCRIPT_NAME'];
+		}
+		if ( $path !== false ) {
+			$uri = preg_replace( '{^(.*)/(mw-)?config.*$}', '$1', $path );
+			$this->setVar( 'wgScriptPath', $uri );
+		} else {
+			$this->showError( 'config-no-uri' );
+
+			return false;
+		}
+
+		return parent::envCheckPath();
+	}
+
+	protected function envGetDefaultServer() {
+		return WebRequest::detectServer();
+	}
 }
