@@ -1,17 +1,36 @@
 <?php
 /**
- * Handler for DjVu images
+ * Handler for DjVu images.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * http://www.gnu.org/copyleft/gpl.html
  *
  * @file
  * @ingroup Media
  */
- 
+
 /**
  * Handler for DjVu images
  *
  * @ingroup Media
  */
 class DjVuHandler extends ImageHandler {
+
+	/**
+	 * @return bool
+	 */
 	function isEnabled() {
 		global $wgDjvuRenderer, $wgDjvuDump, $wgDjvuToXML;
 		if ( !$wgDjvuRenderer || ( !$wgDjvuDump && !$wgDjvuToXML ) ) {
@@ -22,9 +41,25 @@ class DjVuHandler extends ImageHandler {
 		}
 	}
 
-	function mustRender( $file ) { return true; }
-	function isMultiPage( $file ) { return true; }
+	/**
+	 * @param $file
+	 * @return bool
+	 */
+	function mustRender( $file ) {
+		return true;
+	}
 
+	/**
+	 * @param $file
+	 * @return bool
+	 */
+	function isMultiPage( $file ) {
+		return true;
+	}
+
+	/**
+	 * @return array
+	 */
 	function getParamMap() {
 		return array(
 			'img_width' => 'width',
@@ -32,6 +67,11 @@ class DjVuHandler extends ImageHandler {
 		);
 	}
 
+	/**
+	 * @param $name
+	 * @param $value
+	 * @return bool
+	 */
 	function validateParam( $name, $value ) {
 		if ( in_array( $name, array( 'width', 'height', 'page' ) ) ) {
 			if ( $value <= 0 ) {
@@ -44,6 +84,10 @@ class DjVuHandler extends ImageHandler {
 		}
 	}
 
+	/**
+	 * @param $params
+	 * @return bool|string
+	 */
 	function makeParamString( $params ) {
 		$page = isset( $params['page'] ) ? $params['page'] : 1;
 		if ( !isset( $params['width'] ) ) {
@@ -52,6 +96,10 @@ class DjVuHandler extends ImageHandler {
 		return "page{$page}-{$params['width']}px";
 	}
 
+	/**
+	 * @param $str
+	 * @return array|bool
+	 */
 	function parseParamString( $str ) {
 		$m = false;
 		if ( preg_match( '/^page(\d+)-(\d+)px$/', $str, $m ) ) {
@@ -61,6 +109,10 @@ class DjVuHandler extends ImageHandler {
 		}
 	}
 
+	/**
+	 * @param $params
+	 * @return array
+	 */
 	function getScriptParams( $params ) {
 		return array(
 			'width' => $params['width'],
@@ -68,6 +120,14 @@ class DjVuHandler extends ImageHandler {
 		);
 	}
 
+	/**
+	 * @param $image File
+	 * @param  $dstPath
+	 * @param  $dstUrl
+	 * @param  $params
+	 * @param int $flags
+	 * @return MediaTransformError|ThumbnailImage|TransformParameterError
+	 */
 	function doTransform( $image, $dstPath, $dstUrl, $params, $flags = 0 ) {
 		global $wgDjvuRenderer, $wgDjvuPostProcessor;
 
@@ -75,8 +135,10 @@ class DjVuHandler extends ImageHandler {
 		// normaliseParams will inevitably give.
 		$xml = $image->getMetadata();
 		if ( !$xml ) {
-			return new MediaTransformError( 'thumbnail_error', @$params['width'], @$params['height'],
-				wfMsg( 'djvu_no_xml' ) );
+			$width = isset( $params['width'] ) ? $params['width'] : 0;
+			$height = isset( $params['height'] ) ? $params['height'] : 0;
+			return new MediaTransformError( 'thumbnail_error', $width, $height,
+				wfMessage( 'djvu_no_xml' )->text() );
 		}
 
 		if ( !$this->normaliseParams( $image, $params ) ) {
@@ -84,30 +146,49 @@ class DjVuHandler extends ImageHandler {
 		}
 		$width = $params['width'];
 		$height = $params['height'];
-		$srcPath = $image->getPath();
 		$page = $params['page'];
 		if ( $page > $this->pageCount( $image ) ) {
-			return new MediaTransformError( 'thumbnail_error', $width, $height, wfMsg( 'djvu_page_error' ) );
+			return new MediaTransformError(
+				'thumbnail_error',
+				$width,
+				$height,
+				wfMessage( 'djvu_page_error' )->text()
+			);
 		}
 
 		if ( $flags & self::TRANSFORM_LATER ) {
-			return new ThumbnailImage( $image, $dstUrl, $width, $height, $dstPath, $page );
+			$params = array(
+				'width' => $width,
+				'height' => $height,
+				'page' => $page
+			);
+			return new ThumbnailImage( $image, $dstUrl, $dstPath, $params );
 		}
 
-		if ( !wfMkdirParents( dirname( $dstPath ) ) ) {
-			return new MediaTransformError( 'thumbnail_error', $width, $height, wfMsg( 'thumbnail_dest_directory' ) );
+		if ( !wfMkdirParents( dirname( $dstPath ), null, __METHOD__ ) ) {
+			return new MediaTransformError(
+				'thumbnail_error',
+				$width,
+				$height,
+				wfMessage( 'thumbnail_dest_directory' )->text()
+			);
 		}
 
+		$srcPath = $image->getLocalRefPath();
 		# Use a subshell (brackets) to aggregate stderr from both pipeline commands
 		# before redirecting it to the overall stdout. This works in both Linux and Windows XP.
-		$cmd = '(' . wfEscapeShellArg( $wgDjvuRenderer ) . " -format=ppm -page={$page} -size={$width}x{$height} " .
-			wfEscapeShellArg( $srcPath );
+		$cmd = '(' . wfEscapeShellArg(
+			$wgDjvuRenderer,
+			"-format=ppm",
+			"-page={$page}",
+			"-size={$params['physicalWidth']}x{$params['physicalHeight']}",
+			$srcPath );
 		if ( $wgDjvuPostProcessor ) {
 			$cmd .= " | {$wgDjvuPostProcessor}";
 		}
-		$cmd .= ' > ' . wfEscapeShellArg($dstPath) . ') 2>&1';
+		$cmd .= ' > ' . wfEscapeShellArg( $dstPath ) . ') 2>&1';
 		wfProfileIn( 'ddjvu' );
-		wfDebug( __METHOD__.": $cmd\n" );
+		wfDebug( __METHOD__ . ": $cmd\n" );
 		$retval = '';
 		$err = wfShellExec( $cmd, $retval );
 		wfProfileOut( 'ddjvu' );
@@ -116,15 +197,22 @@ class DjVuHandler extends ImageHandler {
 		if ( $retval != 0 || $removed ) {
 			wfDebugLog( 'thumbnail',
 				sprintf( 'thumbnail failed on %s: error %d "%s" from "%s"',
-					wfHostname(), $retval, trim($err), $cmd ) );
+					wfHostname(), $retval, trim( $err ), $cmd ) );
 			return new MediaTransformError( 'thumbnail_error', $width, $height, $err );
 		} else {
-			return new ThumbnailImage( $image, $dstUrl, $width, $height, $dstPath, $page );
+			$params = array(
+				'width' => $width,
+				'height' => $height,
+				'page' => $page
+			);
+			return new ThumbnailImage( $image, $dstUrl, $dstPath, $params );
 		}
 	}
 
 	/**
 	 * Cache an instance of DjVuImage in an Image object, return that instance
+	 *
+	 * @return DjVuImage
 	 */
 	function getDjVuImage( $image, $path ) {
 		if ( !$image ) {
@@ -139,8 +227,11 @@ class DjVuHandler extends ImageHandler {
 
 	/**
 	 * Cache a document tree for the DjVu XML metadata
+	 * @param $image File
+	 * @param $gettext Boolean: DOCUMENT (Default: false)
+	 * @return bool
 	 */
-	function getMetaTree( $image , $gettext = false ) {
+	function getMetaTree( $image, $gettext = false ) {
 		if ( isset( $image->dejaMetaTree ) ) {
 			return $image->dejaMetaTree;
 		}
@@ -158,24 +249,23 @@ class DjVuHandler extends ImageHandler {
 			$image->dejaMetaTree = false;
 			$image->djvuTextTree = false;
 			$tree = new SimpleXMLElement( $metadata );
-			if( $tree->getName() == 'mw-djvu' ) {
-				foreach($tree->children() as $b){ 
-					if( $b->getName() == 'DjVuTxt' ) {
+			if ( $tree->getName() == 'mw-djvu' ) {
+				foreach ( $tree->children() as $b ) {
+					if ( $b->getName() == 'DjVuTxt' ) {
 						$image->djvuTextTree = $b;
-					}
-					else if ( $b->getName() == 'DjVuXML' ) {
+					} elseif ( $b->getName() == 'DjVuXML' ) {
 						$image->dejaMetaTree = $b;
 					}
 				}
 			} else {
 				$image->dejaMetaTree = $tree;
 			}
-		} catch( Exception $e ) {
-			wfDebug( "Bogus multipage XML metadata on '$image->name'\n" );
+		} catch ( Exception $e ) {
+			wfDebug( "Bogus multipage XML metadata on '{$image->getName()}'\n" );
 		}
 		wfRestoreWarnings();
 		wfProfileOut( __METHOD__ );
-		if( $gettext ) {
+		if ( $gettext ) {
 			return $image->djvuTextTree;
 		} else {
 			return $image->dejaMetaTree;
@@ -206,7 +296,7 @@ class DjVuHandler extends ImageHandler {
 	}
 
 	function isMetadataValid( $image, $metadata ) {
-		return !empty( $metadata ) && $metadata != serialize(array());
+		return !empty( $metadata ) && $metadata != serialize( array() );
 	}
 
 	function pageCount( $image ) {
@@ -223,7 +313,7 @@ class DjVuHandler extends ImageHandler {
 			return false;
 		}
 
-		$o = $tree->BODY[0]->OBJECT[$page-1];
+		$o = $tree->BODY[0]->OBJECT[$page - 1];
 		if ( $o ) {
 			return array(
 				'width' => intval( $o['width'] ),
@@ -234,13 +324,13 @@ class DjVuHandler extends ImageHandler {
 		}
 	}
 
-	function getPageText( $image, $page ){
+	function getPageText( $image, $page ) {
 		$tree = $this->getMetaTree( $image, true );
 		if ( !$tree ) {
 			return false;
 		}
 
-		$o = $tree->BODY[0]->PAGE[$page-1];
+		$o = $tree->BODY[0]->PAGE[$page - 1];
 		if ( $o ) {
 			$txt = $o['value'];
 			return $txt;
