@@ -78,14 +78,16 @@ abstract class MediaHandler {
 	/**
 	 * Merge a parameter array into a string appropriate for inclusion in filenames
 	 *
-	 * @param $params array
+	 * @param $params array Array of parameters that have been through normaliseParams.
+	 * @return String
 	 */
 	abstract function makeParamString( $params );
 
 	/**
 	 * Parse a param string made with makeParamString back into an array
 	 *
-	 * @param $str string
+	 * @param $str string The parameter string without file name (e.g. 122px)
+	 * @return Array|Boolean Array of parameters or false on failure.
 	 */
 	abstract function parseParamString( $str );
 
@@ -116,7 +118,9 @@ abstract class MediaHandler {
 	 * @param string $path the filename
 	 * @return String
 	 */
-	function getMetadata( $image, $path ) { return ''; }
+	function getMetadata( $image, $path ) {
+		return '';
+	}
 
 	/**
 	 * Get metadata version.
@@ -133,10 +137,10 @@ abstract class MediaHandler {
 	 *
 	 * @return string version string
 	 */
-	static function getMetadataVersion () {
+	static function getMetadataVersion() {
 		$version = Array( '2' ); // core metadata version
 		wfRunHooks( 'GetMetadataVersion', Array( &$version ) );
-		return implode( ';', $version);
+		return implode( ';', $version );
 	}
 
 	/**
@@ -166,7 +170,9 @@ abstract class MediaHandler {
 	 *
 	 * @return string
 	 */
-	function getMetadataType( $image ) { return false; }
+	function getMetadataType( $image ) {
+		return false;
+	}
 
 	/**
 	 * Check if the metadata string is valid for this handler.
@@ -216,6 +222,7 @@ abstract class MediaHandler {
 	 * @param string $dstPath filesystem destination path
 	 * @param string $dstUrl destination URL to use in output HTML
 	 * @param array $params arbitrary set of parameters validated by $this->validateParam()
+	 *   Note: These parameters have *not* gone through $this->normaliseParams()
 	 * @param $flags Integer: a bitfield, may contain self::TRANSFORM_LATER
 	 *
 	 * @return MediaTransformOutput
@@ -224,6 +231,10 @@ abstract class MediaHandler {
 
 	/**
 	 * Get the thumbnail extension and MIME type for a given source MIME type
+	 *
+	 * @param String $ext Extension of original file
+	 * @param String $mime Mime type of original file
+	 * @param Array $params Handler specific rendering parameters
 	 * @return array thumbnail extension and MIME type
 	 */
 	function getThumbType( $ext, $mime, $params = null ) {
@@ -255,63 +266,96 @@ abstract class MediaHandler {
 	 * True if the handled types can be transformed
 	 * @return bool
 	 */
-	function canRender( $file ) { return true; }
+	function canRender( $file ) {
+		return true;
+	}
+
 	/**
 	 * True if handled types cannot be displayed directly in a browser
 	 * but can be rendered
 	 * @return bool
 	 */
-	function mustRender( $file ) { return false; }
+	function mustRender( $file ) {
+		return false;
+	}
+
 	/**
 	 * True if the type has multi-page capabilities
 	 * @return bool
 	 */
-	function isMultiPage( $file ) { return false; }
+	function isMultiPage( $file ) {
+		return false;
+	}
+
 	/**
 	 * Page count for a multi-page document, false if unsupported or unknown
 	 * @return bool
 	 */
-	function pageCount( $file ) { return false; }
+	function pageCount( $file ) {
+		return false;
+	}
+
 	/**
 	 * The material is vectorized and thus scaling is lossless
 	 * @return bool
 	 */
-	function isVectorized( $file ) { return false; }
+	function isVectorized( $file ) {
+		return false;
+	}
+
 	/**
 	 * The material is an image, and is animated.
 	 * In particular, video material need not return true.
 	 * @note Before 1.20, this was a method of ImageHandler only
 	 * @return bool
 	 */
-	function isAnimatedImage( $file ) { return false; }
+	function isAnimatedImage( $file ) {
+		return false;
+	}
+
 	/**
 	 * If the material is animated, we can animate the thumbnail
 	 * @since 1.20
 	 * @return bool If material is not animated, handler may return any value.
 	 */
-	function canAnimateThumbnail( $file ) { return true; }
+	function canAnimateThumbnail( $file ) {
+		return true;
+	}
+
 	/**
 	 * False if the handler is disabled for all files
 	 * @return bool
 	 */
-	function isEnabled() { return true; }
+	function isEnabled() {
+		return true;
+	}
 
 	/**
 	 * Get an associative array of page dimensions
 	 * Currently "width" and "height" are understood, but this might be
 	 * expanded in the future.
-	 * Returns false if unknown or if the document is not multi-page.
+	 * Returns false if unknown.
+	 *
+	 * It is expected that handlers for paged media (e.g. DjVuHandler)
+	 * will override this method so that it gives the correct results
+	 * for each specific page of the file, using the $page argument.
+	 *
+	 * @note For non-paged media, use getImageSize.
 	 *
 	 * @param $image File
-	 * @param $page Unused, left for backcompatibility?
-	 * @return array
+	 * @param $page What page to get dimensions of
+	 * @return array|bool
 	 */
 	function getPageDimensions( $image, $page ) {
 		$gis = $this->getImageSize( $image, $image->getLocalRefPath() );
-		return array(
-			'width' => $gis[0],
-			'height' => $gis[1]
-		);
+		if ( $gis ) {
+			return array(
+				'width' => $gis[0],
+				'height' => $gis[1]
+			);
+		} else {
+			return false;
+		}
 	}
 
 	/**
@@ -394,9 +438,9 @@ abstract class MediaHandler {
 	function visibleMetadataFields() {
 		$fields = array();
 		$lines = explode( "\n", wfMessage( 'metadata-fields' )->inContentLanguage()->text() );
-		foreach( $lines as $line ) {
+		foreach ( $lines as $line ) {
 			$matches = array();
-			if( preg_match( '/^\\*\s*(.*?)\s*$/', $line, $matches ) ) {
+			if ( preg_match( '/^\\*\s*(.*?)\s*$/', $line, $matches ) ) {
 				$fields[] = $matches[1];
 			}
 		}
@@ -448,6 +492,8 @@ abstract class MediaHandler {
 	}
 
 	/**
+	 * Used instead of getLongDesc if there is no handler registered for file.
+	 *
 	 * @param $file File
 	 * @return string
 	 */
@@ -457,6 +503,8 @@ abstract class MediaHandler {
 	}
 
 	/**
+	 * Short description. Shown on Special:Search results.
+	 *
 	 * @param $file File
 	 * @return string
 	 */
@@ -467,6 +515,8 @@ abstract class MediaHandler {
 	}
 
 	/**
+	 * Long description. Shown under image on image description page surounded by ().
+	 *
 	 * @param $file File
 	 * @return string
 	 */
@@ -476,6 +526,8 @@ abstract class MediaHandler {
 	}
 
 	/**
+	 * Used instead of getShortDesc if there is no handler registered for file.
+	 *
 	 * @param $file File
 	 * @return string
 	 */
@@ -496,19 +548,32 @@ abstract class MediaHandler {
 	public static function fitBoxWidth( $boxWidth, $boxHeight, $maxHeight ) {
 		$idealWidth = $boxWidth * $maxHeight / $boxHeight;
 		$roundedUp = ceil( $idealWidth );
-		if( round( $roundedUp * $boxHeight / $boxWidth ) > $maxHeight ) {
+		if ( round( $roundedUp * $boxHeight / $boxWidth ) > $maxHeight ) {
 			return floor( $idealWidth );
 		} else {
 			return $roundedUp;
 		}
 	}
 
+	/**
+	 * Shown in file history box on image description page.
+	 *
+	 * @param File $file
+	 * @return String Dimensions
+	 */
 	function getDimensionsString( $file ) {
 		return '';
 	}
 
 	/**
-	 * Modify the parser object post-transform
+	 * Modify the parser object post-transform.
+	 *
+	 * This is often used to do $parser->addOutputHook(),
+	 * in order to add some javascript to render a viewer.
+	 * See TimedMediaHandler or OggHandler for an example.
+	 *
+	 * @param Parser $parser
+	 * @param File $file
 	 */
 	function parserTransformHook( $parser, $file ) {}
 
@@ -535,9 +600,9 @@ abstract class MediaHandler {
 	 * @return bool True if removed, false otherwise
 	 */
 	function removeBadFile( $dstPath, $retval = 0 ) {
-		if( file_exists( $dstPath ) ) {
+		if ( file_exists( $dstPath ) ) {
 			$thumbstat = stat( $dstPath );
-			if( $thumbstat['size'] == 0 || $retval != 0 ) {
+			if ( $thumbstat['size'] == 0 || $retval != 0 ) {
 				$result = unlink( $dstPath );
 
 				if ( $result ) {
@@ -556,10 +621,17 @@ abstract class MediaHandler {
 	}
 
 	/**
-	 * Remove files from the purge list
+	 * Remove files from the purge list.
+	 *
+	 * This is used by some video handlers to prevent ?action=purge
+	 * from removing a transcoded video, which is expensive to
+	 * regenerate.
+	 *
+	 * @see LocalFile::purgeThumbnails
 	 *
 	 * @param array $files
-	 * @param array $options
+	 * @param array $options Purge options. Currently will always be
+	 *  an array with a single key 'forThumbRefresh' set to true.
 	 */
 	public function filterThumbnailPurgeList( &$files, $options ) {
 		// Do nothing
@@ -573,4 +645,23 @@ abstract class MediaHandler {
 	public static function canRotate() {
 		return false;
 	}
+
+	/**
+	 * On supporting image formats, try to read out the low-level orientation
+	 * of the file and return the angle that the file needs to be rotated to
+	 * be viewed.
+	 *
+	 * This information is only useful when manipulating the original file;
+	 * the width and height we normally work with is logical, and will match
+	 * any produced output views.
+	 *
+	 * For files we don't know, we return 0.
+	 *
+	 * @param $file File
+	 * @return int 0, 90, 180 or 270
+	 */
+	public function getRotation( $file ) {
+		return 0;
+	}
+
 }
