@@ -39,4 +39,6 @@ class ProfilerStub extends Profiler {
 	public function close() {}
 	public function logData() {}
 	public function getCurrentSection() { return ''; }
+	public function transactionWritingIn( $server, $db ) {}
+	public function transactionWritingOut( $server, $db ) {}
 }
