@@ -56,7 +56,9 @@ class ResourceLoaderUserOptionsModule extends ResourceLoaderModule {
 	public function getScript( ResourceLoaderContext $context ) {
 		global $wgUser;
 		return Xml::encodeJsCall( 'mw.user.options.set',
-			array( $wgUser->getOptions() ) );
+			array( $wgUser->getOptions() ),
+			ResourceLoader::inDebugMode()
+		);
 	}
 
 	/**
