@@ -2,6 +2,21 @@
 /**
  * Basic search engine
  *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * http://www.gnu.org/copyleft/gpl.html
+ *
  * @file
  * @ingroup Search
  */
@@ -22,7 +37,15 @@ class SearchEngine {
 	var $namespaces = array( NS_MAIN );
 	var $showRedirects = false;
 
-	function __construct($db = null) {
+	/// Feature values
+	protected $features = array();
+
+	/**
+	 * @var DatabaseBase
+	 */
+	protected $db;
+
+	function __construct( $db = null ) {
 		if ( $db ) {
 			$this->db = $db;
 		} else {
@@ -35,8 +58,8 @@ class SearchEngine {
 	 * If title searches are not supported or disabled, return null.
 	 * STUB
 	 *
-	 * @param $term String: raw search term
-	 * @return SearchResultSet
+	 * @param string $term raw search term
+	 * @return SearchResultSet|Status|null
 	 */
 	function searchText( $term ) {
 		return null;
@@ -47,16 +70,48 @@ class SearchEngine {
 	 * If title searches are not supported or disabled, return null.
 	 * STUB
 	 *
-	 * @param $term String: raw search term
-	 * @return SearchResultSet
+	 * @param string $term raw search term
+	 * @return SearchResultSet|null
 	 */
 	function searchTitle( $term ) {
 		return null;
 	}
 
-	/** If this search backend can list/unlist redirects */
+	/**
+	 * If this search backend can list/unlist redirects
+	 * @deprecated since 1.18 Call supports( 'list-redirects' );
+	 * @return bool
+	 */
 	function acceptListRedirects() {
-		return true;
+		wfDeprecated( __METHOD__, '1.18' );
+		return $this->supports( 'list-redirects' );
+	}
+
+	/**
+	 * @since 1.18
+	 * @param $feature String
+	 * @return Boolean
+	 */
+	public function supports( $feature ) {
+		switch ( $feature ) {
+		case 'list-redirects':
+		case 'search-update':
+			return true;
+		case 'title-suffix-filter':
+		default:
+			return false;
+		}
+	}
+
+	/**
+	 * Way to pass custom data for engines
+	 * @since 1.18
+	 * @param $feature String
+	 * @param $data Mixed
+	 * @return bool
+	 */
+	public function setFeatureData( $feature, $data ) {
+		$this->features[$feature] = $data;
 	}
 
 	/**
@@ -64,7 +119,7 @@ class SearchEngine {
 	 * on text to be used for searching or updating search index.
 	 * Default implementation does nothing (simply returns $string).
 	 *
-	 * @param $string string: String to process
+	 * @param string $string String to process
 	 * @return string
 	 */
 	public function normalizeText( $string ) {
@@ -95,11 +150,11 @@ class SearchEngine {
 		wfRunHooks( 'SearchGetNearMatchComplete', array( $searchterm, &$title ) );
 		return $title;
 	}
-	
+
 	/**
-	 * Do a near match (see SearchEngine::getNearMatch) and wrap it into a 
+	 * Do a near match (see SearchEngine::getNearMatch) and wrap it into a
 	 * SearchResultSet.
-	 * 
+	 *
 	 * @param $searchterm string
 	 * @return SearchResultSet
 	 */
@@ -109,9 +164,10 @@ class SearchEngine {
 
 	/**
 	 * Really find the title match.
+	 * @return null|Title
 	 */
 	private static function getNearMatchInternal( $searchterm ) {
-		global $wgContLang;
+		global $wgContLang, $wgEnableSearchContributorsByIP;
 
 		$allSearchTerms = array( $searchterm );
 
@@ -128,35 +184,42 @@ class SearchEngine {
 
 			# Exact match? No need to look further.
 			$title = Title::newFromText( $term );
-			if ( is_null( $title ) )
+			if ( is_null( $title ) ) {
 				return null;
+			}
 
-			if ( $title->getNamespace() == NS_SPECIAL || $title->isExternal() || $title->exists() ) {
+			# Try files if searching in the Media: namespace
+			if ( $title->getNamespace() == NS_MEDIA ) {
+				$title = Title::makeTitle( NS_FILE, $title->getText() );
+			}
+
+			if ( $title->isSpecialPage() || $title->isExternal() || $title->exists() ) {
 				return $title;
 			}
 
 			# See if it still otherwise has content is some sane sense
-			$article = MediaWiki::articleFromTitle( $title );
-			if ( $article->hasViewableContent() ) {
+			$page = WikiPage::factory( $title );
+			if ( $page->hasViewableContent() ) {
+				return $title;
+			}
+
+			if ( !wfRunHooks( 'SearchAfterNoDirectMatch', array( $term, &$title ) ) ) {
 				return $title;
 			}
 
 			# Now try all lower case (i.e. first letter capitalized)
-			#
 			$title = Title::newFromText( $wgContLang->lc( $term ) );
 			if ( $title && $title->exists() ) {
 				return $title;
 			}
 
 			# Now try capitalized string
-			#
 			$title = Title::newFromText( $wgContLang->ucwords( $term ) );
 			if ( $title && $title->exists() ) {
 				return $title;
 			}
 
 			# Now try all upper case
-			#
 			$title = Title::newFromText( $wgContLang->uc( $term ) );
 			if ( $title && $title->exists() ) {
 				return $title;
@@ -178,12 +241,13 @@ class SearchEngine {
 		$title = Title::newFromText( $searchterm );
 
 		# Entering an IP address goes to the contributions page
-		if ( ( $title->getNamespace() == NS_USER && User::isIP( $title->getText() ) )
-			|| User::isIP( trim( $searchterm ) ) ) {
-			return SpecialPage::getTitleFor( 'Contributions', $title->getDBkey() );
+		if ( $wgEnableSearchContributorsByIP ) {
+			if ( ( $title->getNamespace() == NS_USER && User::isIP( $title->getText() ) )
+				|| User::isIP( trim( $searchterm ) ) ) {
+				return SpecialPage::getTitleFor( 'Contributions', $title->getDBkey() );
+			}
 		}
 
-
 		# Entering a user goes to the user page whether it's there or not
 		if ( $title->getNamespace() == NS_USER ) {
 			return $title;
@@ -245,6 +309,7 @@ class SearchEngine {
 	 * or namespace names
 	 *
 	 * @param $query String
+	 * @return string
 	 */
 	function replacePrefixes( $query ) {
 		global $wgContLang;
@@ -255,11 +320,11 @@ class SearchEngine {
 			return $parsed;
 		}
 
-		$allkeyword = wfMsgForContent( 'searchall' ) . ":";
+		$allkeyword = wfMessage( 'searchall' )->inContentLanguage()->text() . ":";
 		if ( strncmp( $query, $allkeyword, strlen( $allkeyword ) ) == 0 ) {
 			$this->namespaces = null;
 			$parsed = substr( $query, strlen( $allkeyword ) );
-		} else if ( strpos( $query, ':' ) !== false ) {
+		} elseif ( strpos( $query, ':' ) !== false ) {
 			$prefix = substr( $query, 0, strpos( $query, ':' ) );
 			$index = $wgContLang->getNsIndex( $prefix );
 			if ( $index !== false ) {
@@ -267,8 +332,9 @@ class SearchEngine {
 				$parsed = substr( $query, strlen( $prefix ) + 1 );
 			}
 		}
-		if ( trim( $parsed ) == '' )
+		if ( trim( $parsed ) == '' ) {
 			$parsed = $query; // prefix was the whole query
+		}
 
 		wfRunHooks( 'SearchEngineReplacePrefixesComplete', array( $this, $query, &$parsed ) );
 
@@ -302,33 +368,32 @@ class SearchEngine {
 	public static function userNamespaces( $user ) {
 		global $wgSearchEverythingOnlyLoggedIn;
 
-		// get search everything preference, that can be set to be read for logged-in users
-		$searcheverything = false;
-		if ( ( $wgSearchEverythingOnlyLoggedIn && $user->isLoggedIn() )
-		    || !$wgSearchEverythingOnlyLoggedIn )
-			$searcheverything = $user->getOption( 'searcheverything' );
-
-		// searcheverything overrides other options
-		if ( $searcheverything )
-			return array_keys( SearchEngine::searchableNamespaces() );
-
-		$arr = Preferences::loadOldSearchNs( $user );
 		$searchableNamespaces = SearchEngine::searchableNamespaces();
 
-		$arr = array_intersect( $arr, array_keys( $searchableNamespaces ) ); // Filter
+		// get search everything preference, that can be set to be read for logged-in users
+		// it overrides other options
+		if ( !$wgSearchEverythingOnlyLoggedIn || $user->isLoggedIn() ) {
+			if ( $user->getOption( 'searcheverything' ) ) {
+				return array_keys( $searchableNamespaces );
+			}
+		}
+
+		$arr = array();
+		foreach ( $searchableNamespaces as $ns => $name ) {
+			if ( $user->getOption( 'searchNs' . $ns ) ) {
+				$arr[] = $ns;
+			}
+		}
 
 		return $arr;
 	}
 
 	/**
-	 * Find snippet highlight settings for a given user
+	 * Find snippet highlight settings for all users
 	 *
-	 * @param $user User
 	 * @return Array contextlines, contextchars
 	 */
-	public static function userHighlightPrefs( &$user ) {
-		// $contextlines = $user->getOption( 'contextlines',  5 );
-		// $contextchars = $user->getOption( 'contextchars', 50 );
+	public static function userHighlightPrefs() {
 		$contextlines = 2; // Hardcode this. Old defaults sucked. :)
 		$contextchars = 75; // same as above.... :P
 		return array( $contextlines, $contextchars );
@@ -350,14 +415,16 @@ class SearchEngine {
 	 * and preferences
 	 *
 	 * @param $namespaces Array
+	 * @return array
 	 */
 	public static function namespacesAsText( $namespaces ) {
 		global $wgContLang;
 
 		$formatted = array_map( array( $wgContLang, 'getFormattedNsText' ), $namespaces );
 		foreach ( $formatted as $key => $ns ) {
-			if ( empty( $ns ) )
-				$formatted[$key] = wfMsg( 'blanknamespace' );
+			if ( empty( $ns ) ) {
+				$formatted[$key] = wfMessage( 'blanknamespace' )->text();
+			}
 		}
 		return $formatted;
 	}
@@ -387,22 +454,45 @@ class SearchEngine {
 	 * Load up the appropriate search engine class for the currently
 	 * active database backend, and return a configured instance.
 	 *
+	 * @param String $type Type of search backend, if not the default
 	 * @return SearchEngine
 	 */
-	public static function create() {
+	public static function create( $type = null ) {
 		global $wgSearchType;
 		$dbr = null;
-		if ( $wgSearchType ) {
+
+		$alternatives = self::getSearchTypes();
+
+		if ( $type && in_array( $type, $alternatives ) ) {
+			$class = $type;
+		} elseif ( $wgSearchType !== null ) {
 			$class = $wgSearchType;
 		} else {
 			$dbr = wfGetDB( DB_SLAVE );
 			$class = $dbr->getSearchEngine();
 		}
+
 		$search = new $class( $dbr );
 		$search->setLimitOffset( 0, 0 );
 		return $search;
 	}
 
+	/**
+	 * Return the search engines we support. If only $wgSearchType
+	 * is set, it'll be an array of just that one item.
+	 *
+	 * @return array
+	 */
+	public static function getSearchTypes() {
+		global $wgSearchType, $wgSearchTypeAlternatives;
+		static $alternatives = null;
+		if ( $alternatives === null ) {
+			$alternatives = $wgSearchTypeAlternatives ?: array();
+			array_unshift( $alternatives, $wgSearchType );
+		}
+		return $alternatives;
+	}
+
 	/**
 	 * Create or update the search index record for the given page.
 	 * Title and text should be pre-processed.
@@ -428,33 +518,59 @@ class SearchEngine {
 		// no-op
 	}
 
+	/**
+	 * Delete an indexed page
+	 * Title should be pre-processed.
+	 * STUB
+	 *
+	 * @param Integer $id Page id that was deleted
+	 * @param String $title Title of page that was deleted
+	 */
+	function delete( $id, $title ) {
+		// no-op
+	}
+
 	/**
 	 * Get OpenSearch suggestion template
 	 *
 	 * @return String
 	 */
 	public static function getOpenSearchTemplate() {
-		global $wgOpenSearchTemplate, $wgServer;
-		if ( $wgOpenSearchTemplate )	{
+		global $wgOpenSearchTemplate, $wgCanonicalServer;
+		if ( $wgOpenSearchTemplate ) {
 			return $wgOpenSearchTemplate;
 		} else {
 			$ns = implode( '|', SearchEngine::defaultNamespaces() );
-			if ( !$ns ) $ns = "0";
-			return $wgServer . wfScript( 'api' ) . '?action=opensearch&search={searchTerms}&namespace=' . $ns;
+			if ( !$ns ) {
+				$ns = "0";
+			}
+			return $wgCanonicalServer . wfScript( 'api' ) . '?action=opensearch&search={searchTerms}&namespace=' . $ns;
 		}
 	}
 
 	/**
-	 * Get internal MediaWiki Suggest template
+	 * Get the raw text for updating the index from a content object
+	 * Nicer search backends could possibly do something cooler than
+	 * just returning raw text
 	 *
-	 * @return String
+	 * @todo This isn't ideal, we'd really like to have content-specific handling here
+	 * @param Title $t Title we're indexing
+	 * @param Content $c Content of the page to index
+	 * @return string
 	 */
-	public static function getMWSuggestTemplate() {
-		global $wgMWSuggestTemplate, $wgServer;
-		if ( $wgMWSuggestTemplate )
-			return $wgMWSuggestTemplate;
-		else
-			return $wgServer . wfScript( 'api' ) . '?action=opensearch&search={searchTerms}&namespace={namespaces}&suggest';
+	public function getTextFromContent( Title $t, Content $c = null ) {
+		return $c ? $c->getTextForSearchIndex() : '';
+	}
+
+	/**
+	 * If an implementation of SearchEngine handles all of its own text processing
+	 * in getTextFromContent() and doesn't require SearchUpdate::updateText()'s
+	 * rather silly handling, it should return true here instead.
+	 *
+	 * @return bool
+	 */
+	public function textAlreadyUpdatedForIndex() {
+		return false;
 	}
 }
 
@@ -575,6 +691,9 @@ class SearchResultSet {
  * This class is used for different SQL-based search engines shipped with MediaWiki
  */
 class SqlSearchResultSet extends SearchResultSet {
+
+	protected $mResultSet;
+
 	function __construct( $resultSet, $terms ) {
 		$this->mResultSet = $resultSet;
 		$this->mTerms = $terms;
@@ -585,26 +704,30 @@ class SqlSearchResultSet extends SearchResultSet {
 	}
 
 	function numRows() {
-		if ( $this->mResultSet === false )
+		if ( $this->mResultSet === false ) {
 			return false;
+		}
 
 		return $this->mResultSet->numRows();
 	}
 
 	function next() {
-		if ( $this->mResultSet === false )
+		if ( $this->mResultSet === false ) {
 			return false;
+		}
 
 		$row = $this->mResultSet->fetchObject();
-		if ( $row === false )
+		if ( $row === false ) {
 			return false;
-			
+		}
+
 		return SearchResult::newFromRow( $row );
 	}
 
 	function free() {
-		if ( $this->mResultSet === false )
+		if ( $this->mResultSet === false ) {
 			return false;
+		}
 
 		$this->mResultSet->free();
 	}
@@ -617,21 +740,34 @@ class SearchResultTooMany {
 	# # Some search engines may bail out if too many matches are found
 }
 
-
 /**
- * @todo Fixme: This class is horribly factored. It would probably be better to
+ * @todo FIXME: This class is horribly factored. It would probably be better to
  * have a useful base class to which you pass some standard information, then
  * let the fancy self-highlighters extend that.
  * @ingroup Search
  */
 class SearchResult {
+
+	/**
+	 * @var Revision
+	 */
 	var $mRevision = null;
 	var $mImage = null;
 
+	/**
+	 * @var Title
+	 */
+	var $mTitle;
+
+	/**
+	 * @var String
+	 */
+	var $mText;
+
 	/**
 	 * Return a new SearchResult and initializes it with a title.
-	 * 
-	 * @param $title Title 
+	 *
+	 * @param $title Title
 	 * @return SearchResult
 	 */
 	public static function newFromTitle( $title ) {
@@ -641,7 +777,7 @@ class SearchResult {
 	}
 	/**
 	 * Return a new SearchResult and initializes it with a row.
-	 * 
+	 *
 	 * @param $row object
 	 * @return SearchResult
 	 */
@@ -650,36 +786,40 @@ class SearchResult {
 		$result->initFromRow( $row );
 		return $result;
 	}
-	
+
 	public function __construct( $row = null ) {
 		if ( !is_null( $row ) ) {
 			// Backwards compatibility with pre-1.17 callers
 			$this->initFromRow( $row );
 		}
 	}
-	
+
 	/**
 	 * Initialize from a database row. Makes a Title and passes that to
 	 * initFromTitle.
-	 * 
+	 *
 	 * @param $row object
 	 */
 	protected function initFromRow( $row ) {
 		$this->initFromTitle( Title::makeTitle( $row->page_namespace, $row->page_title ) );
 	}
-	
+
 	/**
 	 * Initialize from a Title and if possible initializes a corresponding
 	 * Revision and File.
-	 * 
+	 *
 	 * @param $title Title
 	 */
 	protected function initFromTitle( $title ) {
 		$this->mTitle = $title;
 		if ( !is_null( $this->mTitle ) ) {
-			$this->mRevision = Revision::newFromTitle( $this->mTitle );
-			if ( $this->mTitle->getNamespace() === NS_FILE )
+			$id = false;
+			wfRunHooks( 'SearchResultInitFromTitle', array( $title, &$id ) );
+			$this->mRevision = Revision::newFromTitle(
+				$this->mTitle, $id, Revision::READ_NORMAL );
+			if ( $this->mTitle->getNamespace() === NS_FILE ) {
 				$this->mImage = wfFindFile( $this->mTitle );
+			}
 		}
 	}
 
@@ -689,8 +829,9 @@ class SearchResult {
 	 * @return Boolean
 	 */
 	function isBrokenTitle() {
-		if ( is_null( $this->mTitle ) )
+		if ( is_null( $this->mTitle ) ) {
 			return true;
+		}
 		return false;
 	}
 
@@ -711,7 +852,7 @@ class SearchResult {
 	}
 
 	/**
-	 * @return Double or null if not supported
+	 * @return float|null if not supported
 	 */
 	function getScore() {
 		return null;
@@ -722,31 +863,35 @@ class SearchResult {
 	 */
 	protected function initText() {
 		if ( !isset( $this->mText ) ) {
-			if ( $this->mRevision != null )
-				$this->mText = $this->mRevision->getText();
-			else // TODO: can we fetch raw wikitext for commons images?
+			if ( $this->mRevision != null ) {
+				$this->mText = SearchEngine::create()
+					->getTextFromContent( $this->mTitle, $this->mRevision->getContent() );
+			} else { // TODO: can we fetch raw wikitext for commons images?
 				$this->mText = '';
-
+			}
 		}
 	}
 
 	/**
-	 * @param $terms Array: terms to highlight
+	 * @param array $terms terms to highlight
 	 * @return String: highlighted text snippet, null (and not '') if not supported
 	 */
 	function getTextSnippet( $terms ) {
-		global $wgUser, $wgAdvancedSearchHighlighting;
+		global $wgAdvancedSearchHighlighting;
 		$this->initText();
-		list( $contextlines, $contextchars ) = SearchEngine::userHighlightPrefs( $wgUser );
+
+		// TODO: make highliter take a content object. Make ContentHandler a factory for SearchHighliter.
+		list( $contextlines, $contextchars ) = SearchEngine::userHighlightPrefs();
 		$h = new SearchHighlighter();
-		if ( $wgAdvancedSearchHighlighting )
+		if ( $wgAdvancedSearchHighlighting ) {
 			return $h->highlightText( $this->mText, $terms, $contextlines, $contextchars );
-		else
+		} else {
 			return $h->highlightSimple( $this->mText, $terms, $contextlines, $contextchars );
+		}
 	}
 
 	/**
-	 * @param $terms Array: terms to highlight
+	 * @param array $terms terms to highlight
 	 * @return String: highlighted title, '' if not supported
 	 */
 	function getTitleSnippet( $terms ) {
@@ -754,7 +899,7 @@ class SearchResult {
 	}
 
 	/**
-	 * @param $terms Array: terms to highlight
+	 * @param array $terms terms to highlight
 	 * @return String: highlighted redirect name (redirect to this page), '' if none or not supported
 	 */
 	function getRedirectSnippet( $terms ) {
@@ -786,10 +931,11 @@ class SearchResult {
 	 * @return String: timestamp
 	 */
 	function getTimestamp() {
-		if ( $this->mRevision )
+		if ( $this->mRevision ) {
 			return $this->mRevision->getTimestamp();
-		else if ( $this->mImage )
+		} elseif ( $this->mImage ) {
 			return $this->mImage->getTimestamp();
+		}
 		return '';
 	}
 
@@ -865,7 +1011,7 @@ class SearchHighlighter {
 	 * Default implementation of wikitext highlighting
 	 *
 	 * @param $text String
-	 * @param $terms Array: terms to highlight (unescaped)
+	 * @param array $terms terms to highlight (unescaped)
 	 * @param $contextlines Integer
 	 * @param $contextchars Integer
 	 * @return String
@@ -875,8 +1021,9 @@ class SearchHighlighter {
 		global $wgSearchHighlightBoundaries;
 		$fname = __METHOD__;
 
-		if ( $text == '' )
+		if ( $text == '' ) {
 			return '';
+		}
 
 		// spli text into text + templates/links/tables
 		$spat = "/(\\{\\{)|(\\[\\[[^\\]:]+:)|(\n\\{\\|)";
@@ -886,14 +1033,14 @@ class SearchHighlighter {
 			2 => '/(\[\[)|(\]\])/', // image
 			3 => "/(\n\\{\\|)|(\n\\|\\})/" ); // table
 
-		// FIXME: this should prolly be a hook or something
+		// @todo FIXME: This should prolly be a hook or something
 		if ( function_exists( 'wfCite' ) ) {
 			$spat .= '|(<ref>)'; // references via cite extension
 			$endPatterns[4] = '/(<ref>)|(<\/ref>)/';
 		}
 		$spat .= '/';
 		$textExt = array(); // text extracts
-		$otherExt = array();  // other extracts
+		$otherExt = array(); // other extracts
 		wfProfileIn( "$fname-split" );
 		$start = 0;
 		$textLen = strlen( $text );
@@ -907,8 +1054,9 @@ class SearchHighlighter {
 						if ( $key == 2 ) {
 							// see if this is an image link
 							$ns = substr( $val[0], 2, - 1 );
-							if ( $wgContLang->getNsIndex( $ns ) != NS_FILE )
+							if ( $wgContLang->getNsIndex( $ns ) != NS_FILE ) {
 								break;
+							}
 
 						}
 						$epat = $endPatterns[$key];
@@ -929,7 +1077,7 @@ class SearchHighlighter {
 								$len = strlen( $endMatches[2][0] );
 								$off = $endMatches[2][1];
 								$this->splitAndAdd( $otherExt, $count,
-									substr( $text, $start, $off + $len  - $start ) );
+									substr( $text, $start, $off + $len - $start ) );
 								$start = $off + $len;
 								$found = true;
 								break;
@@ -972,7 +1120,7 @@ class SearchHighlighter {
 		$anyterm = implode( '|', $terms );
 		$phrase = implode( "$wgSearchHighlightBoundaries+", $terms );
 
-		// FIXME: a hack to scale contextchars, a correct solution
+		// @todo FIXME: A hack to scale contextchars, a correct solution
 		// would be to have contextchars actually be char and not byte
 		// length, and do proper utf-8 substrings and lengths everywhere,
 		// but PHP is making that very hard and unclean to implement :(
@@ -1041,8 +1189,8 @@ class SearchHighlighter {
 		} else {
 			// if begin of the article contains the whole phrase, show only that !!
 			if ( array_key_exists( $first, $snippets ) && preg_match( $pat1, $snippets[$first] )
-			    && $offsets[$first] < $contextchars * 2 ) {
-				$snippets = array ( $first => $snippets[$first] );
+				&& $offsets[$first] < $contextchars * 2 ) {
+				$snippets = array( $first => $snippets[$first] );
 			}
 
 			// calc by how much to extend existing snippets
@@ -1062,10 +1210,10 @@ class SearchHighlighter {
 				// add more lines
 				$add = $index + 1;
 				while ( $len < $targetchars - 20
-				       && array_key_exists( $add, $all )
-				       && !array_key_exists( $add, $snippets ) ) {
-				    $offsets[$add] = 0;
-				    $tt = "\n" . $this->extract( $all[$add], 0, $targetchars - $len, $offsets[$add] );
+						&& array_key_exists( $add, $all )
+						&& !array_key_exists( $add, $snippets ) ) {
+					$offsets[$add] = 0;
+					$tt = "\n" . $this->extract( $all[$add], 0, $targetchars - $len, $offsets[$add] );
 					$extended[$add] = $tt;
 					$len += strlen( $tt );
 					$add++;
@@ -1073,29 +1221,31 @@ class SearchHighlighter {
 			}
 		}
 
-		// $snippets = array_map('htmlspecialchars', $extended);
+		// $snippets = array_map( 'htmlspecialchars', $extended );
 		$snippets = $extended;
 		$last = - 1;
 		$extract = '';
 		foreach ( $snippets as $index => $line ) {
-			if ( $last == - 1 )
+			if ( $last == - 1 ) {
 				$extract .= $line; // first line
-			elseif ( $last + 1 == $index && $offsets[$last] + strlen( $snippets[$last] ) >= strlen( $all[$last] ) )
+			} elseif ( $last + 1 == $index && $offsets[$last] + strlen( $snippets[$last] ) >= strlen( $all[$last] ) ) {
 				$extract .= " " . $line; // continous lines
-			else
+			} else {
 				$extract .= '<b> ... </b>' . $line;
+			}
 
 			$last = $index;
 		}
-		if ( $extract )
+		if ( $extract ) {
 			$extract .= '<b> ... </b>';
+		}
 
 		$processed = array();
 		foreach ( $terms as $term ) {
 			if ( ! isset( $processed[$term] ) ) {
 				$pat3 = "/$patPre(" . $term . ")$patPost/ui"; // highlight word
 				$extract = preg_replace( $pat3,
-			  		"\\1<span class='searchmatch'>\\2</span>\\3", $extract );
+					"\\1<span class='searchmatch'>\\2</span>\\3", $extract );
 				$processed[$term] = true;
 			}
 		}
@@ -1108,7 +1258,7 @@ class SearchHighlighter {
 	/**
 	 * Split text into lines and add it to extracts array
 	 *
-	 * @param $extracts Array: index -> $line
+	 * @param array $extracts index -> $line
 	 * @param $count Integer
 	 * @param $text String
 	 */
@@ -1116,8 +1266,9 @@ class SearchHighlighter {
 		$split = explode( "\n", $this->mCleanWikitext ? $this->removeWiki( $text ) : $text );
 		foreach ( $split as $line ) {
 			$tt = trim( $line );
-			if ( $tt )
+			if ( $tt ) {
 				$extracts[$count++] = $tt;
+			}
 		}
 	}
 
@@ -1125,13 +1276,15 @@ class SearchHighlighter {
 	 * Do manual case conversion for non-ascii chars
 	 *
 	 * @param $matches Array
+	 * @return string
 	 */
 	function caseCallback( $matches ) {
 		global $wgContLang;
 		if ( strlen( $matches[0] ) > 1 ) {
 			return '[' . $wgContLang->lc( $matches[0] ) . $wgContLang->uc( $matches[0] ) . ']';
-		} else
+		} else {
 			return $matches[0];
+		}
 	}
 
 	/**
@@ -1145,22 +1298,27 @@ class SearchHighlighter {
 	 * @return String
 	 */
 	function extract( $text, $start, $end, &$posStart = null, &$posEnd = null ) {
-		if ( $start != 0 )
+		if ( $start != 0 ) {
 			$start = $this->position( $text, $start, 1 );
-		if ( $end >= strlen( $text ) )
+		}
+		if ( $end >= strlen( $text ) ) {
 			$end = strlen( $text );
-		else
+		} else {
 			$end = $this->position( $text, $end );
+		}
 
-		if ( !is_null( $posStart ) )
+		if ( !is_null( $posStart ) ) {
 			$posStart = $start;
-		if ( !is_null( $posEnd ) )
+		}
+		if ( !is_null( $posEnd ) ) {
 			$posEnd = $end;
+		}
 
-		if ( $end > $start )
+		if ( $end > $start ) {
 			return substr( $text, $start, $end - $start );
-		else
+		} else {
 			return '';
+		}
 	}
 
 	/**
@@ -1184,8 +1342,9 @@ class SearchHighlighter {
 			while ( $char >= 0x80 && $char < 0xc0 ) {
 				// skip trailing bytes
 				$point++;
-				if ( $point >= strlen( $text ) )
+				if ( $point >= strlen( $text ) ) {
 					return strlen( $text );
+				}
 				$char = ord( $text[$point] );
 			}
 			return $point;
@@ -1196,33 +1355,37 @@ class SearchHighlighter {
 	/**
 	 * Search extracts for a pattern, and return snippets
 	 *
-	 * @param $pattern String: regexp for matching lines
-	 * @param $extracts Array: extracts to search
+	 * @param string $pattern regexp for matching lines
+	 * @param array $extracts extracts to search
 	 * @param $linesleft Integer: number of extracts to make
 	 * @param $contextchars Integer: length of snippet
-	 * @param $out Array: map for highlighted snippets
-	 * @param $offsets Array: map of starting points of snippets
+	 * @param array $out map for highlighted snippets
+	 * @param array $offsets map of starting points of snippets
 	 * @protected
 	 */
 	function process( $pattern, $extracts, &$linesleft, &$contextchars, &$out, &$offsets ) {
-		if ( $linesleft == 0 )
+		if ( $linesleft == 0 ) {
 			return; // nothing to do
+		}
 		foreach ( $extracts as $index => $line ) {
-			if ( array_key_exists( $index, $out ) )
+			if ( array_key_exists( $index, $out ) ) {
 				continue; // this line already highlighted
+			}
 
 			$m = array();
-			if ( !preg_match( $pattern, $line, $m, PREG_OFFSET_CAPTURE ) )
+			if ( !preg_match( $pattern, $line, $m, PREG_OFFSET_CAPTURE ) ) {
 				continue;
+			}
 
 			$offset = $m[0][1];
 			$len = strlen( $m[0][0] );
-			if ( $offset + $len < $contextchars )
+			if ( $offset + $len < $contextchars ) {
 				$begin = 0;
-			elseif ( $len > $contextchars )
+			} elseif ( $len > $contextchars ) {
 				$begin = $offset;
-			else
+			} else {
 				$begin = $offset + intval( ( $len - $contextchars ) / 2 );
+			}
 
 			$end = $begin + $contextchars;
 
@@ -1231,25 +1394,27 @@ class SearchHighlighter {
 			$out[$index] = $this->extract( $line, $begin, $end, $posBegin );
 			$offsets[$index] = $posBegin;
 			$linesleft--;
-			if ( $linesleft == 0 )
+			if ( $linesleft == 0 ) {
 				return;
+			}
 		}
 	}
 
 	/**
 	 * Basic wikitext removal
 	 * @protected
+	 * @return mixed
 	 */
 	function removeWiki( $text ) {
 		$fname = __METHOD__;
 		wfProfileIn( $fname );
 
-		// $text = preg_replace("/'{2,5}/", "", $text);
-		// $text = preg_replace("/\[[a-z]+:\/\/[^ ]+ ([^]]+)\]/", "\\2", $text);
-		// $text = preg_replace("/\[\[([^]|]+)\]\]/", "\\1", $text);
-		// $text = preg_replace("/\[\[([^]]+\|)?([^|]]+)\]\]/", "\\2", $text);
-		// $text = preg_replace("/\\{\\|(.*?)\\|\\}/", "", $text);
-		// $text = preg_replace("/\\[\\[[A-Za-z_-]+:([^|]+?)\\]\\]/", "", $text);
+		// $text = preg_replace( "/'{2,5}/", "", $text );
+		// $text = preg_replace( "/\[[a-z]+:\/\/[^ ]+ ([^]]+)\]/", "\\2", $text );
+		// $text = preg_replace( "/\[\[([^]|]+)\]\]/", "\\1", $text );
+		// $text = preg_replace( "/\[\[([^]]+\|)?([^|]]+)\]\]/", "\\2", $text );
+		// $text = preg_replace( "/\\{\\|(.*?)\\|\\}/", "", $text );
+		// $text = preg_replace( "/\\[\\[[A-Za-z_-]+:([^|]+?)\\]\\]/", "", $text );
 		$text = preg_replace( "/\\{\\{([^|]+?)\\}\\}/", "", $text );
 		$text = preg_replace( "/\\{\\{([^|]+\\|)(.*?)\\}\\}/", "\\2", $text );
 		$text = preg_replace( "/\\[\\[([^|]+?)\\]\\]/", "\\1", $text );
@@ -1272,79 +1437,80 @@ class SearchHighlighter {
 	 */
 	function linkReplace( $matches ) {
 		$colon = strpos( $matches[1], ':' );
-		if ( $colon === false )
+		if ( $colon === false ) {
 			return $matches[2]; // replace with caption
+		}
 		global $wgContLang;
 		$ns = substr( $matches[1], 0, $colon );
 		$index = $wgContLang->getNsIndex( $ns );
-		if ( $index !== false && ( $index == NS_FILE || $index == NS_CATEGORY ) )
+		if ( $index !== false && ( $index == NS_FILE || $index == NS_CATEGORY ) ) {
 			return $matches[0]; // return the whole thing
-		else
+		} else {
 			return $matches[2];
-
+		}
 	}
 
 	/**
-     * Simple & fast snippet extraction, but gives completely unrelevant
-     * snippets
-     *
-     * @param $text String
-     * @param $terms Array
-     * @param $contextlines Integer
-     * @param $contextchars Integer
-     * @return String
-     */
-    public function highlightSimple( $text, $terms, $contextlines, $contextchars ) {
-        global $wgContLang;
-        $fname = __METHOD__;
+	 * Simple & fast snippet extraction, but gives completely unrelevant
+	 * snippets
+	 *
+	 * @param $text String
+	 * @param $terms Array
+	 * @param $contextlines Integer
+	 * @param $contextchars Integer
+	 * @return String
+	 */
+	public function highlightSimple( $text, $terms, $contextlines, $contextchars ) {
+		global $wgContLang;
+		$fname = __METHOD__;
 
-        $lines = explode( "\n", $text );
+		$lines = explode( "\n", $text );
 
-        $terms = implode( '|', $terms );
-        $max = intval( $contextchars ) + 1;
-        $pat1 = "/(.*)($terms)(.{0,$max})/i";
+		$terms = implode( '|', $terms );
+		$max = intval( $contextchars ) + 1;
+		$pat1 = "/(.*)($terms)(.{0,$max})/i";
 
-        $lineno = 0;
+		$lineno = 0;
 
-        $extract = "";
-        wfProfileIn( "$fname-extract" );
-        foreach ( $lines as $line ) {
-            if ( 0 == $contextlines ) {
-                break;
-            }
-            ++$lineno;
-            $m = array();
-            if ( ! preg_match( $pat1, $line, $m ) ) {
-                continue;
-            }
-            --$contextlines;
-            $pre = $wgContLang->truncate( $m[1], - $contextchars );
+		$extract = "";
+		wfProfileIn( "$fname-extract" );
+		foreach ( $lines as $line ) {
+			if ( 0 == $contextlines ) {
+				break;
+			}
+			++$lineno;
+			$m = array();
+			if ( ! preg_match( $pat1, $line, $m ) ) {
+				continue;
+			}
+			--$contextlines;
+			// truncate function changes ... to relevant i18n message.
+			$pre = $wgContLang->truncate( $m[1], - $contextchars, '...', false );
 
-            if ( count( $m ) < 3 ) {
-                $post = '';
-            } else {
-                $post = $wgContLang->truncate( $m[3], $contextchars );
-            }
+			if ( count( $m ) < 3 ) {
+				$post = '';
+			} else {
+				$post = $wgContLang->truncate( $m[3], $contextchars, '...', false );
+			}
 
-            $found = $m[2];
+			$found = $m[2];
 
-            $line = htmlspecialchars( $pre . $found . $post );
-            $pat2 = '/(' . $terms . ")/i";
-            $line = preg_replace( $pat2,
-              "<span class='searchmatch'>\\1</span>", $line );
+			$line = htmlspecialchars( $pre . $found . $post );
+			$pat2 = '/(' . $terms . ")/i";
+			$line = preg_replace( $pat2, "<span class='searchmatch'>\\1</span>", $line );
 
-            $extract .= "${line}\n";
-        }
-        wfProfileOut( "$fname-extract" );
+			$extract .= "${line}\n";
+		}
+		wfProfileOut( "$fname-extract" );
 
-        return $extract;
-    }
+		return $extract;
+	}
 
 }
 
 /**
  * Dummy class to be used when non-supported Database engine is present.
- * @todo Fixme: dummy class should probably try something at least mildly useful,
+ * @todo FIXME: Dummy class should probably try something at least mildly useful,
  * such as a LIKE search through titles.
  * @ingroup Search
  */
