@@ -29,7 +29,6 @@
  * @ingroup SpecialPage
  */
 class SpecialExport extends SpecialPage {
-
 	private $curonly, $doExport, $pageLinkDepth, $templates;
 	private $images;
 
@@ -38,9 +37,9 @@ class SpecialExport extends SpecialPage {
 	}
 
 	public function execute( $par ) {
-		global $wgOut, $wgRequest, $wgSitename, $wgExportAllowListContributors;
+		global $wgSitename, $wgExportAllowListContributors, $wgExportFromNamespaces;
 		global $wgExportAllowHistory, $wgExportMaxHistory, $wgExportMaxLinkDepth;
-		global $wgExportFromNamespaces;
+		global $wgExportAllowAll;
 
 		$this->setHeaders();
 		$this->outputHeader();
@@ -48,16 +47,18 @@ class SpecialExport extends SpecialPage {
 		// Set some variables
 		$this->curonly = true;
 		$this->doExport = false;
-		$this->templates = $wgRequest->getCheck( 'templates' );
-		$this->images = $wgRequest->getCheck( 'images' ); // Doesn't do anything yet
+		$request = $this->getRequest();
+		$this->templates = $request->getCheck( 'templates' );
+		$this->images = $request->getCheck( 'images' ); // Doesn't do anything yet
 		$this->pageLinkDepth = $this->validateLinkDepth(
-			$wgRequest->getIntOrNull( 'pagelink-depth' )
+			$request->getIntOrNull( 'pagelink-depth' )
 		);
 		$nsindex = '';
+		$exportall = false;
 
-		if ( $wgRequest->getCheck( 'addcat' ) ) {
-			$page = $wgRequest->getText( 'pages' );
-			$catname = $wgRequest->getText( 'catname' );
+		if ( $request->getCheck( 'addcat' ) ) {
+			$page = $request->getText( 'pages' );
+			$catname = $request->getText( 'catname' );
 
 			if ( $catname !== '' && $catname !== null && $catname !== false ) {
 				$t = Title::makeTitleSafe( NS_MAIN, $catname );
@@ -73,12 +74,11 @@ class SpecialExport extends SpecialPage {
 					}
 				}
 			}
-		}
-		elseif( $wgRequest->getCheck( 'addns' ) && $wgExportFromNamespaces ) {
-			$page = $wgRequest->getText( 'pages' );
-			$nsindex = $wgRequest->getText( 'nsindex', '' );
+		} elseif ( $request->getCheck( 'addns' ) && $wgExportFromNamespaces ) {
+			$page = $request->getText( 'pages' );
+			$nsindex = $request->getText( 'nsindex', '' );
 
-			if ( strval( $nsindex ) !== ''  ) {
+			if ( strval( $nsindex ) !== '' ) {
 				/**
 				 * Same implementation as above, so same @todo
 				 */
@@ -87,196 +87,269 @@ class SpecialExport extends SpecialPage {
 					$page .= "\n" . implode( "\n", $nspages );
 				}
 			}
-		}
-		elseif( $wgRequest->wasPosted() && $par == '' ) {
-			$page = $wgRequest->getText( 'pages' );
-			$this->curonly = $wgRequest->getCheck( 'curonly' );
-			$rawOffset = $wgRequest->getVal( 'offset' );
+		} elseif ( $request->getCheck( 'exportall' ) && $wgExportAllowAll ) {
+			$this->doExport = true;
+			$exportall = true;
 
-			if( $rawOffset ) {
+			/* Although $page and $history are not used later on, we
+			nevertheless set them to avoid that PHP notices about using
+			undefined variables foul up our XML output (see call to
+			doExport(...) further down) */
+			$page = '';
+			$history = '';
+		} elseif ( $request->wasPosted() && $par == '' ) {
+			$page = $request->getText( 'pages' );
+			$this->curonly = $request->getCheck( 'curonly' );
+			$rawOffset = $request->getVal( 'offset' );
+
+			if ( $rawOffset ) {
 				$offset = wfTimestamp( TS_MW, $rawOffset );
 			} else {
 				$offset = null;
 			}
 
-			$limit = $wgRequest->getInt( 'limit' );
-			$dir = $wgRequest->getVal( 'dir' );
+			$limit = $request->getInt( 'limit' );
+			$dir = $request->getVal( 'dir' );
 			$history = array(
 				'dir' => 'asc',
 				'offset' => false,
 				'limit' => $wgExportMaxHistory,
 			);
-			$historyCheck = $wgRequest->getCheck( 'history' );
+			$historyCheck = $request->getCheck( 'history' );
 
 			if ( $this->curonly ) {
 				$history = WikiExporter::CURRENT;
 			} elseif ( !$historyCheck ) {
-				if ( $limit > 0 && ($wgExportMaxHistory == 0 || $limit < $wgExportMaxHistory ) ) {
+				if ( $limit > 0 && ( $wgExportMaxHistory == 0 || $limit < $wgExportMaxHistory ) ) {
 					$history['limit'] = $limit;
 				}
+
 				if ( !is_null( $offset ) ) {
 					$history['offset'] = $offset;
 				}
+
 				if ( strtolower( $dir ) == 'desc' ) {
 					$history['dir'] = 'desc';
 				}
 			}
 
-			if( $page != '' ) {
+			if ( $page != '' ) {
 				$this->doExport = true;
 			}
 		} else {
 			// Default to current-only for GET requests.
-			$page = $wgRequest->getText( 'pages', $par );
-			$historyCheck = $wgRequest->getCheck( 'history' );
+			$page = $request->getText( 'pages', $par );
+			$historyCheck = $request->getCheck( 'history' );
 
-			if( $historyCheck ) {
+			if ( $historyCheck ) {
 				$history = WikiExporter::FULL;
 			} else {
 				$history = WikiExporter::CURRENT;
 			}
 
-			if( $page != '' ) {
+			if ( $page != '' ) {
 				$this->doExport = true;
 			}
 		}
 
-		if( !$wgExportAllowHistory ) {
+		if ( !$wgExportAllowHistory ) {
 			// Override
 			$history = WikiExporter::CURRENT;
 		}
 
-		$list_authors = $wgRequest->getCheck( 'listauthors' );
+		$list_authors = $request->getCheck( 'listauthors' );
 		if ( !$this->curonly || !$wgExportAllowListContributors ) {
-			$list_authors = false ;
+			$list_authors = false;
 		}
 
 		if ( $this->doExport ) {
-			$wgOut->disable();
+			$this->getOutput()->disable();
 
 			// Cancel output buffering and gzipping if set
 			// This should provide safer streaming for pages with history
 			wfResetOutputBuffers();
-			$wgRequest->response()->header( "Content-type: application/xml; charset=utf-8" );
+			$request->response()->header( "Content-type: application/xml; charset=utf-8" );
 
-			if( $wgRequest->getCheck( 'wpDownload' ) ) {
+			if ( $request->getCheck( 'wpDownload' ) ) {
 				// Provide a sane filename suggestion
 				$filename = urlencode( $wgSitename . '-' . wfTimestampNow() . '.xml' );
-				$wgRequest->response()->header( "Content-disposition: attachment;filename={$filename}" );
+				$request->response()->header( "Content-disposition: attachment;filename={$filename}" );
 			}
 
-			$this->doExport( $page, $history, $list_authors );
+			$this->doExport( $page, $history, $list_authors, $exportall );
 
 			return;
 		}
 
-		$wgOut->addWikiMsg( 'exporttext' );
+		$out = $this->getOutput();
+		$out->addWikiMsg( 'exporttext' );
 
 		$form = Xml::openElement( 'form', array( 'method' => 'post',
-			'action' => $this->getTitle()->getLocalUrl( 'action=submit' ) ) );
-		$form .= Xml::inputLabel( wfMsg( 'export-addcattext' )    , 'catname', 'catname', 40 ) . '&#160;';
-		$form .= Xml::submitButton( wfMsg( 'export-addcat' ), array( 'name' => 'addcat' ) ) . '<br />';
+			'action' => $this->getTitle()->getLocalURL( 'action=submit' ) ) );
+		$form .= Xml::inputLabel(
+			$this->msg( 'export-addcattext' )->text(),
+			'catname',
+			'catname',
+			40
+		) . '&#160;';
+		$form .= Xml::submitButton(
+			$this->msg( 'export-addcat' )->text(),
+			array( 'name' => 'addcat' )
+		) . '<br />';
 
 		if ( $wgExportFromNamespaces ) {
-			$form .= Xml::namespaceSelector( $nsindex, null, 'nsindex', wfMsg( 'export-addnstext' ) ) . '&#160;';
-			$form .= Xml::submitButton( wfMsg( 'export-addns' ), array( 'name' => 'addns' ) ) . '<br />';
+			$form .= Html::namespaceSelector(
+				array(
+					'selected' => $nsindex,
+					'label' => $this->msg( 'export-addnstext' )->text()
+				), array(
+					'name' => 'nsindex',
+					'id' => 'namespace',
+					'class' => 'namespaceselector',
+				)
+			) . '&#160;';
+			$form .= Xml::submitButton(
+				$this->msg( 'export-addns' )->text(),
+				array( 'name' => 'addns' )
+			) . '<br />';
 		}
 
-		$form .= Xml::element( 'textarea', array( 'name' => 'pages', 'cols' => 40, 'rows' => 10 ), $page, false );
+		if ( $wgExportAllowAll ) {
+			$form .= Xml::checkLabel(
+				$this->msg( 'exportall' )->text(),
+				'exportall',
+				'exportall',
+				$request->wasPosted() ? $request->getCheck( 'exportall' ) : false
+			) . '<br />';
+		}
+
+		$form .= Xml::element(
+			'textarea',
+			array( 'name' => 'pages', 'cols' => 40, 'rows' => 10 ),
+			$page,
+			false
+		);
 		$form .= '<br />';
 
-		if( $wgExportAllowHistory ) {
+		if ( $wgExportAllowHistory ) {
 			$form .= Xml::checkLabel(
-				wfMsg( 'exportcuronly' ),
+				$this->msg( 'exportcuronly' )->text(),
 				'curonly',
 				'curonly',
-				$wgRequest->wasPosted() ? $wgRequest->getCheck( 'curonly' ) : true
+				$request->wasPosted() ? $request->getCheck( 'curonly' ) : true
 			) . '<br />';
 		} else {
-			$wgOut->addHTML( wfMsgExt( 'exportnohistory', 'parse' ) );
+			$out->addWikiMsg( 'exportnohistory' );
 		}
 
 		$form .= Xml::checkLabel(
-			wfMsg( 'export-templates' ),
+			$this->msg( 'export-templates' )->text(),
 			'templates',
 			'wpExportTemplates',
-			$wgRequest->wasPosted() ? $wgRequest->getCheck( 'templates' ) : false
+			$request->wasPosted() ? $request->getCheck( 'templates' ) : false
 		) . '<br />';
 
-		if( $wgExportMaxLinkDepth || $this->userCanOverrideExportDepth() ) {
-			$form .= Xml::inputLabel( wfMsg( 'export-pagelinks' ), 'pagelink-depth', 'pagelink-depth', 20, 0 ) . '<br />';
+		if ( $wgExportMaxLinkDepth || $this->userCanOverrideExportDepth() ) {
+			$form .= Xml::inputLabel(
+				$this->msg( 'export-pagelinks' )->text(),
+				'pagelink-depth',
+				'pagelink-depth',
+				20,
+				0
+			) . '<br />';
 		}
+
 		// Enable this when we can do something useful exporting/importing image information. :)
-		//$form .= Xml::checkLabel( wfMsg( 'export-images' ), 'images', 'wpExportImages', false ) . '<br />';
+		//$form .= Xml::checkLabel( $this->msg( 'export-images' )->text(), 'images', 'wpExportImages', false ) . '<br />';
 		$form .= Xml::checkLabel(
-			wfMsg( 'export-download' ),
+			$this->msg( 'export-download' )->text(),
 			'wpDownload',
 			'wpDownload',
-			$wgRequest->wasPosted() ? $wgRequest->getCheck( 'wpDownload' ) : true
+			$request->wasPosted() ? $request->getCheck( 'wpDownload' ) : true
 		) . '<br />';
 
-		$form .= Xml::submitButton( wfMsg( 'export-submit' ), Linker::tooltipAndAccesskeyAttribs( 'export' ) );
+		if ( $wgExportAllowListContributors ) {
+			$form .= Xml::checkLabel(
+				$this->msg( 'exportlistauthors' )->text(),
+				'listauthors',
+				'listauthors',
+				$request->wasPosted() ? $request->getCheck( 'listauthors' ) : false
+			) . '<br />';
+		}
+
+		$form .= Xml::submitButton(
+			$this->msg( 'export-submit' )->text(),
+			Linker::tooltipAndAccesskeyAttribs( 'export' )
+		);
 		$form .= Xml::closeElement( 'form' );
 
-		$wgOut->addHTML( $form );
+		$out->addHTML( $form );
 	}
 
+	/**
+	 * @return bool
+	 */
 	private function userCanOverrideExportDepth() {
-		global $wgUser;
-		return $wgUser->isAllowed( 'override-export-depth' );
+		return $this->getUser()->isAllowed( 'override-export-depth' );
 	}
 
 	/**
 	 * Do the actual page exporting
 	 *
-	 * @param $page String: user input on what page(s) to export
+	 * @param string $page user input on what page(s) to export
 	 * @param $history Mixed: one of the WikiExporter history export constants
 	 * @param $list_authors Boolean: Whether to add distinct author list (when
 	 *                      not returning full history)
+	 * @param $exportall Boolean: Whether to export everything
 	 */
-	private function doExport( $page, $history, $list_authors ) {
-		$pageSet = array(); // Inverted index of all pages to look up
+	private function doExport( $page, $history, $list_authors, $exportall ) {
 
-		// Split up and normalize input
-		foreach( explode( "\n", $page ) as $pageName ) {
-			$pageName = trim( $pageName );
-			$title = Title::newFromText( $pageName );
-			if( $title && $title->getInterwiki() == '' && $title->getText() !== '' ) {
-				// Only record each page once!
-				$pageSet[$title->getPrefixedText()] = true;
+		// If we are grabbing everything, enable full history and ignore the rest
+		if ( $exportall ) {
+			$history = WikiExporter::FULL;
+		} else {
+
+			$pageSet = array(); // Inverted index of all pages to look up
+
+			// Split up and normalize input
+			foreach ( explode( "\n", $page ) as $pageName ) {
+				$pageName = trim( $pageName );
+				$title = Title::newFromText( $pageName );
+				if ( $title && $title->getInterwiki() == '' && $title->getText() !== '' ) {
+					// Only record each page once!
+					$pageSet[$title->getPrefixedText()] = true;
+				}
 			}
+
+			// Set of original pages to pass on to further manipulation...
+			$inputPages = array_keys( $pageSet );
+
+			// Look up any linked pages if asked...
+			if ( $this->templates ) {
+				$pageSet = $this->getTemplates( $inputPages, $pageSet );
+			}
+			$linkDepth = $this->pageLinkDepth;
+			if ( $linkDepth ) {
+				$pageSet = $this->getPageLinks( $inputPages, $pageSet, $linkDepth );
+			}
+
+			// Enable this when we can do something useful exporting/importing image information.
+			// if( $this->images ) ) {
+			// $pageSet = $this->getImages( $inputPages, $pageSet );
+			// }
+
+			$pages = array_keys( $pageSet );
+
+			// Normalize titles to the same format and remove dupes, see bug 17374
+			foreach ( $pages as $k => $v ) {
+				$pages[$k] = str_replace( " ", "_", $v );
+			}
+
+			$pages = array_unique( $pages );
 		}
 
-		// Set of original pages to pass on to further manipulation...
-		$inputPages = array_keys( $pageSet );
-
-		// Look up any linked pages if asked...
-		if( $this->templates ) {
-			$pageSet = $this->getTemplates( $inputPages, $pageSet );
-		}
-		$linkDepth = $this->pageLinkDepth;
-		if( $linkDepth ) {
-			$pageSet = $this->getPageLinks( $inputPages, $pageSet, $linkDepth );
-		}
-
-		/*
-		 // Enable this when we can do something useful exporting/importing image information. :)
-		 if( $this->images ) ) {
-		 $pageSet = $this->getImages( $inputPages, $pageSet );
-		 }
-		 */
-
-		$pages = array_keys( $pageSet );
-
-		// Normalize titles to the same format and remove dupes, see bug 17374
-		foreach( $pages as $k => $v ) {
-			$pages[$k] = str_replace( " ", "_", $v );
-		}
-
-		$pages = array_unique( $pages );
-
 		/* Ok, let's get to it... */
-		if( $history == WikiExporter::CURRENT ) {
+		if ( $history == WikiExporter::CURRENT ) {
 			$lb = false;
 			$db = wfGetDB( DB_SLAVE );
 			$buffer = WikiExporter::BUFFER;
@@ -288,7 +361,7 @@ class SpecialExport extends SpecialPage {
 
 			// This might take a while... :D
 			wfSuppressWarnings();
-			set_time_limit(0);
+			set_time_limit( 0 );
 			wfRestoreWarnings();
 		}
 
@@ -296,38 +369,37 @@ class SpecialExport extends SpecialPage {
 		$exporter->list_authors = $list_authors;
 		$exporter->openStream();
 
-		foreach( $pages as $page ) {
-			/*
-			 if( $wgExportMaxHistory && !$this->curonly ) {
-			 $title = Title::newFromText( $page );
-			 if( $title ) {
-			 $count = Revision::countByTitle( $db, $title );
-			 if( $count > $wgExportMaxHistory ) {
-			 wfDebug( __FUNCTION__ .
-			 ": Skipped $page, $count revisions too big\n" );
-			 continue;
-			 }
-			 }
-			 }*/
-			#Bug 8824: Only export pages the user can read
-			$title = Title::newFromText( $page );
-			if( is_null( $title ) ) {
-				continue; #TODO: perhaps output an <error> tag or something.
-			}
-			if( !$title->userCanRead() ) {
-				continue; #TODO: perhaps output an <error> tag or something.
-			}
+		if ( $exportall ) {
+			$exporter->allPages();
+		} else {
+			foreach ( $pages as $page ) {
+				#Bug 8824: Only export pages the user can read
+				$title = Title::newFromText( $page );
+				if ( is_null( $title ) ) {
+					// @todo Perhaps output an <error> tag or something.
+					continue;
+				}
 
-			$exporter->pageByTitle( $title );
+				if ( !$title->userCan( 'read', $this->getUser() ) ) {
+					// @todo Perhaps output an <error> tag or something.
+					continue;
+				}
+
+				$exporter->pageByTitle( $title );
+			}
 		}
 
 		$exporter->closeStream();
 
-		if( $lb ) {
+		if ( $lb ) {
 			$lb->closeAll();
 		}
 	}
 
+	/**
+	 * @param $title Title
+	 * @return array
+	 */
 	private function getPagesFromCategory( $title ) {
 		global $wgContLang;
 
@@ -346,16 +418,21 @@ class SpecialExport extends SpecialPage {
 
 		foreach ( $res as $row ) {
 			$n = $row->page_title;
-			if ($row->page_namespace) {
+			if ( $row->page_namespace ) {
 				$ns = $wgContLang->getNsText( $row->page_namespace );
 				$n = $ns . ':' . $n;
 			}
 
 			$pages[] = $n;
 		}
+
 		return $pages;
 	}
 
+	/**
+	 * @param $nsindex int
+	 * @return array
+	 */
 	private function getPagesFromNamespace( $nsindex ) {
 		global $wgContLang;
 
@@ -380,6 +457,7 @@ class SpecialExport extends SpecialPage {
 
 			$pages[] = $n;
 		}
+
 		return $pages;
 	}
 
@@ -392,23 +470,25 @@ class SpecialExport extends SpecialPage {
 	private function getTemplates( $inputPages, $pageSet ) {
 		return $this->getLinks( $inputPages, $pageSet,
 			'templatelinks',
-			array( 'tl_namespace AS namespace', 'tl_title AS title' ),
+			array( 'namespace' => 'tl_namespace', 'title' => 'tl_title' ),
 			array( 'page_id=tl_from' )
 		);
 	}
 
 	/**
 	 * Validate link depth setting, if available.
+	 * @param $depth int
+	 * @return int
 	 */
 	private function validateLinkDepth( $depth ) {
 		global $wgExportMaxLinkDepth;
 
-		if( $depth < 0 ) {
+		if ( $depth < 0 ) {
 			return 0;
 		}
 
 		if ( !$this->userCanOverrideExportDepth() ) {
-			if( $depth > $wgExportMaxLinkDepth ) {
+			if ( $depth > $wgExportMaxLinkDepth ) {
 				return $wgExportMaxLinkDepth;
 			}
 		}
@@ -418,15 +498,22 @@ class SpecialExport extends SpecialPage {
 		 * crazy-big export from being done by someone setting the depth
 		 * number too high. In other words, last resort safety net.
 		 */
+
 		return intval( min( $depth, 5 ) );
 	}
 
-	/** Expand a list of pages to include pages linked to from that page. */
+	/**
+	 * Expand a list of pages to include pages linked to from that page.
+	 * @param $inputPages array
+	 * @param $pageSet array
+	 * @param $depth int
+	 * @return array
+	 */
 	private function getPageLinks( $inputPages, $pageSet, $depth ) {
-		for( ; $depth > 0; --$depth ) {
+		for ( ; $depth > 0; --$depth ) {
 			$pageSet = $this->getLinks(
 				$inputPages, $pageSet, 'pagelinks',
-				array( 'pl_namespace AS namespace', 'pl_title AS title' ),
+				array( 'namespace' => 'pl_namespace', 'title' => 'pl_title' ),
 				array( 'page_id=pl_from' )
 			);
 			$inputPages = array_keys( $pageSet );
@@ -448,21 +535,27 @@ class SpecialExport extends SpecialPage {
 			$inputPages,
 			$pageSet,
 			'imagelinks',
-			array( NS_FILE . ' AS namespace', 'il_to AS title' ),
+			array( 'namespace' => NS_FILE, 'title' => 'il_to' ),
 			array( 'page_id=il_from' )
 		);
 	}
 
 	/**
 	 * Expand a list of pages to include items used in those pages.
+	 * @param array $inputPages Array of page titles
+	 * @param array $pageSet
+	 * @param string $table
+	 * @param array $fields Array of field names
+	 * @param array $join
+	 * @return array
 	 */
 	private function getLinks( $inputPages, $pageSet, $table, $fields, $join ) {
 		$dbr = wfGetDB( DB_SLAVE );
 
-		foreach( $inputPages as $page ) {
+		foreach ( $inputPages as $page ) {
 			$title = Title::newFromText( $page );
 
-			if( $title ) {
+			if ( $title ) {
 				$pageSet[$title->getPrefixedText()] = true;
 				/// @todo FIXME: May or may not be more efficient to batch these
 				///        by namespace when given multiple input pages.
@@ -479,7 +572,7 @@ class SpecialExport extends SpecialPage {
 					__METHOD__
 				);
 
-				foreach( $result as $row ) {
+				foreach ( $result as $row ) {
 					$template = Title::makeTitle( $row->namespace, $row->title );
 					$pageSet[$template->getPrefixedText()] = true;
 				}
@@ -489,4 +582,7 @@ class SpecialExport extends SpecialPage {
 		return $pageSet;
 	}
 
+	protected function getGroupName() {
+		return 'pagetools';
+	}
 }
