@@ -27,9 +27,8 @@
  * @ingroup SpecialPage
  */
 class SpecialProtectedtitles extends SpecialPage {
-
 	protected $IdLevel = 'level';
-	protected $IdType  = 'type';
+	protected $IdType = 'type';
 
 	public function __construct() {
 		parent::__construct( 'Protectedtitles' );
@@ -56,20 +55,20 @@ class SpecialProtectedtitles extends SpecialPage {
 		$this->getOutput()->addHTML( $this->showOptions( $NS, $type, $level ) );
 
 		if ( $pager->getNumRows() ) {
-			$s = $pager->getNavigationBar();
-			$s .= "<ul>" .
-				$pager->getBody() .
-				"</ul>";
-			$s .= $pager->getNavigationBar();
+			$this->getOutput()->addHTML(
+				$pager->getNavigationBar() .
+					'<ul>' . $pager->getBody() . '</ul>' .
+					$pager->getNavigationBar()
+			);
 		} else {
-			$s = '<p>' . wfMsgHtml( 'protectedtitlesempty' ) . '</p>';
+			$this->getOutput()->addWikiMsg( 'protectedtitlesempty' );
 		}
-		$this->getOutput()->addHTML( $s );
 	}
 
 	/**
 	 * Callback function to output a restriction
 	 *
+	 * @param object $row Database row
 	 * @return string
 	 */
 	function formatRow( $row ) {
@@ -77,34 +76,52 @@ class SpecialProtectedtitles extends SpecialPage {
 
 		static $infinity = null;
 
-		if( is_null( $infinity ) ){
+		if ( is_null( $infinity ) ) {
 			$infinity = wfGetDB( DB_SLAVE )->getInfinity();
 		}
 
 		$title = Title::makeTitleSafe( $row->pt_namespace, $row->pt_title );
+		if ( !$title ) {
+			wfProfileOut( __METHOD__ );
+
+			return Html::rawElement(
+				'li',
+				array(),
+				Html::element(
+					'span',
+					array( 'class' => 'mw-invalidtitle' ),
+					Linker::getInvalidTitleDescription(
+						$this->getContext(),
+						$row->pt_namespace,
+						$row->pt_title
+					)
+				)
+			) . "\n";
+		}
+
 		$link = Linker::link( $title );
-
-		$description_items = array ();
-
-		$protType = wfMsgHtml( 'restriction-level-' . $row->pt_create_perm );
-
+		$description_items = array();
+		// Messages: restriction-level-sysop, restriction-level-autoconfirmed
+		$protType = $this->msg( 'restriction-level-' . $row->pt_create_perm )->escaped();
 		$description_items[] = $protType;
-
 		$lang = $this->getLanguage();
-		$expiry = strlen( $row->pt_expiry ) ? $lang->formatExpiry( $row->pt_expiry, TS_MW ) : $infinity;
-		if( $expiry != $infinity ) {
-			$expiry_description = wfMsg(
-				'protect-expiring-local',
-				$lang->timeanddate( $expiry, true ),
-				$lang->date( $expiry, true ),
-				$lang->time( $expiry, true )
-			);
+		$expiry = strlen( $row->pt_expiry ) ?
+			$lang->formatExpiry( $row->pt_expiry, TS_MW ) :
+			$infinity;
 
-			$description_items[] = htmlspecialchars($expiry_description);
+		if ( $expiry != $infinity ) {
+			$user = $this->getUser();
+			$description_items[] = $this->msg(
+				'protect-expiring-local',
+				$lang->userTimeAndDate( $expiry, $user ),
+				$lang->userDate( $expiry, $user ),
+				$lang->userTime( $expiry, $user )
+			)->escaped();
 		}
 
 		wfProfileOut( __METHOD__ );
 
+		// @todo i18n: This should use a comma separator instead of a hard coded comma, right?
 		return '<li>' . $lang->specialList( $link, implode( $description_items, ', ' ) ) . "</li>\n";
 	}
 
@@ -112,20 +129,22 @@ class SpecialProtectedtitles extends SpecialPage {
 	 * @param $namespace Integer:
 	 * @param $type string
 	 * @param $level string
+	 * @return string
 	 * @private
 	 */
-	function showOptions( $namespace, $type='edit', $level ) {
+	function showOptions( $namespace, $type = 'edit', $level ) {
 		global $wgScript;
 		$action = htmlspecialchars( $wgScript );
 		$title = $this->getTitle();
 		$special = htmlspecialchars( $title->getPrefixedDBkey() );
+
 		return "<form action=\"$action\" method=\"get\">\n" .
 			'<fieldset>' .
-			Xml::element( 'legend', array(), wfMsg( 'protectedtitles' ) ) .
+			Xml::element( 'legend', array(), $this->msg( 'protectedtitles' )->text() ) .
 			Html::hidden( 'title', $special ) . "&#160;\n" .
 			$this->getNamespaceMenu( $namespace ) . "&#160;\n" .
 			$this->getLevelMenu( $level ) . "&#160;\n" .
-			"&#160;" . Xml::submitButton( wfMsg( 'allpagessubmit' ) ) . "\n" .
+			"&#160;" . Xml::submitButton( $this->msg( 'allpagessubmit' )->text() ) . "\n" .
 			"</fieldset></form>";
 	}
 
@@ -137,44 +156,59 @@ class SpecialProtectedtitles extends SpecialPage {
 	 * @return string
 	 */
 	function getNamespaceMenu( $namespace = null ) {
-		return Xml::label( wfMsg( 'namespace' ), 'namespace' )
-			. '&#160;'
-			. Xml::namespaceSelector( $namespace, '' );
+		return Html::namespaceSelector(
+			array(
+				'selected' => $namespace,
+				'all' => '',
+				'label' => $this->msg( 'namespace' )->text()
+			), array(
+				'name' => 'namespace',
+				'id' => 'namespace',
+				'class' => 'namespaceselector',
+			)
+		);
 	}
 
 	/**
+	 * @param string $pr_level Determines which option is selected as default
 	 * @return string Formatted HTML
 	 * @private
 	 */
 	function getLevelMenu( $pr_level ) {
 		global $wgRestrictionLevels;
 
-		$m = array( wfMsg('restriction-level-all') => 0 ); // Temporary array
+		// Temporary array
+		$m = array( $this->msg( 'restriction-level-all' )->text() => 0 );
 		$options = array();
 
 		// First pass to load the log names
-		foreach( $wgRestrictionLevels as $type ) {
-			if ( $type !='' && $type !='*') {
-				$text = wfMsg("restriction-level-$type");
+		foreach ( $wgRestrictionLevels as $type ) {
+			if ( $type != '' && $type != '*' ) {
+				// Messages: restriction-level-sysop, restriction-level-autoconfirmed
+				$text = $this->msg( "restriction-level-$type" )->text();
 				$m[$text] = $type;
 			}
 		}
+
 		// Is there only one level (aside from "all")?
-		if( count($m) <= 2 ) {
+		if ( count( $m ) <= 2 ) {
 			return '';
 		}
 		// Third pass generates sorted XHTML content
-		foreach( $m as $text => $type ) {
-			$selected = ($type == $pr_level );
+		foreach ( $m as $text => $type ) {
+			$selected = ( $type == $pr_level );
 			$options[] = Xml::option( $text, $type, $selected );
 		}
 
-		return
-			Xml::label( wfMsg('restriction-level') , $this->IdLevel ) . '&#160;' .
+		return Xml::label( $this->msg( 'restriction-level' )->text(), $this->IdLevel ) . '&#160;' .
 			Xml::tags( 'select',
 				array( 'id' => $this->IdLevel, 'name' => $this->IdLevel ),
 				implode( "\n", $options ) );
 	}
+
+	protected function getGroupName() {
+		return 'maintenance';
+	}
 }
 
 /**
@@ -184,12 +218,14 @@ class SpecialProtectedtitles extends SpecialPage {
 class ProtectedTitlesPager extends AlphabeticPager {
 	public $mForm, $mConds;
 
-	function __construct( $form, $conds = array(), $type, $level, $namespace, $sizetype='', $size=0 ) {
+	function __construct( $form, $conds = array(), $type, $level, $namespace,
+		$sizetype = '', $size = 0
+	) {
 		$this->mForm = $form;
 		$this->mConds = $conds;
 		$this->level = $level;
 		$this->namespace = $namespace;
-		$this->size = intval($size);
+		$this->size = intval( $size );
 		parent::__construct( $form->getContext() );
 	}
 
@@ -205,6 +241,7 @@ class ProtectedTitlesPager extends AlphabeticPager {
 
 		$lb->execute();
 		wfProfileOut( __METHOD__ );
+
 		return '';
 	}
 
@@ -212,7 +249,7 @@ class ProtectedTitlesPager extends AlphabeticPager {
 	 * @return Title
 	 */
 	function getTitle() {
-		return SpecialPage::getTitleFor( 'Protectedtitles' );
+		return $this->mForm->getTitle();
 	}
 
 	function formatRow( $row ) {
@@ -225,13 +262,18 @@ class ProtectedTitlesPager extends AlphabeticPager {
 	function getQueryInfo() {
 		$conds = $this->mConds;
 		$conds[] = 'pt_expiry>' . $this->mDb->addQuotes( $this->mDb->timestamp() );
-		if( $this->level )
+		if ( $this->level ) {
 			$conds['pt_create_perm'] = $this->level;
-		if( !is_null($this->namespace) )
+		}
+
+		if ( !is_null( $this->namespace ) ) {
 			$conds[] = 'pt_namespace=' . $this->mDb->addQuotes( $this->namespace );
+		}
+
 		return array(
 			'tables' => 'protected_titles',
-			'fields' => 'pt_namespace,pt_title,pt_create_perm,pt_expiry,pt_timestamp',
+			'fields' => array( 'pt_namespace', 'pt_title', 'pt_create_perm',
+				'pt_expiry', 'pt_timestamp' ),
 			'conds' => $conds
 		);
 	}
@@ -240,4 +282,3 @@ class ProtectedTitlesPager extends AlphabeticPager {
 		return 'pt_timestamp';
 	}
 }
-
