@@ -1,5 +1,7 @@
 <?php
 /**
+ * Implements Special:Unblock
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -30,61 +32,48 @@ class SpecialUnblock extends SpecialPage {
 	protected $type;
 	protected $block;
 
-	public function __construct(){
+	public function __construct() {
 		parent::__construct( 'Unblock', 'block' );
 	}
 
-	public function execute( $par ){
-		global $wgUser, $wgOut, $wgRequest;
+	public function execute( $par ) {
+		$this->checkPermissions();
+		$this->checkReadOnly();
 
-		# Check permissions
-		if( !$this->userCanExecute( $wgUser ) ) {
-			$this->displayRestrictionError();
-			return;
-		}
-
-		# Check for database lock
-		if( wfReadOnly() ) {
-			throw new ReadOnlyError;
-		}
-
-		list( $this->target, $this->type ) = SpecialBlock::getTargetAndType( $par, $wgRequest );
+		list( $this->target, $this->type ) = SpecialBlock::getTargetAndType( $par, $this->getRequest() );
 		$this->block = Block::newFromTarget( $this->target );
 
-		# bug 15810: blocked admins should have limited access here.  This won't allow sysops
-		# to remove autoblocks on themselves, but they should have ipblock-exempt anyway
-		$status = SpecialBlock::checkUnblockSelf( $this->target );
-		if ( $status !== true ) {
-			throw new ErrorPageError( 'badaccess', $status );
-		}
+		$this->setHeaders();
+		$this->outputHeader();
 
-		$wgOut->setPageTitle( wfMsg( 'unblockip' ) );
-		$wgOut->addModules( 'mediawiki.special' );
+		$out = $this->getOutput();
+		$out->setPageTitle( $this->msg( 'unblockip' ) );
+		$out->addModules( 'mediawiki.special' );
 
 		$form = new HTMLForm( $this->getFields(), $this->getContext() );
-		$form->setWrapperLegend( wfMsg( 'unblockip' ) );
-		$form->setSubmitCallback( array( __CLASS__, 'processUnblock' ) );
-		$form->setSubmitText( wfMsg( 'ipusubmit' ) );
-		$form->addPreText( wfMsgExt( 'unblockiptext', 'parse' ) );
+		$form->setWrapperLegendMsg( 'unblockip' );
+		$form->setSubmitCallback( array( __CLASS__, 'processUIUnblock' ) );
+		$form->setSubmitTextMsg( 'ipusubmit' );
+		$form->addPreText( $this->msg( 'unblockiptext' )->parseAsBlock() );
 
-		if( $form->show() ){
-			switch( $this->type ){
+		if ( $form->show() ) {
+			switch ( $this->type ) {
 				case Block::TYPE_USER:
 				case Block::TYPE_IP:
-					$wgOut->addWikiMsg( 'unblocked',  $this->target );
+					$out->addWikiMsg( 'unblocked', wfEscapeWikiText( $this->target ) );
 					break;
 				case Block::TYPE_RANGE:
-					$wgOut->addWikiMsg( 'unblocked-range', $this->target );
+					$out->addWikiMsg( 'unblocked-range', wfEscapeWikiText( $this->target ) );
 					break;
 				case Block::TYPE_ID:
 				case Block::TYPE_AUTO:
-					$wgOut->addWikiMsg( 'unblocked-id', $this->target );
+					$out->addWikiMsg( 'unblocked-id', wfEscapeWikiText( $this->target ) );
 					break;
 			}
 		}
 	}
 
-	protected function getFields(){
+	protected function getFields() {
 		$fields = array(
 			'Target' => array(
 				'type' => 'text',
@@ -103,25 +92,24 @@ class SpecialUnblock extends SpecialPage {
 			)
 		);
 
-		if( $this->block instanceof Block ){
+		if ( $this->block instanceof Block ) {
 			list( $target, $type ) = $this->block->getTargetAndType();
 
 			# Autoblocks are logged as "autoblock #123 because the IP was recently used by
 			# User:Foo, and we've just got any block, auto or not, that applies to a target
 			# the user has specified.  Someone could be fishing to connect IPs to autoblocks,
 			# so don't show any distinction between unblocked IPs and autoblocked IPs
-			if( $type == Block::TYPE_AUTO && $this->type == Block::TYPE_IP ){
+			if ( $type == Block::TYPE_AUTO && $this->type == Block::TYPE_IP ) {
 				$fields['Target']['default'] = $this->target;
 				unset( $fields['Name'] );
 
 			} else {
 				$fields['Target']['default'] = $target;
 				$fields['Target']['type'] = 'hidden';
-				switch( $type ){
+				switch ( $type ) {
 					case Block::TYPE_USER:
 					case Block::TYPE_IP:
-						$skin = $this->getSkin();
-						$fields['Name']['default'] = $skin->link(
+						$fields['Name']['default'] = Linker::link(
 							$target->getUserPage(),
 							$target->getName()
 						);
@@ -148,31 +136,52 @@ class SpecialUnblock extends SpecialPage {
 		return $fields;
 	}
 
+	/**
+	 * Submit callback for an HTMLForm object
+	 * @param array $data
+	 * @param HTMLForm $form
+	 * @return Array( Array(message key, parameters)
+	 */
+	public static function processUIUnblock( array $data, HTMLForm $form ) {
+		return self::processUnblock( $data, $form->getContext() );
+	}
+
 	/**
 	 * Process the form
+	 *
+	 * @param $data Array
+	 * @param $context IContextSource
+	 * @throws ErrorPageError
 	 * @return Array( Array(message key, parameters) ) on failure, True on success
 	 */
-	public static function processUnblock( array $data ){
-		global $wgUser;
-
+	public static function processUnblock( array $data, IContextSource $context ) {
+		$performer = $context->getUser();
 		$target = $data['Target'];
 		$block = Block::newFromTarget( $data['Target'] );
 
-		if( !$block instanceof Block ){
+		if ( !$block instanceof Block ) {
 			return array( array( 'ipb_cant_unblock', $target ) );
 		}
 
+		# bug 15810: blocked admins should have limited access here.  This
+		# won't allow sysops to remove autoblocks on themselves, but they
+		# should have ipblock-exempt anyway
+		$status = SpecialBlock::checkUnblockSelf( $target, $performer );
+		if ( $status !== true ) {
+			throw new ErrorPageError( 'badaccess', $status );
+		}
+
 		# If the specified IP is a single address, and the block is a range block, don't
 		# unblock the whole range.
 		list( $target, $type ) = SpecialBlock::getTargetAndType( $target );
-		if( $block->getType() == Block::TYPE_RANGE && $type == Block::TYPE_IP ) {
-			 $range = $block->getTarget();
-			 return array( array( 'ipb_blocked_as_range', $target, $range ) );
+		if ( $block->getType() == Block::TYPE_RANGE && $type == Block::TYPE_IP ) {
+			$range = $block->getTarget();
+			return array( array( 'ipb_blocked_as_range', $target, $range ) );
 		}
 
 		# If the name was hidden and the blocking user cannot hide
 		# names, then don't allow any block removals...
-		if( !$wgUser->isAllowed( 'hideuser' ) && $block->mHideName ) {
+		if ( !$performer->isAllowed( 'hideuser' ) && $block->mHideName ) {
 			return array( 'unblock-hideuser' );
 		}
 
@@ -182,7 +191,7 @@ class SpecialUnblock extends SpecialPage {
 		}
 
 		# Unset _deleted fields as needed
-		if( $block->mHideName ) {
+		if ( $block->mHideName ) {
 			# Something is deeply FUBAR if this is not a User object, but who knows?
 			$id = $block->getTarget() instanceof User
 				? $block->getTarget()->getID()
@@ -202,8 +211,12 @@ class SpecialUnblock extends SpecialPage {
 
 		# Make log entry
 		$log = new LogPage( 'block' );
-		$log->addEntry( 'unblock', $page, $data['Reason'] );
+		$log->addEntry( 'unblock', $page, $data['Reason'], array(), $performer );
 
 		return true;
 	}
+
+	protected function getGroupName() {
+		return 'users';
+	}
 }
