@@ -47,17 +47,17 @@ class UncategorizedPagesPage extends PageQueryPage {
 	}
 
 	function getQueryInfo() {
-		return array (
-			'tables' => array ( 'page', 'categorylinks' ),
-			'fields' => array ( 'namespace' => 'page_namespace',
+		return array(
+			'tables' => array( 'page', 'categorylinks' ),
+			'fields' => array( 'namespace' => 'page_namespace',
 					'title' => 'page_title',
 					'value' => 'page_title' ),
 			// default for page_namespace is all content namespaces (if requestedNamespace is false)
 			// otherwise, page_namespace is requestedNamespace
-			'conds' => array ( 'cl_from IS NULL',
+			'conds' => array( 'cl_from IS NULL',
 					'page_namespace' => ( $this->requestedNamespace !== false ? $this->requestedNamespace : MWNamespace::getContentNamespaces() ),
 					'page_is_redirect' => 0 ),
-			'join_conds' => array ( 'categorylinks' => array (
+			'join_conds' => array( 'categorylinks' => array(
 					'LEFT JOIN', 'cl_from = page_id' ) )
 		);
 	}
@@ -65,8 +65,9 @@ class UncategorizedPagesPage extends PageQueryPage {
 	function getOrderFields() {
 		// For some crazy reason ordering by a constant
 		// causes a filesort
-		if( $this->requestedNamespace === false && count( MWNamespace::getContentNamespaces() ) > 1 )
+		if ( $this->requestedNamespace === false && count( MWNamespace::getContentNamespaces() ) > 1 ) {
 			return array( 'page_namespace', 'page_title' );
+		}
 		return array( 'page_title' );
 	}
 
