@@ -22,21 +22,21 @@
  */
 
 /**
-  * These determine things like interwikis, language selectors, and so on.
-  * Safe to change without running scripts on the respective sites.
-  *
-  * \xE2\x80\x8E is the left-to-right marker and
-  * \xE2\x80\x8F is the right-to-left marker.
-  * They are required for ensuring the correct display of brackets in
-  * mixed rtl/ltr environment.
-  *
-  * Some writing systems require some line-height fixes. This includes
-  * most Indic scripts, like Devanagari.
-  * If you are adding support for such a language, add it also to
-  * the relevant section in skins/common/shared.css.
-  *
-  * @ingroup Language
-  */
+ * These determine things like interwikis, language selectors, and so on.
+ * Safe to change without running scripts on the respective sites.
+ *
+ * \xE2\x80\x8E is the left-to-right marker and
+ * \xE2\x80\x8F is the right-to-left marker.
+ * They are required for ensuring the correct display of brackets in
+ * mixed rtl/ltr environment.
+ *
+ * Some writing systems require some line-height fixes. This includes
+ * most Indic scripts, like Devanagari.
+ * If you are adding support for such a language, add it also to
+ * the relevant section in skins/common/shared.css.
+ *
+ * @ingroup Language
+ */
 /* private */ $coreLanguageNames = array(
 	'aa' => 'Qafár af',	# Afar
 	'ab' => 'Аҧсшәа',	# Abkhaz
@@ -54,7 +54,7 @@
 	'arn' => 'mapudungun',	# Mapuche, Mapudungu, Araucanian (Araucano)
 	'ary' => 'Maġribi',	# Moroccan Spoken Arabic
 	'arz' => 'مصرى',	# Egyptian Spoken Arabic
-	'as' => 'অসমীয়া',	# Assamese
+	'as' => 'অসমীয়া',	# Assamese
 	'ast' => 'asturianu',	# Asturian
 	'av' => 'авар',	# Avar
 	'avk' => 'Kotava', # Kotava
@@ -64,6 +64,8 @@
 	'ba' => 'башҡортса',	# Bashkir
 	'bar' => 'Boarisch',	# Bavarian (Austro-Bavarian and South Tyrolean)
 	'bat-smg' => 'žemaitėška', # Samogitian (deprecated code, 'sgs' in ISO 693-3 since 2010-06-30 )
+	'bbc' => 'Batak Toba', # Batak Toba (falls back to bbc-latn)
+	'bbc-latn' => 'Batak Toba', # Batak Toba
 	'bcc' => 'بلوچی مکرانی', # Southern Balochi
 	'bcl' => 'Bikol Central', # Bikol: Central Bicolano language
 	'be' => 'беларуская',	#  Belarusian normative
@@ -155,7 +157,7 @@
 	'gu' => 'ગુજરાતી',	# Gujarati
 	'gv' => 'Gaelg',		# Manx
 	'ha' => 'Hausa',	# Hausa
-	'hak' => 'Hak-kâ-fa',	# Hakka
+	'hak' => '客家語/Hak-kâ-ngî',	# Hakka
 	'haw' => 'Hawai`i',		# Hawaiian
 	'he' => 'עברית',	# Hebrew
 	'hi' => 'हिन्दी',	# Hindi
@@ -165,7 +167,7 @@
 	'ho' => 'Hiri Motu',	# Hiri Motu
 	'hr' => 'hrvatski',		# Croatian
 	'hsb' => 'hornjoserbsce',	# Upper Sorbian
-	'ht'  => 'Kreyòl ayisyen',		# Haitian Creole French
+	'ht' => 'Kreyòl ayisyen',		# Haitian Creole French
 	'hu' => 'magyar',		# Hungarian
 	'hy' => 'Հայերեն',	# Armenian
 	'hz' => 'Otsiherero',	# Herero
@@ -219,7 +221,7 @@
 	'ks-arab' => 'کٲشُر',	# Kashmiri (Perso-Arabic script)
 	'ks-deva' => 'कॉशुर',	# Kashmiri (Devanagari script)
 	'ksh' => 'Ripoarisch',	# Ripuarian
-	'ku'  => 'Kurdî',	# Kurdish (multiple scripts - defaults to Latin)
+	'ku' => 'Kurdî',	# Kurdish (multiple scripts - defaults to Latin)
 	'ku-latn' => "Kurdî (latînî)\xE2\x80\x8E",	# Northern Kurdish (Latin script)
 	'ku-arab' => "كوردي (عەرەبی)\xE2\x80\x8F",	# Northern Kurdish (Arabic script) (falls back to ckb)
 	'kv' => 'коми',	# Komi-Zyrian (Cyrillic is common script but also written in Latin script)
@@ -237,7 +239,7 @@
 	'liv' => 'Līvõ kēļ',	# Livonian
 	'lmo' => 'lumbaart',	# Lombard
 	'ln' => 'lingála',		# Lingala
-	'lo' => 'ລາວ',# Laotian
+	'lo' => 'ລາວ',	# Laotian
 	'loz' => 'Silozi', # Lozi
 	'lt' => 'lietuvių',	# Lithuanian
 	'ltg' => 'latgaļu', 	# Latgalian
@@ -269,7 +271,7 @@
 	'na' => 'Dorerin Naoero',		# Nauruan
 	'nah' => 'Nāhuatl',		# Nahuatl, en:Wikipedia writes Nahuatlahtolli, while another form is Náhuatl
 	'nan' => 'Bân-lâm-gú', # Min-nan -- (bug 8217) nan instead of zh-min-nan, http://www.sil.org/iso639-3/codes.asp?order=639_3&letter=n
-	'nap' => 'Nnapulitano',	# Neapolitan
+	'nap' => 'Napulitano',	# Neapolitan, bug 43793
 	'nb' => "norsk bokmål",		# Norwegian (Bokmal)
 	'nds' => 'Plattdüütsch',	# Low German ''or'' Low Saxon
 	'nds-nl' => 'Nedersaksies',	# aka Nedersaksisch: Dutch Low Saxon
@@ -288,7 +290,7 @@
 	'ny' => 'Chi-Chewa',	# Chichewa
 	'oc' => 'occitan',		# Occitan
 	'om' => 'Oromoo',		# Oromo
-	'or' => 'ଓଡ଼ିଆ',		# Oriya
+	'or' => 'ଓଡ଼ିଆ',		# Oriya
 	'os' => 'Ирон', # Ossetic -- fixed per bug 29091
 	'pa' => 'ਪੰਜਾਬੀ', # Eastern Punjabi (Gurmukhi script) (pan)
 	'pag' => 'Pangasinan',	# Pangasinan
