@@ -21,9 +21,7 @@
  * @ingroup Language
  */
 
-require_once( __DIR__ . '/../LanguageConverter.php' );
-require_once( __DIR__ . '/LanguageSr_ec.php' );
-require_once( __DIR__ . '/LanguageSr_el.php' );
+require_once __DIR__ . '/../LanguageConverter.php';
 
 /**
  * There are two levels of conversion for Serbian: the script level
@@ -75,7 +73,7 @@ class SrConverter extends LanguageConverter {
 		$this->mTables = array(
 			'sr-ec' => new ReplacementArray( $this->mToCyrillics ),
 			'sr-el' => new ReplacementArray( $this->mToLatin ),
-			'sr'    => new ReplacementArray()
+			'sr' => new ReplacementArray()
 		);
 	}
 
@@ -118,14 +116,16 @@ class SrConverter extends LanguageConverter {
 		// check for user namespace
 		if ( is_object( $nt ) ) {
 			$ns = $nt->getNamespace();
-			if ( $ns == NS_USER || $ns == NS_USER_TALK )
+			if ( $ns == NS_USER || $ns == NS_USER_TALK ) {
 				return;
+			}
 		}
 
 		$oldlink = $link;
 		parent::findVariantLink( $link, $nt, $ignoreOtherCond );
-		if ( $this->getPreferredVariant() == $this->mMainLanguageCode )
+		if ( $this->getPreferredVariant() == $this->mMainLanguageCode ) {
 			$link = $oldlink;
+		}
 	}
 
 	/**
@@ -139,9 +139,11 @@ class SrConverter extends LanguageConverter {
 	 */
 	function autoConvert( $text, $toVariant = false ) {
 		global $wgTitle;
-		if ( is_object( $wgTitle ) && $wgTitle->getNameSpace() == NS_FILE ) {
+		if ( is_object( $wgTitle ) && $wgTitle->getNamespace() == NS_FILE ) {
 			$imagename = $wgTitle->getNsText();
-			if ( preg_match( "/^$imagename:/", $text ) ) return $text;
+			if ( preg_match( "/^$imagename:/", $text ) ) {
+				return $text;
+			}
 		}
 		return parent::autoConvert( $text, $toVariant );
 	}
@@ -162,14 +164,16 @@ class SrConverter extends LanguageConverter {
 		// regexp for roman numbers
 		$roman = 'M{0,4}(CM|CD|D?C{0,3})(XC|XL|L?X{0,3})(IX|IV|V?I{0,3})';
 
-		$reg = '/^' . $roman . '$|^' . $roman . $breaks . '|' . $breaks . $roman . '$|' . $breaks . $roman . $breaks . '/';
+		$reg = '/^' . $roman . '$|^' . $roman . $breaks . '|' . $breaks
+			. $roman . '$|' . $breaks . $roman . $breaks . '/';
 
 		$matches = preg_split( $reg, $text, -1, PREG_SPLIT_OFFSET_CAPTURE );
 
 		$m = array_shift( $matches );
 		$this->loadTables();
 		if ( !isset( $this->mTables[$toVariant] ) ) {
-			throw new MWException( "Broken variant table: " . implode( ',', array_keys( $this->mTables ) ) );
+			throw new MWException( "Broken variant table: "
+				. implode( ',', array_keys( $this->mTables ) ) );
 		}
 		$ret = $this->mTables[$toVariant]->replace( $m[0] );
 		$mstart = $m[1] + strlen( $m[0] );
@@ -194,13 +198,13 @@ class SrConverter extends LanguageConverter {
 	 * @since 1.19
 	 */
 	public function guessVariant( $text, $variant ) {
-		$numCyrillic = preg_match_all("/[шђчћжШЂЧЋЖ]/u", $text, $dummy);
-		$numLatin = preg_match_all("/[šđčćžŠĐČĆŽ]/u", $text, $dummy);
+		$numCyrillic = preg_match_all( "/[шђчћжШЂЧЋЖ]/u", $text, $dummy );
+		$numLatin = preg_match_all( "/[šđčćžŠĐČĆŽ]/u", $text, $dummy );
 
-		if( $variant == 'sr-ec' ) {
-			return (boolean) ($numCyrillic > $numLatin);
-		} elseif( $variant == 'sr-el' ) {
-			return (boolean) ($numLatin > $numCyrillic);
+		if ( $variant == 'sr-ec' ) {
+			return $numCyrillic > $numLatin;
+		} elseif ( $variant == 'sr-el' ) {
+			return $numLatin > $numCyrillic;
 		} else {
 			return false;
 		}
@@ -214,7 +218,7 @@ class SrConverter extends LanguageConverter {
  *
  * @ingroup Language
  */
-class LanguageSr extends LanguageSr_ec {
+class LanguageSr extends Language {
 	function __construct() {
 		global $wgHooks;
 
@@ -222,52 +226,16 @@ class LanguageSr extends LanguageSr_ec {
 
 		$variants = array( 'sr', 'sr-ec', 'sr-el' );
 		$variantfallbacks = array(
-			'sr'    => 'sr-ec',
+			'sr' => 'sr-ec',
 			'sr-ec' => 'sr',
 			'sr-el' => 'sr',
 		);
 
 		$flags = array(
 			'S' => 'S', 'писмо' => 'S', 'pismo' => 'S',
-			'W' => 'W', 'реч'   => 'W', 'reč'   => 'W', 'ријеч' => 'W', 'riječ' => 'W'
+			'W' => 'W', 'реч' => 'W', 'reč' => 'W', 'ријеч' => 'W', 'riječ' => 'W'
 		);
 		$this->mConverter = new SrConverter( $this, 'sr', $variants, $variantfallbacks, $flags );
 		$wgHooks['PageContentSaveComplete'][] = $this->mConverter;
 	}
-
-	/**
-	 * @param $count int
-	 * @param $forms array
-	 *
-	 * @return string
-	 */
-	function convertPlural( $count, $forms ) {
-		if ( !count( $forms ) ) {
-			return '';
-		}
-
-		// If the actual number is not mentioned in the expression, then just two forms are enough:
-		// singular for $count == 1
-		// plural   for $count != 1
-		// For example, "This user belongs to {{PLURAL:$1|one group|several groups}}."
-		if ( count( $forms ) === 2 ) {
-			return $count == 1 ? $forms[0] : $forms[1];
-		}
-
-		// @todo FIXME: CLDR defines 4 plural forms. Form with decimals missing.
-		// See http://unicode.org/repos/cldr-tmp/trunk/diff/supplemental/language_plural_rules.html#ru
-		$forms = $this->preConvertPlural( $forms, 3 );
-
-		if ( $count > 10 && floor( ( $count % 100 ) / 10 ) == 1 ) {
-			return $forms[2];
-		} else {
-			switch ( $count % 10 ) {
-				case 1:  return $forms[0];
-				case 2:
-				case 3:
-				case 4:  return $forms[1];
-				default: return $forms[2];
-			}
-		}
-	}
 }
