@@ -19,45 +19,74 @@ $rtl = true;
 
 $namespaceNames = array(
 	NS_MEDIA            => 'މީޑިއާ',
-	NS_SPECIAL          => 'ހާއްޞަ',
+	NS_SPECIAL          => 'ޚާއްސަ',
 	NS_MAIN             => '',
 	NS_TALK             => 'ޚިޔާލު',
 	NS_USER             => 'މެމްބަރު',
 	NS_USER_TALK        => 'މެމްބަރުގެ_ވާހަކަ',
-	NS_FILE             => 'ފައިލް',
-	NS_FILE_TALK        => 'ފައިލް_ޚިޔާލު',
+	NS_PROJECT_TALK     => '$1ގެ_ވާހަކަ',
+	NS_FILE             => 'ފައިލު',
+	NS_FILE_TALK        => 'ފައިލުގެ_ޚިޔާލު',
 	NS_MEDIAWIKI        => 'މީޑިއާވިކީ',
-	NS_MEDIAWIKI_TALK   => 'މީޑިޔާވިކި_ޚިޔާލު',
+	NS_MEDIAWIKI_TALK   => 'މިޑިއާވިކީ_ޚިޔާލު',
 	NS_TEMPLATE         => 'ފަންވަތް',
-	NS_TEMPLATE_TALK    => 'ފަންވަތް_ޚިޔާލު',
+	NS_TEMPLATE_TALK    => 'ފަންވަތުގެ_ޚިޔާލު',
 	NS_HELP             => 'އެހީ',
-	NS_HELP_TALK        => 'އެހީ_ޚިޔާލު',
+	NS_HELP_TALK        => 'އެހީގެ_ޚިޔާލު',
 	NS_CATEGORY         => 'ޤިސްމު',
-	NS_CATEGORY_TALK    => 'ޤިސްމު_ޚިޔާލު',
+	NS_CATEGORY_TALK    => 'ޤިސްމުގެ_ޚިޔާލު',
+);
+
+$namespaceAliases = array(
+	'ހާއްޞަ'          => NS_SPECIAL,
+	'ފައިލް'           => NS_FILE,
+	'ފައިލް_ޚިޔާލު'    => NS_FILE_TALK,
+	'މީޑިޔާވިކި_ޚިޔާލު' => NS_MEDIAWIKI_TALK,
+	'ފަންވަތް_ޚިޔާލު'  => NS_TEMPLATE_TALK,
+	'އެހީ_ޚިޔާލު'      => NS_HELP_TALK,
+	'ޤިސްމު_ޚިޔާލު'   => NS_CATEGORY_TALK,
 );
 
 $specialPageAliases = array(
-	'Allpages'                  => array( 'ހުރިހާ ސަފްޙާއެއް' ),
+	'Activeusers'               => array( 'ހަރަކާތްތެރި_މެމްބަރުން' ),
+	'Allmessages'               => array( 'ހުރިހާ_މެސެޖެއް' ),
+	'Allpages'                  => array( 'ހުރިހާ_ޞަފްޙާއެއް' ),
+	'Ancientpages'              => array( 'ބާ_ޞަފްޙާތައް' ),
+	'Blankpage'                 => array( 'ހުސް_ޞަފްޙާ' ),
 	'Contributions'             => array( 'ޙިއްސާ' ),
-	'CreateAccount'             => array( 'މެމްބަރުކަން ހާސިލްކުރައްވާ' ),
-	'Emailuser'                 => array( 'މެމްބަރަށް އީ-މެއިލް ފޮނުވާ' ),
-	'BlockList'                 => array( 'ބްލޮކް ކުރެވިފައިވާ ލިސްޓް' ),
-	'Listfiles'                 => array( 'ފައިލް ލިސްޓް' ),
-	'Longpages'                 => array( 'ދިގު ސަފްޙާތައް' ),
-	'Newimages'                 => array( 'އާ ފައިލް' ),
-	'Newpages'                  => array( 'އާ ސަފްހާތައް' ),
+	'CreateAccount'             => array( 'މެމްބަރުކަން_ހާސިލްކުރައްވާ' ),
+	'Emailuser'                 => array( 'މެމްބަރަށް_އީ-މެއިލް_ފޮނުވާ' ),
+	'BlockList'                 => array( 'ބްލޮކް_ކުރެވިފައިވާ_ލިސްޓް' ),
+	'Listfiles'                 => array( 'ފައިލް_ލިސްޓް' ),
+	'Log'                       => array( 'ލޮގު' ),
+	'Longpages'                 => array( 'ދިގު_ސަފްޙާތައް' ),
+	'Mypage'                    => array( 'މަގޭ_ޞަފްޙާ' ),
+	'Mytalk'                    => array( 'މަގޭ_ވާހަކަ' ),
+	'Myuploads'                 => array( 'މަގޭ_ފައިލުތައް' ),
+	'Newimages'                 => array( 'އާ_ފައިލް' ),
+	'Newpages'                  => array( 'އާ_ސަފްހާތައް' ),
 	'Preferences'               => array( 'ތަރުޖީހުތައް' ),
-	'Protectedpages'            => array( 'ދިފާޢުކުރެވިފައިވާ ސަފްޙާތައް' ),
-	'Randompage'                => array( 'ކޮންމެވެސް ސަފްޙާއެއް' ),
-	'Recentchanges'             => array( 'އެންމެ ފަހުގެ ބަދަލްތައް' ),
-	'Shortpages'                => array( 'ކުރު ސަފްޙާތައް' ),
-	'Specialpages'              => array( 'ޙާއްސަ ސަފްޙާތައް' ),
-	'Uncategorizedtemplates'    => array( 'ޤިސްމުކުރެވިފައި ނުވާ ފަންވަތް' ),
-	'Unusedcategories'          => array( 'ބޭނުން ނުކުރާ ޤިސްމުތައް' ),
-	'Unusedimages'              => array( 'ބޭނުން ނުކުރާ ފައިލް' ),
+	'Protectedpages'            => array( 'ދިފާޢުކުރެވިފައިވާ_ސަފްޙާތައް' ),
+	'Protectedtitles'           => array( 'ދިފާޢުކުރެވިފައިވާ_ނަންތައް' ),
+	'Randompage'                => array( 'ކޮންމެވެސް_ސަފްޙާއެއް' ),
+	'Recentchanges'             => array( 'އެންމެ_ފަހުގެ_ބަދަލުތައް' ),
+	'Search'                    => array( 'ހޯއްދަވާ' ),
+	'Shortpages'                => array( 'ކުރު_ސަފްޙާތައް' ),
+	'Specialpages'              => array( 'ޙާއްސަ_ސަފްޙާތައް' ),
+	'Statistics'                => array( 'ތަފާސްހިސާބު' ),
+	'Uncategorizedpages'        => array( 'ޤިސްމުކުރެވިފައިނުވާ_ޞަފްޙާތައް' ),
+	'Uncategorizedtemplates'    => array( 'ޤިސްމުކުރެވިފައިނުވާ_ފަންވަތް' ),
+	'Unusedcategories'          => array( 'ބޭނުން_ނުކުރާ_ޤިސްމުތައް' ),
+	'Unusedimages'              => array( 'ބޭނުން_ނުކުރާ_ފައިލް' ),
+	'Unusedtemplates'           => array( 'ބޭނުންނުކުރާ_ފަންވަތްތައް' ),
 	'Upload'                    => array( 'ފޮނުއްވާ' ),
 	'Userlogin'                 => array( 'ވަދެވަޑައިގަންނަވާ' ),
-	'Userlogout'                => array( 'ބޭރަށް ވަޑައިގަންނަވާ' ),
+	'Userlogout'                => array( 'ބޭރަށް_ވަޑައިގަންނަވާ' ),
+	'Wantedcategories'          => array( 'ބޭނުންވާ_ޤިސްމުތައް' ),
+	'Wantedfiles'               => array( 'ބޭނުންވާ_ފައިލުތައް' ),
+	'Wantedpages'               => array( 'ބޭނުންވާ_ޞަފްޙާތައް' ),
+	'Wantedtemplates'           => array( 'ބޭނުންވާ_ފަންވަތްތައް' ),
+	'Watchlist'                 => array( 'މަގޭ_ނަޒަރު' ),
 );
 
 $messages = array(
@@ -232,7 +261,7 @@ $messages = array(
 $1',
 'pool-errorunknown' => 'ކޮންމެވެސް ކުށެއް',
 
-# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
+# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage).
 'aboutsite' => '{{SITENAME}}ގެ ތަޢާރަފު',
 'aboutpage' => 'Project:ތަޢާރަފު',
 'copyright' => 'ހުރިހާ މާއްދާއެއް $1 ގެ ދަށުން ލިބެން އެބަހުއްޓެވެ.',
@@ -242,7 +271,6 @@ $1',
 'disclaimers' => 'އިއުލާނުތައް',
 'disclaimerpage' => 'Project:ޢާއްމު ޢިއުލާނުތައް',
 'edithelp' => 'ބަދަލުތައް ގެނައުމަށް އެހީ އެއް',
-'edithelppage' => 'އެހީ: އުނިއިތުރު ގެންނެވުން',
 'helppage' => 'Help:ފިހުރިސްތު',
 'mainpage' => 'މައި ޞަފްޙާ',
 'mainpage-description' => 'މައި ޞަފްޙާ',
@@ -348,7 +376,7 @@ $1',
 'newpassword' => 'އައު ސިއްރުބަސް:',
 'retypenew' => 'އައު ސިއްރުބަސް އަލުންލިޔުއްވާ:',
 'resetpass_submit' => 'ސިއްރުބަސް ހަމަޖައްސަވާފައި ވަދެވަޑައިގަންނަވާ',
-'resetpass_success' => 'ތިބެފުޅާގެ ސިއްރުބަސް ބަދަލުކުރެވިއްޖެ. 
+'changepassword-success' => 'ތިބެފުޅާގެ ސިއްރުބަސް ބަދަލުކުރެވިއްޖެ. 
 މިހާރު ވަދެވަޑައިގަންނަވަނީ...',
 'resetpass_forbidden' => 'ސިއްރުބަސް ބަދަލެއް ނުކުރެވޭނެއެވެ',
 'resetpass-submit-loggedin' => 'ސިއްރުބަސް ބަދަލުކުރައްވާ',
@@ -470,7 +498,6 @@ $1',
 'shown-title' => 'ދައްކަވާނީ ޞަފްޙާއަކަށް $1 {{PLURAL:$1|ނަތީޖާ|ނަތީޖާ }}',
 'viewprevnext' => 'ބައްލަވާ($1 {{int:pipe-separator}} $2) ($3).',
 'searchmenu-new' => "''' މި ވިކީގައި \"[[:\$1]]\" ފަށްޓަވައިދެއްވާ! '''",
-'searchhelp-url' => 'Help:ފިހުރިސްތު',
 'searchprofile-articles' => 'މަޒުމޫނު ޞަފްޙާތައް',
 'searchprofile-project' => 'އެހީ ޞަފްޙާތަކާއި މަޝްރޫޢު ޞަފްޙާތައް',
 'searchprofile-images' => 'މަލްޓިމީޑިއާ',
@@ -707,7 +734,6 @@ Also see [[Special:WantedCategories|wanted categories]].',
 'blocklink' => 'ފިޔަވަޅުއަޅުއްވާ',
 'unblocklink' => 'ފިޔަވަޅުއެޅުން ބަދަލުކުރައްވާ',
 'contribslink' => 'ޙިއްޞާ',
-'proxyblocksuccess' => 'ފުރިހަމަވެއްޖެ.',
 
 # Developer tools
 'lockdb' => 'ކޮށާރު ބަންދުކުރައްވާ',
@@ -801,7 +827,7 @@ Also see [[Special:WantedCategories|wanted categories]].',
 # Metadata
 'metadata' => 'މެޓަޑޭޓާ',
 
-# EXIF tags
+# Exif tags
 'exif-imagewidth' => 'ފުޅާމިން',
 'exif-imagelength' => 'އުސްމިން',
 'exif-imagedescription' => 'ތަސްވީރުގެ ސުރުހީ',
