@@ -59,13 +59,13 @@ $messages = array(
 'tog-shownumberswatching' => 'Taishbyn earroo ny h-ymmydeyryn ta freill arrey',
 'tog-oldsig' => "Roie-haishbynys jeh'n screeuys t'ayn hannah:",
 'tog-fancysig' => 'Stiur y screeuys myr wikiteks (gyn kiangley seyr-obbragh)',
-'tog-showjumplinks' => 'Doostey kianglaghyn roshtynagh "lheim dys"',
 'tog-watchlisthideown' => 'Follee my arraghyn hene er my rolley arrey',
 'tog-watchlisthidebots' => 'Follee arraghyn botyn er my rolley arrey',
 'tog-watchlisthideminor' => 'Follee myn-arraghyn er my rolley arrey',
 'tog-watchlisthidepatrolled' => 'Follee arraghyn er nyn scrutaghey er my rolley arrey',
 'tog-ccmeonemails' => 'Cur coip dou jeh dagh post-l verrym da ymmydeyr elley',
 'tog-showhiddencats' => 'Taishbyn ny ronnaghyn follit',
+'tog-useeditwarning' => 'Cur raaue dou my ta mee faagail duillag reaghey gyn sauail yn obbyr jeant aym',
 
 'underline-always' => 'Dagh keayrt',
 'underline-never' => 'Ny jean eh arragh',
@@ -86,16 +86,16 @@ $messages = array(
 'thursday' => 'Jerdein',
 'friday' => 'Jeheiney',
 'saturday' => 'Jesarn',
-'sun' => 'Doon',
-'mon' => 'Lune',
-'tue' => 'Mayrt',
-'wed' => 'Crean',
-'thu' => 'Dein',
-'fri' => 'Hein',
-'sat' => 'Sarn',
+'sun' => 'Jedoonee',
+'mon' => 'Jelune',
+'tue' => 'Jemayrt',
+'wed' => 'Jecrean',
+'thu' => 'Jerdein',
+'fri' => 'Jeheiney',
+'sat' => 'Jesarn',
 'january' => 'Jerrey Geuree',
 'february' => 'Toshiaght Arree',
-'march' => 'Mart',
+'march' => 'Mayrnt',
 'april' => 'Averil',
 'may_long' => 'Boaldyn',
 'june' => 'Mean Souree',
@@ -107,7 +107,7 @@ $messages = array(
 'december' => 'Mee ny Nollick',
 'january-gen' => 'Jerrey Geuree',
 'february-gen' => 'Toshiaght Arree',
-'march-gen' => 'Mart',
+'march-gen' => 'Mayrnt',
 'april-gen' => 'Averil',
 'may-gen' => 'Boaldyn',
 'june-gen' => 'Mean Souree',
@@ -119,7 +119,7 @@ $messages = array(
 'december-gen' => 'Mee ny Nollick',
 'jan' => 'JGeu',
 'feb' => 'TArr',
-'mar' => 'Mart',
+'mar' => 'Mayrnt',
 'apr' => 'Ave',
 'may' => 'Boal',
 'jun' => 'MSou',
@@ -138,9 +138,9 @@ $messages = array(
 'category-empty' => "''Cha nel duillagyn ny meanyn 'sy ronney shoh ec y traa t'ayn.''",
 'hidden-categories' => '{{PLURAL:$1|Ronney follit|Ronnaghyn follit}}',
 'hidden-category-category' => 'Ronnaghyn follit',
-'category-subcat-count' => "{{PLURAL:$2|Ta{{PLURAL:$1|&nbsp;ny $1 fo-ronney|'n $1 'o-ronney|'n $1 'o-ronney|&nbsp;ny $1 fo-ronnaghyn}} shoh ec y ronney shoh, jeh'n lane-sym $2.}}",
+'category-subcat-count' => "{{PLURAL:$2|Ta {{PLURAL:$1|ny $1 fo-ronney|yn $1 'o-ronney|yn $1 'o-ronney|ny $1 fo-ronnaghyn}} shoh ec y ronney shoh, jeh'n lane-sym $2.}}",
 'category-subcat-count-limited' => "{{PLURAL:$1|Ta{{PLURAL:$1|&nbsp;ny $1 fo-ronney|'n $1 'o-ronney|'n $1 'o-ronney|&nbsp;ny $1 fo-ronnaghyn}} shoh ec y ronney shoh.}}",
-'category-article-count' => "Ta{{PLURAL:$1|'n $1 duillag|'n $1 duillag|'n $1 ghuillag| ny $1 duillagyn}} heese 'sy ronney shoh, jeh'n lame-sym $2.",
+'category-article-count' => "Ta {{PLURAL:$1|yn $1 duillag|yn $1 duillag|yn $1 ghuillag| ny $1 duillagyn}} heese 'sy ronney shoh, jeh'n lane-sym $2.",
 'category-article-count-limited' => "Ta{{PLURAL:$1|'n $1 duillag|'n $1 duillag|'n $1 ghuillag|&nbsp;ny $1 duillagyn}} heese 'sy ronney shoh.",
 'category-file-count-limited' => "Ta{{PLURAL:$1|'n $1 coadan|'n $1 choadan|'n $1 choadan|&nbsp;ny $1 coadanyn}} heese 'sy ronney shoh.",
 'listingcontinuesabbrev' => 'tooil.',
@@ -170,7 +170,7 @@ $messages = array(
 'faqpage' => 'Project:FC',
 
 # Vector skin
-'vector-action-addsection' => 'Cooish noa',
+'vector-action-addsection' => 'Cur cooish noa rish',
 'vector-action-delete' => 'Scryss',
 'vector-action-move' => 'Scugh',
 'vector-action-protect' => 'Coadee',
@@ -181,7 +181,7 @@ $messages = array(
 'vector-view-history' => 'Jeeagh er shennaghys',
 'vector-view-view' => 'Lhaih',
 'vector-view-viewsource' => 'Jeeagh er bun',
-'actions' => 'Obbraghyn',
+'actions' => 'Jantyssyn',
 'namespaces' => 'Reamyssyn',
 'variants' => 'Cummaghyn elley',
 
@@ -193,10 +193,10 @@ $messages = array(
 'searchbutton' => 'Ronsee',
 'go' => 'Gow',
 'searcharticle' => 'Gow',
-'history' => 'Shennaghys ny duillag',
+'history' => 'Shennaghys y duillag',
 'history_short' => 'Shennaghys',
 'printableversion' => 'Lhieggan clou',
-'permalink' => 'Kiangley yiarn',
+'permalink' => 'Kiangley beayn',
 'print' => 'Clou',
 'view' => 'Lhaih',
 'edit' => 'Reagh',
@@ -208,7 +208,7 @@ $messages = array(
 'undelete_short' => 'Jee-scryss {{PLURAL:$1|$1 caghlaa|$1 chaghlaa|$1 chaghlaa|$1 caghlaaghyn}}',
 'viewdeleted_short' => 'Jeeagh er {{PLURAL:$1|$1 caghlaa scryssit magh|$1 chaghlaa scryssit magh|$1 chaghlaa scryssit magh|$1 caghlaaghyn scryssit magh}}',
 'protect' => 'Coadee',
-'protect_change' => 'caghlaa',
+'protect_change' => 'ceaghil',
 'protectthispage' => 'Coadee yn duillag shoh',
 'unprotect' => 'Jee-choadee',
 'unprotectthispage' => 'Jee-choadee yn duillag shoh',
@@ -240,7 +240,7 @@ $messages = array(
 'jumptosearch' => 'ronsee',
 'pool-errorunknown' => 'Doilleeid gyn enney',
 
-# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
+# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage).
 'aboutsite' => 'Mychione {{SITENAME}}',
 'aboutpage' => 'Project:Mychione',
 'copyright' => 'Ta stoo ry-gheddyn rere $1.',
@@ -250,7 +250,6 @@ $messages = array(
 'disclaimers' => 'Jiooldeyderyn',
 'disclaimerpage' => 'Project:Obbalys cadjin',
 'edithelp' => 'Cooney reaghee',
-'edithelppage' => 'Help:Reaghey',
 'helppage' => 'Help:Cummal',
 'mainpage' => 'Ard-ghuillag',
 'mainpage-description' => 'Ard-ghuillag',
@@ -287,15 +286,15 @@ $messages = array(
 'site-atom-feed' => 'Scoltey Atom $1',
 'page-rss-feed' => 'Scoltey RSS "$1"',
 'page-atom-feed' => 'Atom Feed "$1"',
-'red-link-title' => '$1 (cha nel y duillag shoh ayn)',
+'red-link-title' => '$1 (cha nel y duillag ayn)',
 'sort-descending' => 'Sorçhee veih smoo',
 'sort-ascending' => 'Sorçhee veih sloo',
 
 # Short words for each namespace, by default used in the namespace tab in monobook
 'nstab-main' => 'Duillag',
-'nstab-user' => 'Duillag yn ymmydeyr',
+'nstab-user' => 'Duillag ymmydeyr',
 'nstab-special' => 'Er lheh',
-'nstab-project' => 'Duillag shalee',
+'nstab-project' => 'Duillag halee',
 'nstab-image' => 'Coadan',
 'nstab-mediawiki' => 'Çhaghteraght',
 'nstab-template' => 'Clowan',
@@ -312,10 +311,10 @@ $messages = array(
 'readonly' => 'Stoyr-fysseree fo ghlass',
 'missing-article' => 'Cha row teks duillag, lhisagh ve er ngeddyn lesh yn ennym "$1" $2, feddynit ec y stoyr-fysseree.
 
-Dy cadjin, shen eiyrtys criggal er kiangley caghlaaee ny shennaghys ta ass date as kianglt rish dys duillag t\'er ny scryssey.
+Dy cadjin, shen eiyrtys criggal er kiangley caghlaaee ny shennaghys ta ass daayt as kianglt rish dys duillag va scryssit magh roish shoh.
 
-Mannagh vel, foddee dy vel doghan \'sy chooid vog feddynit magh ayd.<br />
-Cur coontey jeh da [[Special:ListUsers/sysop|reireyder]], as goaill stiagh yn URL my saillt.',
+Mannagh vel, foddee dy vel doghan \'sy chooid vog feddynit magh eu.<br />
+Cur-shiu coontey jeh da [[Special:ListUsers/sysop|reireyder]], as goaill stiagh yn URL my sailliu.',
 'missingarticle-rev' => '(caghlaa#: $1)',
 'missingarticle-diff' => '(Caghlaa: $1, $2)',
 'internalerror' => 'Marranys ynveanagh',
@@ -325,14 +324,13 @@ Cur coontey jeh da [[Special:ListUsers/sysop|reireyder]], as goaill stiagh yn UR
 'badarticleerror' => 'Cha nod oo jannoo yn obbyr shen er y duillag shoh.',
 'cannotdelete-title' => 'Gyn jargaght y duillag "$1" y scryssey',
 'badtitle' => 'Drogh-ennym',
-'badtitletext' => "Va marranys ayn bentyn rish ennym ny duillag v'ou shirrey. Foddee dy row eh follym ny gyn vree, ny kianglt dy moal myr kiangley eddyr-wiki. Foddee dy vel cowraghyn 'syn ennym nagh nod oo jannoo ymmyd jeu ayns enmyn.",
+'badtitletext' => "Va marranys ayn bentyn rish ennym y duillag v'ou shirrey. Foddee dy row eh follym ny gyn vree, ny kianglt dy moal myr kiangley eddyr-wiki. Foddee dy vel cowraghyn 'syn ennym nagh nod oo jannoo ymmyd jej ayns enmyn.",
 'viewsource' => 'Jeeagh er bun',
 'viewsource-title' => 'Jeeagh er bun $1',
 'actionthrottled' => 'Obbyr er ny phlooghey',
 'actionthrottledtext' => "Myr saase noi-spam, cha nod oo jannoo yn obbyr shoh rouyr keayrtyn ayns tammylt beg, as t'ou er roshtyn yn earroo smoo.  Jean eab noa dy gerrid, my saillt.",
 'protectedpagetext' => "Ta'n duillag shoh fo ghlass, as cha nod oo eshyn y reaghey.",
 'viewsourcetext' => 'Foddee oo jeeagh as jean aascreeuyn er bun ny duillag shoh:',
-'sqlhidden' => '(briaght SQL follit)',
 'namespaceprotected' => "Cha nel kiart ayd duillagyn 'sy reamys '''$1''' y reaghey.",
 'ns-specialprotected' => 'Cha nod oo reaghey duillagyn er lheh.',
 
@@ -344,7 +342,7 @@ Cur coontey jeh da [[Special:ListUsers/sysop|reireyder]], as goaill stiagh yn UR
 # Login and logout pages
 'yourname' => "Dt'ennym ymmydeyr:",
 'yourpassword' => 'Fockle yn arrey:',
-'yourpasswordagain' => "Aascreeu d'ockle arrey:",
+'yourpasswordagain' => "Aascreeu dt'ockle arrey:",
 'remembermypassword' => "Cooinnee m'ockle arrey (rish wheesh as $1 {{PLURAL:$1|laa|laa|laa|laaghyn}})",
 'login' => 'Log stiagh',
 'nav-login-createaccount' => 'Log stiagh / croo coontys',
@@ -359,7 +357,7 @@ Cur coontey jeh da [[Special:ListUsers/sysop|reireyder]], as goaill stiagh yn UR
 'createaccount' => 'Croo coontys',
 'gotaccount' => "Vel coontys ayd hannah? '''$1'''.",
 'gotaccountlink' => 'Log stiagh',
-'createaccountmail' => 'Liorish post-L',
+'createaccountmail' => "Croo fockle arrey shallidagh gyn tort as cur eh da'n post-l reiht ayd",
 'createaccountreason' => 'Fa:',
 'loginerror' => 'Marranys loggal stiagh',
 'createaccounterror' => 'Cha nod shin croo coontys: $1',
@@ -425,7 +423,7 @@ Fockle arrey shallidagh: $2',
 'headline_sample' => 'Teks y chione-linney',
 'headline_tip' => 'Kione-linney corrym 2',
 'nowiki_sample' => 'Cur stiagh teks gyn cummey ayns shoh',
-'nowiki_tip' => 'Ny chur tastey da cummey wikiagh',
+'nowiki_tip' => 'Ny chur tastey da cummey wiki',
 'image_tip' => 'Coadan jingit',
 'media_tip' => 'Kiangley yn choadan',
 'sig_tip' => "Dt'ennym screeuit lesh clouag hraa",
@@ -434,15 +432,15 @@ Fockle arrey shallidagh: $2',
 # Edit pages
 'summary' => 'Giare-choontey:',
 'subject' => 'Cooish/kione-linney:',
-'minoredit' => 'She myn-arraghey eh shoh',
+'minoredit' => 'She myn-reaghey eh shoh',
 'watchthis' => 'Freill arrey er y duillag shoh',
 'savearticle' => 'Sauail y duillag',
 'preview' => 'Roie-haishbynys',
 'showpreview' => 'Taishbyn roie-haishbynys',
 'showlivepreview' => 'Roie-haishbynys bio',
 'showdiff' => 'Taishbyn caghlaaghyn',
-'anoneditwarning' => "'''Raaue:''' Cha nel ou loggit stiagh.
-Bee dt'enmys IP recortyssit ayns shennaghys reaghey yn duillag shoh.",
+'anoneditwarning' => "'''Raaue:''' Cha nel oo loggit stiagh.
+Bee dt'enmys IP recortyssit ayns shennaghys reaghee yn duillag shoh.",
 'missingcommenttext' => 'Taggloo er heese, my sailt.',
 'summary-preview' => 'Roie-haishbynys y ghiare-choontey:',
 'subject-preview' => 'Roie-haishbynys cooish/kione-linney:',
@@ -468,17 +466,21 @@ She $3 dt'enmys IP roie, as she dt'enney ghlass na #$5. Cur ad lesh dagh ooilley
 Foddee oo ceaghley yn fockle arrey noa da'n choontys noa shoh er duillag ''[[Special:ChangePassword|cheaghley fockle yn arrey]]'' lurg loggal stiagh.",
 'newarticle' => '(Noa)',
 'newarticletext' => 'T’ou er jeet trooid kiangley dys duillag nagh vel ayn foast.
-Son dy chroo y duillag, gow toshiaght screeuyn ‘sy chishtey çheu heese jeh shoh (jeeagh er [[{{MediaWiki:Helppage}}|duillag y chooney]] son ny smoo fys).
-My haink oo dys shoh trooid marranys, crig er cramman ‘erash’ yn jeeagheyder ayd.',
+My vel oo geearree yn duillah shoh y chroo, gow toshiaght screeuyn ‘sy chishtey çheu heese jeh shoh (jeeagh er [[{{MediaWiki:Helppage}}|y duillag choonee]] son tooilley oayllys).
+My haink oo dys shoh fo marranys, crig er cramman ‘erash’ jeh’n jeeagheyder ayd.',
 'noarticletext' => "Cha nel teks 'sy duillag shoh ec y traa t'ayn.
-Foddee oo [[Special:Search/{{PAGENAME}}|ronsaghey enmys ny duillag shoh]] ayns duillagyn elley,
+Foddee oo [[Special:Search/{{PAGENAME}}|ronsaghey enmys y duillag shoh]] ayns duillagyn elley,
 <span class=\"plainlinks\">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} jannoo ronsaghey 'sy lioaryn cooishyn ta bentyn r'ee],
 ny [{{fullurl:{{FULLPAGENAME}}|action=edit}} reaghey yn duillag shoh]</span>.",
+'noarticletext-nopermission' => "Cha nel teks 'sy duillag shoh ec y traa t'ayn.
+Foddee oo [[Special:Search/{{PAGENAME}}|ronsaghey enmys y duillag shoh]] ayns duillagyn elley,
+<span class=\"plainlinks\">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} ny jannoo ronsaghey 'sy lioaryn cooishyn ta bentyn r'ee]</span>,
+agh cha nel kied ayd yn duillag y chroo.",
 'note' => "'''Note:'''",
 'previewnote' => "'''Cooinnee nagh vel agh roie-haishbynys eh shoh;
 cha nel dty chaghlaaghyn sauailt foast!'''",
 'editing' => 'Reaghey $1',
-'editingsection' => 'Reaghey $1 (meer)',
+'editingsection' => 'Reaghey $1 (rheynn)',
 'editingcomment' => 'Reaghey $1 (meer noa)',
 'yourtext' => 'Dty heks',
 'storedversion' => 'Lhieggan stoyrit',
@@ -496,31 +498,33 @@ Chammah as shen, t’ou gialdyn dooin dy screeu oo hene eh, ny ren oo coip jeh n
 Foddee shiu goll er ash as reaghey duillag t'ayn nish, ny [[Special:UserLogin|loggal stiagh ny croo coontys]].",
 'nocreate-loggedin' => 'Cha nel kied ayd duillagyn noa y chroo er {{SITENAME}}.',
 'permissionserrorstext-withaction' => 'Cha nel kiart ayd $2, er {{PLURAL:$1|y fa|y fa|y fa|ny faghyn}} heese:',
-'recreate-moveddeleted-warn' => "'''Raaue: Ta shiu aachroo duillag as eh er ve scrysst roie.'''
+'recreate-moveddeleted-warn' => "'''Raaue: T’ou aachroo duillag as eh er ve scrysst hannah hene.'''
 
 By chair dhyt smooinagh vel eh kiart goll er oai lesh reaghey yn duillag shoh.<br />
 Ta lioar ny scryssaghyn magh kiarit ayns shoh rere dty chaays hene:",
+'editwarning-warning' => "My faagys oo y duillag, hed caghlaaghyn erbee er coayl, foddee.
+My t'ou uss loggalt stiagh, foddee oo lhiettal y raaue shoh 'sy tosheeaghtyn ayd, 'sy rheynn \"Reaghey\".",
 
 # Account creation failure
 'cantcreateaccounttitle' => 'Cha nod coontys y chroo',
 
 # History pages
-'viewpagelogs' => 'Jeeagh er lioaryn cooishyn ny duillag shoh',
+'viewpagelogs' => 'Jeeagh er ny lioaryn cooishyn son y duillag shoh',
 'currentrev' => 'Aavriwnys roie',
-'currentrev-asof' => 'Aavriwnys roie er $1',
+'currentrev-asof' => "Aavriwnys s'noa er $1",
 'revisionasof' => 'Aavriwnys veih $1',
 'revision-info' => 'Aavriwnys veih $1 ec $2',
 'previousrevision' => '←Aavriwnys ny shinney',
 'nextrevision' => 'Aavriwnys ny saa→',
-'currentrevisionlink' => 'Aavriwnys roie',
-'cur' => 'traa',
+'currentrevisionlink' => 'Aavriwnys s’noa',
+'cur' => 'bio',
 'next' => 'nah',
 'last' => 'roish',
 'page_first' => 'Kied',
 'page_last' => 'roish',
 'histlegend' => "Reih anchaslys: jean reih kiarkil reih ny lhiegganyn by vie lhiat cosoylaghey ad, as crig er \"enter\", ny er y cramman ec cass y rolley.<br />
 Ogher: '''({{int:cur}})''' = anchaslyssyn rish y lhieggan t'ayn nish,
-'''({{int:last}})''' = anchaslyssyn rish y lhieggan roish, '''{{int:minoreditletter}}''' = mynchaghlaa",
+'''({{int:last}})''' = anchaslyssyn rish y lhieggan roish, '''{{int:minoreditletter}}''' = myn-reaghey",
 'history-fieldset-title' => 'Femblal shennaghys',
 'histfirst' => 'By hoshee',
 'histlast' => 'By yerree',
@@ -538,7 +542,7 @@ Ogher: '''({{int:cur}})''' = anchaslyssyn rish y lhieggan t'ayn nish,
 'rev-showdeleted' => 'taishbyn',
 'revdelete-hide-image' => 'Follee cummal y choadan',
 'revdelete-log' => 'Fa:',
-'revdel-restore' => 'ceaghley leayrid',
+'revdel-restore' => 'ceaghil leayrid',
 'pagehist' => 'Shennaghys y duillag',
 'deletedhist' => 'Shennaghys scryssit',
 
@@ -557,12 +561,12 @@ Ogher: '''({{int:cur}})''' = anchaslyssyn rish y lhieggan t'ayn nish,
 # Diffs
 'history-title' => 'Shennaghys aavriwnys dy "$1"',
 'lineno' => 'Linney $1:',
-'compareselectedversions' => 'Cosoylaghey ny lhiegganyn reiht',
-'editundo' => 'rassey',
+'compareselectedversions' => 'Cosoylee ny lhiegganyn reiht',
+'editundo' => 'rass',
 
 # Search results
-'searchresults' => 'Eiyrtyssyn y ronsaghey',
-'searchresults-title' => 'Eiyrtyssyn y ronsaghey er son "$1"',
+'searchresults' => 'Eiyrtyssyn y ronsee',
+'searchresults-title' => 'Eiyrtyssyn y ronsee son "$1"',
 'searchresulttext' => 'Son ny smoo oayllys mychione ronsaghtyn er {{SITENAME}}, jeeagh er [[{{MediaWiki:Helppage}}|{{int:help}}]].',
 'searchsubtitle' => 'Ren oo ronsaghey er \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|dagh duillag ta toshiaghey lesh "$1"]]{{int:pipe-separator}}[[Special:WhatLinksHere/$1|dagh duillag ta kianglt rish "$1"]])',
 'searchsubtitleinvalid' => "Ren oo ronsaghey er '''$1'''",
@@ -570,9 +574,16 @@ Ogher: '''({{int:cur}})''' = anchaslyssyn rish y lhieggan t'ayn nish,
 'notextmatches' => 'Cha nel shen ry-lhaih er duillag erbee',
 'prevn' => '{{PLURAL:$1|$1}} roish shoh',
 'nextn' => 'nah {{PLURAL:$1|$1}}',
+'shown-title' => 'Taishbyn $1 {{PLURAL:$1|eiyrtys|eiyrtyssyn}} er dagh duillag',
 'viewprevnext' => 'Jeeagh er ($1 {{int:pipe-separator}} $2) ($3)',
-'searchhelp-url' => 'Help:Cummal',
+'searchmenu-new' => "'''Croo yn duillag \"[[:\$1]]\" er y wiki shoh!'''",
+'searchprofile-articles' => 'Duillagyn cummal',
 'searchprofile-project' => 'Duillagyn Coonee as Shalee',
+'searchprofile-everything' => 'Dagh red',
+'searchprofile-articles-tooltip' => 'Ronsee ayns $1',
+'searchprofile-project-tooltip' => 'Ronsee ayns $1',
+'searchprofile-images-tooltip' => 'Ronsee coadanyn',
+'searchprofile-everything-tooltip' => 'Ronsee dagh red (goaill stiagh duillagyn resoonaght)',
 'search-result-size' => "$1 ({{PLURAL:$2|1 fockle|$2 'ockle|$2 'ockle|$2 focklyn}})",
 'search-result-score' => 'Bentynys: $1%',
 'search-redirect' => '(aa-enmyssit ass $1)',
@@ -594,9 +605,6 @@ My t'ou uss son ronsaghey dagh cooid (as shen goaill stiagh duillagyn resooney,
 'powersearch-field' => 'Ronsee er son',
 'search-external' => 'Ronsaghey mooie',
 
-# Quickbar
-'qbsettings-none' => 'Veg',
-
 # Preferences page
 'preferences' => 'Tosheeaghtyn',
 'mypreferences' => 'My hosheeaghtyn',
@@ -734,9 +742,9 @@ My bailliu eh y chiarail, bee eh ymmydit son cur gys lieh y chur dhyt er son yn
 'recentchanges' => "Caghlaaghyn s'noa",
 'recentchanges-legend' => "Reihyssyn da ny caghlaaghyn s'noa",
 'recentchanges-summary' => "Shirrey ny caghlaaghyn s'noa da'n wiki er y duillag shoh.",
-'recentchanges-feed-description' => "Shirr ny caghlaaghyn jeianagh er y wiki 'sy scoltey shoh.",
+'recentchanges-feed-description' => "Shirr ny caghlaaghyn s'noa er y wiki 'sy scoltey shoh.",
 'recentchanges-label-newpage' => 'Ren y reaghey shoh croo duillag noa',
-'recentchanges-label-minor' => "She myn-arraghey t'ayn",
+'recentchanges-label-minor' => 'She myn-reaghey eh shoh',
 'recentchanges-label-bot' => 'Ren bot y reaghey shoh',
 'rcnote' => "Ny ta heese, she {{PLURAL:$1|ny '''$1''' caghlaa|yn '''$1''' chaghlaa|ny '''$1''' chaghlaa|ny '''$1''' caghlaaghyn}} s'jerree ayns {{PLURAL:$2|ny '''$2''' laa|yn '''$2''' laa|ny '''$2''' laa|ny '''$2''' laaghyn}} s'jerree, kiart ec $4, $5.",
 'rcnotefrom' => "Shoh heese ny caghlaaghyn veih '''$2''' (gys '''$1''' taishbynit).",
@@ -745,7 +753,7 @@ My bailliu eh y chiarail, bee eh ymmydit son cur gys lieh y chur dhyt er son yn
 'rcshowhidebots' => '{{PLURAL:$1|$1 robot|$1 robot|$1 robot|$1 robotyn}}',
 'rcshowhideliu' => '{{PLURAL:$1|$1 ymmydeyr|$1 ymmydeyr|$1 ymmydeyr|$1 ymmydeyryn}} ta loggit stiagh',
 'rcshowhideanons' => '{{PLURAL:$1|$1 ymmydeyr|$1 ymmydeyr|$1 ymmydeyr|$1 ymmydeyryn}} neuenmyssit',
-'rcshowhidepatr' => '$1 arraghyn patrolaghit',
+'rcshowhidepatr' => '$1 arraghyn patrolit',
 'rcshowhidemine' => "$1 m'arraghyn",
 'rclinks' => "Soilshee {{PLURAL:$1|ny $1 caghlaa|yn $1 chaghlaa|ny $1 chaghlaa|ny $1 caghlaaghyn}} s'jerree ayns {{PLURAL:$2|ny $2 laa|yn $2 laa|ny $2 laa|ny $2 laaghyn}} s'jerree<br />$3",
 'diff' => 'anch',
@@ -756,25 +764,24 @@ My bailliu eh y chiarail, bee eh ymmydit son cur gys lieh y chur dhyt er son yn
 'newpageletter' => 'N',
 'boteditletter' => 'r',
 'rc_categories_any' => 'Ronney erbee',
-'rc-enhanced-expand' => 'Taishbyn sonreeaghtyn (ta JavaScript er shirrey)',
+'rc-enhanced-expand' => 'Taishbyn sonreeaghtyn (ta feme er JavaScript)',
 'rc-enhanced-hide' => 'Follee sonreeaghtyn',
 
 # Recent changes linked
-'recentchangeslinked' => 'Caghlaaghyn-vooinjerys',
+'recentchangeslinked' => 'Caghlaaghyn conastagh',
 'recentchangeslinked-feed' => 'Caghlaaghyn-vooinjerys',
-'recentchangeslinked-toolbox' => 'Caghlaaghyn-vooinjerys',
+'recentchangeslinked-toolbox' => 'Caghlaaghyn conastagh',
 'recentchangeslinked-title' => 'Caghlaaghyn bentyn rish "$1"',
-'recentchangeslinked-noresult' => 'Cha nel caghlaa erbee er duillagyn kianglt car y traa taishbynit.',
 'recentchangeslinked-summary' => "Shoh rolley caghlaaghyn va jeant er duillagyn kianglt veih duillag sonrit (ny er olteynyn ronney sonrit).<br />
 Ta duillagyn er [[Special:Watchlist|dty rolley arrey]] ayns '''clou trome'''.",
 'recentchangeslinked-page' => 'Ennym y duillag:',
 'recentchangeslinked-to' => 'Taishbyn caghlaaghyn da ny duillagyn ta kianglt rish y duillag hene, ayns ynnyd jeh shoh',
 
 # Upload
-'upload' => 'Laadey neese coadan',
+'upload' => 'Laad neese coadan',
 'uploadbtn' => 'Laadey neese coadan',
 'uploadnologin' => 'Cha nel oo loggit stiagh',
-'uploadlogpage' => 'Lioar laadyn neese',
+'uploadlogpage' => 'Lioar ny laadyn neese',
 'filename' => 'Ennym y choadan',
 'filedesc' => 'Giare-choontey',
 'fileuploadsummary' => 'Giare-choontey:',
@@ -806,16 +813,16 @@ Ta duillagyn er [[Special:Watchlist|dty rolley arrey]] ayns '''clou trome'''.",
 # File description page
 'file-anchor-link' => 'Coadan',
 'filehist' => 'Shennaghys y choadan',
-'filehist-help' => 'Crig er date/traa ennagh son dy ‘akin y coadan myr v’eh ec y traa shen.',
+'filehist-help' => 'Crig er daayt/am ennagh son fakin er y choadan myr v’eh ec y traa shen.',
 'filehist-deleteall' => 'scryss ooilley',
 'filehist-deleteone' => 'scryss eh shoh',
-'filehist-revert' => 'goll er ash',
+'filehist-revert' => 'cur er ash',
 'filehist-current' => 'bio',
-'filehist-datetime' => 'Date/Am',
+'filehist-datetime' => 'Daayt/Am',
 'filehist-thumb' => 'Ingin-ordaag',
 'filehist-thumbtext' => "Ingin-ordaag da'n lhieggan shoh ec $1",
 'filehist-user' => 'Ymmydeyr',
-'filehist-dimensions' => 'Mooadyssyn',
+'filehist-dimensions' => 'Towshanyn',
 'filehist-filesize' => 'Mooadys y choadan',
 'filehist-comment' => 'Cohaggloo',
 'imagelinks' => 'Ymmyd y choadan',
@@ -864,8 +871,6 @@ Ta duillagyn er [[Special:Watchlist|dty rolley arrey]] ayns '''clou trome'''.",
 'statistics-header-users' => 'Staydraa ymmydeyr',
 'statistics-pages' => 'Duillagyn',
 
-'disambiguations' => 'Duillagyn ta kianglt rish duillagyn reddaghey',
-
 'doubleredirects' => 'Aa-enmyssyn dooblagh',
 
 'brokenredirects' => 'Aa-enmyssyn brisht',
@@ -914,7 +919,7 @@ Ta duillagyn er [[Special:Watchlist|dty rolley arrey]] ayns '''clou trome'''.",
 'newpages' => 'Duillagyn noa',
 'newpages-username' => 'Ennym ymmydeyr:',
 'ancientpages' => 'Duillagyn by hinney',
-'move' => 'Scughey',
+'move' => 'Scugh',
 'movethispage' => 'Yn duillag shoh y scughey',
 'pager-newer-n' => "{{PLURAL:$1|1 ny s'noa|$1 ny s'noa}}",
 'pager-older-n' => '{{PLURAL:$1|1 ny shinney|$1 ny shinney}}',
@@ -922,7 +927,7 @@ Ta duillagyn er [[Special:Watchlist|dty rolley arrey]] ayns '''clou trome'''.",
 
 # Book sources
 'booksources' => 'Bun-gheillyn lioar',
-'booksources-search-legend' => 'Jean ronsaghey er farraneyn lioar',
+'booksources-search-legend' => 'Jean ronsaghey er bun-gheillyn lioar',
 'booksources-go' => 'Gow',
 
 # Special:Log
@@ -1040,10 +1045,10 @@ Aaveaghey as cooney s\'odjey:
 'historywarning' => 'Raaue: Ta shennaghys ec y duillag ta shiu er-chee scryssey magh, as mysh $1 {{PLURAL:$1|caghlaa|chaghlaa|chaghlaa|caghlaaghyn}} er:',
 'confirmdeletetext' => 'Ta shiu er-çhee scryssey magh duillag myrane lesh y shennaghys eck.<br />
 Feeraghey dy vel eh y çhalee ayd eh y yannoo, dy vel ny scanshyn toiggit ayd, as dy vel oo jannoo eh ayns coardailys rish [[{{MediaWiki:Policy-url}}|y pholasee]].',
-'actioncomplete' => 'Obbraghey creaghnit',
+'actioncomplete' => 'Jantys creaghnit',
 'deletedtext' => 'Ta "$1" scrysst.<br />
 Jeeagh er $2 son recortys ny scryssaghyn magh jeianagh.',
-'dellogpage' => 'Lioar scryssaghyn magh',
+'dellogpage' => 'Lioar ny scryssaghyn magh',
 'deletecomment' => 'Fa:',
 'deleteotherreason' => 'Fa elley/tooilley:',
 'deletereasonotherlist' => 'Fa elley',
@@ -1054,7 +1059,7 @@ Jeeagh er $2 son recortys ny scryssaghyn magh jeianagh.',
 
 # Rollback
 'rollback_short' => 'Aahogherys',
-'rollbacklink' => 'aahogherys',
+'rollbacklink' => 'aahogher',
 'editcomment' => "V'eh \"''\$1''\" giare-choontys y reaghey.",
 
 # Protect
@@ -1097,28 +1102,29 @@ Shoh ny reaghaghyn roie da'n duillag '''$1''':",
 'viewdeletedpage' => 'Jeeagh er duillagyn scrysst',
 'undeletebtn' => 'Cur er ash',
 'undeletelink' => 'jeeagh/cur er ash',
+'undeleteviewlink' => 'jeeagh',
 'undeletereset' => 'Aahoiaghey',
 'undeletecomment' => 'Fa:',
 'undelete-search-box' => 'Ronsee ny duillagyn scrysst',
 'undelete-search-submit' => 'Ronsee',
 
 # Namespace form on various pages
-'namespace' => 'Boayl-ennym:',
-'invert' => 'Cur y teiy bun ry-skyn',
+'namespace' => 'Reamys:',
+'invert' => 'Cur y reih bun ry-skyn',
 'blanknamespace' => '(Cadjin)',
 
 # Contributions
 'contributions' => 'Cohortyssyn ymmydeyr',
-'contributions-title' => 'Cohortyssyn ymmydeyr liorish $1',
+'contributions-title' => 'Cohortyssyn liorish $1',
 'mycontris' => 'My chohortyssyn',
 'contribsub2' => 'Da $1 ($2)',
-'uctop' => ' (baare)',
-'month' => "Veih mee (as ny s'aa):",
-'year' => "Veih blein (as ny s'aa):",
+'uctop' => '(baare)',
+'month' => "Veih'n vee (as ny s'aa):",
+'year' => "Veih'n vlein (as ny s'aa):",
 
 'sp-contributions-newbies' => 'Taishbyn cohortyssyn ec coontyssyn noa ny lomarcan',
 'sp-contributions-newbies-sub' => 'Son coontyssyn noa',
-'sp-contributions-blocklog' => 'Lioar chooishyn ghlassaghyn magh',
+'sp-contributions-blocklog' => 'Lioar chooishyn ny glassaghyn magh',
 'sp-contributions-talk' => 'resoonaght',
 'sp-contributions-userrights' => 'Reireydys kiartyn ymmydeyr',
 'sp-contributions-search' => 'Ronsee cohortyssyn',
@@ -1126,7 +1132,7 @@ Shoh ny reaghaghyn roie da'n duillag '''$1''':",
 'sp-contributions-submit' => 'Ronsee',
 
 # What links here
-'whatlinkshere' => 'Cre ta kianglt rish shoh',
+'whatlinkshere' => 'Cre ta kiangley rish shoh',
 'whatlinkshere-title' => 'Duillagyn ta kianglt rish $1',
 'whatlinkshere-page' => 'Duillag:',
 'linkshere' => "Ta ny duillagyn shoh kianglt rish '''[[:$1]]''':",
@@ -1137,9 +1143,9 @@ Shoh ny reaghaghyn roie da'n duillag '''$1''':",
 'whatlinkshere-prev' => '{{PLURAL:$1|roish|y $1 roish}}',
 'whatlinkshere-next' => '{{PLURAL:$1|y nah|y nah $1}}',
 'whatlinkshere-links' => '← kianglaghyn',
-'whatlinkshere-hideredirs' => 'duillagyn aa-enmyssit $1',
+'whatlinkshere-hideredirs' => '$1 duillagyn aa-enmyssit',
 'whatlinkshere-hidetrans' => '$1 duillagyn er nyn ngoaill stiagh',
-'whatlinkshere-hidelinks' => 'kianglaghyn $1',
+'whatlinkshere-hidelinks' => '$1 kianglaghyn',
 'whatlinkshere-filters' => 'Shollaneyn',
 
 # Block/unblock
@@ -1171,16 +1177,15 @@ Shoh ny reaghaghyn roie da'n duillag '''$1''':",
 'ipblocklist-submit' => 'Ronsee',
 'infiniteblock' => 'neuyerrinagh',
 'createaccountblock' => 'crooaght coontys glasst',
-'blocklink' => 'glassey magh',
-'unblocklink' => 'foshley',
-'change-blocklink' => 'caghlaa glass',
+'blocklink' => 'glass magh',
+'unblocklink' => 'jee-ghlass',
+'change-blocklink' => 'ceaghil glass',
 'contribslink' => 'cohortyssyn',
-'blocklogpage' => 'Lioar chooishyn ghlassaghyn magh',
+'blocklogpage' => 'Lioar chooishyn ny glassaghyn magh',
 'blocklogentry' => 'er nglassey magh [[$1]] rish/derrey $2 $3',
 'unblocklogentry' => '$1 er ny neughlassey magh',
 'block-log-flags-anononly' => 'ymmydeyryn neuenmyssit ynrican',
 'block-log-flags-nocreate' => 'gyn kiart coontyssyn y chroo',
-'proxyblocksuccess' => 'Jeant.',
 
 # Move page
 'move-page' => '$1 y scughey',
@@ -1213,9 +1218,9 @@ Reih ennym elley, my sailliu.',
 Jean covestey eddyr oc er laueyn, my sailliu.'''",
 'movedto' => 'aa-enmyssit myr',
 'movetalk' => 'Scugh yn duillag resoonaght eck',
-'movelogpage' => 'Lioar chooishyn y scughey',
+'movelogpage' => 'Scugh y Lioar chooishyn',
 'movereason' => 'Fa:',
-'revertmove' => 'goll er ash',
+'revertmove' => 'cur er ash',
 'delete_and_move' => 'Scryss as scughey',
 'delete_and_move_confirm' => 'Ta, scryss magh y duillag',
 
@@ -1231,7 +1236,7 @@ Jean covestey eddyr oc er laueyn, my sailliu.'''",
 'allmessagescurrent' => 'Teks roie',
 
 # Thumbnails
-'thumbnail-more' => 'Mooadaghey',
+'thumbnail-more' => 'Mooadee',
 'filemissing' => 'Coadan ersooyl',
 'thumbnail_error' => 'Marranys ingin-ordaag y chroo: $1',
 
@@ -1247,59 +1252,60 @@ Jean covestey eddyr oc er laueyn, my sailliu.'''",
 'tooltip-pt-userpage' => 'My ghuillag ymmydeyr',
 'tooltip-pt-mytalk' => 'My ghuillag resoonaght',
 'tooltip-pt-preferences' => 'My hosheeaghtyn',
-'tooltip-pt-watchlist' => 'Rolley duillagyn ta er dty rolley arrey',
+'tooltip-pt-watchlist' => "Rolley ny duillagyn t'er dty rolley arrey",
 'tooltip-pt-mycontris' => 'Rolley my chohortyssyn',
-'tooltip-pt-login' => 'Ta greinnaghey shiu loggal stiagh, cha nel eh anneydagh, ansherbee.',
+'tooltip-pt-login' => 'Ta shin greinnaghey shiu loggal stiagh; ansherbee, cha nel feme er.',
 'tooltip-pt-logout' => 'Log magh',
-'tooltip-ca-talk' => 'Resoonaght mychione ny duillag cummal',
+'tooltip-ca-talk' => 'Resoonaght mychione y duillag chummal',
 'tooltip-ca-edit' => 'Foddee oo reaghey yn duillag shoh. Crig er y chramman roie-haishbynys roish eh y hauail.',
-'tooltip-ca-addsection' => 'Jean rheynn noa',
+'tooltip-ca-addsection' => 'Cur toshiaght rish rheynn noa',
 'tooltip-ca-viewsource' => "Ta'n duillag shoh fo ghlass. Foddee oo jeeagh er e bun.",
 'tooltip-ca-history' => "Shenn aavriwnyssyn jeh'n duillag shoh",
 'tooltip-ca-protect' => 'Coadee yn duillag shoh',
 'tooltip-ca-delete' => 'Scryss y duillag shoh',
-'tooltip-ca-move' => 'Yn duillag y scughey',
+'tooltip-ca-move' => 'Scugh y duillag',
 'tooltip-ca-watch' => 'Cur y duillag shoh rish dty rolley arrey',
-'tooltip-ca-unwatch' => 'Scughey y duillag shoh ass dty rolley arrey',
+'tooltip-ca-unwatch' => 'Gow y duillag shoh magh ass dty rolley arrey',
 'tooltip-search' => 'Ronsee {{SITENAME}}',
-'tooltip-search-go' => 'Immee dys duillag as yn ennym cruinn shoh er, my vees eh ayn',
+'tooltip-search-go' => 'Immee gys duillag as yn ennym cruinn shoh er, my vees eh ayn',
 'tooltip-search-fulltext' => 'Ronsee ny duillagyn er son y teks shoh',
-'tooltip-p-logo' => 'Ard-ghuillag',
-'tooltip-n-mainpage' => 'Cur keayrt er yn Ard-ghuillag',
-'tooltip-n-mainpage-description' => 'Cur keayrt er yn ard-ghuillag',
-'tooltip-n-portal' => "Mychione y çhalee, jean dty chooid share, c'raad reddyn dy feddyn",
-'tooltip-n-currentevents' => 'Fow oayllys shaghadys fo chooishyn yn laa',
-'tooltip-n-recentchanges' => "Rolley caghlaaghyn s'noa ayns y wiki.",
-'tooltip-n-randompage' => 'Duillag gyn tort y laadey',
+'tooltip-p-logo' => 'Gow gys yn ard-ghuillag',
+'tooltip-n-mainpage' => 'Gow gys yn ard-ghuillag',
+'tooltip-n-mainpage-description' => 'Gow gys yn ard-ghuillag',
+'tooltip-n-portal' => "Mychione y çhalee, jean dty chooid share, c'raad reddyn y gheddyn",
+'tooltip-n-currentevents' => 'Fow fysseree shaghadys er cooishyn yn laa',
+'tooltip-n-recentchanges' => "Rolley ny caghlaaghyn s'noa er y wiki.",
+'tooltip-n-randompage' => 'Laad duillag gyn tort',
 'tooltip-n-help' => 'Boayl gys feddyn magh.',
-'tooltip-t-whatlinkshere' => 'Rolley dagh ooilley ghuillag wiki ta kianglt rish shoh',
+'tooltip-t-whatlinkshere' => 'Rolley dagh ooilley ghuillag wiki ta kiangley rish shoh',
 'tooltip-t-recentchangeslinked' => "Caghlaaghyn s'noa er ny duillagyn ta kianglt rish y duillag shoh",
 'tooltip-feed-rss' => "Beaghey RSS da'n duillag shoh",
 'tooltip-feed-atom' => "Beaghey Atom da'n duillag shoh",
 'tooltip-t-contributions' => 'Jeeagh er cohortyssyn yn ymmydeyr shoh',
 'tooltip-t-emailuser' => "Cur post-L da'n ymmydeyr shoh",
-'tooltip-t-upload' => 'Laadey neese coadanyn',
+'tooltip-t-upload' => 'Laad neese coadanyn',
 'tooltip-t-specialpages' => 'Rolley dagh ooilley ghuillag er lheh',
 'tooltip-t-print' => "Lhieggan so-chlou jeh'n duillag shoh",
-'tooltip-t-permalink' => 'Kiangley beayn da aavriwnys ny duillag shoh',
-'tooltip-ca-nstab-main' => 'Jeeagh er duillag y chummal',
+'tooltip-t-permalink' => 'Kiangley beayn da aavriwnys y duillag shoh',
+'tooltip-ca-nstab-main' => 'Jeeagh er y duillag chummal',
 'tooltip-ca-nstab-user' => 'Jeeagh er duillag yn ymmydeyr',
 'tooltip-ca-nstab-special' => "She duillag er lheh t'ayn; cha nod oo reaghey y duillag hene",
-'tooltip-ca-nstab-project' => 'Jeeagh er duillag y halee',
+'tooltip-ca-nstab-project' => 'Jeeagh er y duillag halee',
 'tooltip-ca-nstab-image' => 'Jeeagh er duillag y choadan',
 'tooltip-ca-nstab-mediawiki' => 'Jeeagh er çhaghteraght y chorys',
-'tooltip-ca-nstab-template' => 'Jeeagh er y clowan',
+'tooltip-ca-nstab-template' => 'Jeeagh er y chlowan',
 'tooltip-ca-nstab-help' => 'Jeeagh er duillag y chooney',
 'tooltip-ca-nstab-category' => 'Jeeagh er duillag y ronney',
-'tooltip-minoredit' => 'She myn-arraghey eh shoh',
+'tooltip-minoredit' => 'She myn-reaghey eh shoh',
 'tooltip-save' => 'Sauail dty chaghlaaghyn',
-'tooltip-preview' => 'Roie-haishbyney ny caghlaaghyn ayd; jannoo ymmyd jeh roish sauail, my saillt!',
-'tooltip-diff' => 'Taishbyn caghlaaghyn y teks ta jeant ayd.',
-'tooltip-compareselectedversions' => 'Jeeagh er ny caghlaaghyn eddyr y daa lhieggan reiht y ghuillag shoh.',
+'tooltip-preview' => 'Roie-haishbyn ny caghlaaghyn eu; jean-shiu ymmyd jeh roish sauail, my sailliu!',
+'tooltip-diff' => 'Taishbyn caghlaaghyn y teks ta jeant eu.',
+'tooltip-compareselectedversions' => "Jeeagh er ny caghlaaghyn eddyr y daa lhieggan reiht jeh'n ghuillag shoh.",
 'tooltip-watch' => 'Cur y duillag shoh rish dty rolley arrey',
-'tooltip-rollback' => 'Ta "aahogherys" rassey dagh cohoyrtys yn ymmydeyr s\'jerree da\'n duillag shoh.',
-'tooltip-undo' => "Ta \"rassey\" cur y reaghey shoh er ash as t'eh fosley yn form reaghee ayns mod roie-haishbynys.<br />
+'tooltip-rollback' => 'Ta "aahogher" rassey dagh cohoyrtys jeh\'n ymmydeyr s\'jerree er y duillag shoh.',
+'tooltip-undo' => "Ta \"rass\" cur y reaghey shoh er ash as t'eh foshley yn form reaghee ayns mod roie-haishbynys.<br />
 T'eh lhiggey da oyr y chur 'sy ghiare-choontey.",
+'tooltip-summary' => 'Cur giare-choontey stiagh',
 
 # Attribution
 'anonymous' => '{{PLURAL:$1|Ymmeyder|Ymmeyderny}} neuenmyssit dy {{SITENAME}}',
@@ -1333,7 +1339,7 @@ Kianglaghyn eiyrtyssagh erbee er yn linney shoh, t'ad goll er loaghtey myr lhimm
 
 # Metadata
 'metadata' => 'Metadata',
-'metadata-help' => "Ta'n coadan shoh goaill tooilley oayllys stiagh, currit veih'n shamraig bun-earrooagh ny yn scanreyder as eh ymmydit dys y coadan y chroo ny y yannoo bun-earrooagh, foddee.<br />
+'metadata-help' => "Ta'n coadan shoh goaill tooilley fysseree stiagh, currit veih'n çhamraig vun-earrooagh ny yn scanreyder, as eh ymmydit dys y coadan y chroo ny y yannoo bun-earrooagh, s'liklee.<br />
 My vel y coadan ceaghlit veih'n chummey bunneydagh, foddee nagh beagh mynphoyntyn ennagh cohoilshaghey yn coadan ceaghlit.",
 'metadata-expand' => 'Taishbyn ny sonreeaghtyn sheeynt',
 'metadata-collapse' => 'Follee ny sonreeaghtyn sheeynt',
@@ -1353,7 +1359,7 @@ Bee adsyn elley follit dy seyr-obbragh.<br />
 * gpslongitude
 * gpsaltitude',
 
-# EXIF tags
+# Exif tags
 'exif-imagewidth' => 'Lheead',
 'exif-imagelength' => 'Yrjid',
 'exif-ycbcrpositioning' => 'Soie Y as C',
@@ -1403,7 +1409,7 @@ Bee adsyn elley follit dy seyr-obbragh.<br />
 'exif-gpsspeed-m' => "Meeillaghyn 'syn oor",
 
 # External editor support
-'edit-externally' => 'Reaghey yn coadan shoh lesh sheeyntagh mooie',
+'edit-externally' => 'Reagh yn coadan shoh lesh sheeyntagh mooie',
 'edit-externally-help' => 'Jeeagh er [//www.mediawiki.org/wiki/Manual:External_editors saraghyn soiaghey seose] son tooilley oayllys.',
 
 # 'all' in various places, this might be different for inflected languages
@@ -1439,9 +1445,9 @@ Bee adsyn elley follit dy seyr-obbragh.<br />
 'watchlistedit-raw-titles' => 'Enmyn:',
 
 # Watchlist editing tools
-'watchlisttools-view' => 'Jeeagh er caghlaaghyn bentynagh',
-'watchlisttools-edit' => 'Jeeagh er as reaghey yn rolley arrey',
-'watchlisttools-raw' => 'Reaghey aw-rolley arrey',
+'watchlisttools-view' => 'Jeeagh er caghlaaghyn conastagh',
+'watchlisttools-edit' => 'Jeeagh er as reagh yn rolley arrey',
+'watchlisttools-raw' => 'Reagh yn aw-rolley arrey',
 
 # Special:Version
 'version' => 'Lhieggan',
@@ -1451,9 +1457,6 @@ Bee adsyn elley follit dy seyr-obbragh.<br />
 'version-license' => 'Kiedoonys',
 'version-software-version' => 'Lhieggan',
 
-# Special:FilePath
-'filepath-page' => 'Coadan:',
-
 # Special:FileDuplicateSearch
 'fileduplicatesearch-filename' => 'Ennym y choadan:',
 'fileduplicatesearch-submit' => 'Ronsee',
