@@ -112,6 +112,7 @@ $messages = array(
 'qbbrowse' => 'Bilid',
 'qbedit' => 'Iislan',
 'qbpageoptions' => 'Dya nga Pahina',
+'qbpageinfo' => 'Konteksto',
 'qbspecialpages' => 'Manga espesyal nga pahina',
 'faq' => 'FAQ',
 'faqpage' => 'Project:FAQ',
@@ -134,7 +135,7 @@ $messages = array(
 'delete' => 'Para',
 'deletethispage' => 'Paraun ang dya nga Pahina',
 'protect' => 'Amlig',
-'protect_change' => 'iislan',
+'protect_change' => 'islan ang proteksyon',
 'protectthispage' => 'Amligan ang dya nga pahina',
 'unprotect' => 'huksun ang proteksyon',
 'unprotectthispage' => 'Huksun ang proteksyon sa dya nga pahina',
@@ -187,7 +188,7 @@ Lantawa sa [[Special:Version|version kang page]].',
 # Short words for each namespace, by default used in the namespace tab in monobook
 'nstab-main' => 'Pahina',
 'nstab-media' => 'Pahina kang Midya',
-'nstab-special' => 'Espesyal nga pahina',
+'nstab-special' => 'Espesyal',
 'nstab-project' => 'Pahina kang Proyekto',
 'nstab-image' => 'Inayap',
 'nstab-mediawiki' => 'Mensahe',
@@ -210,7 +211,7 @@ Lantawa sa [[Special:Version|version kang page]].',
 'viewsource' => 'Turukun ang ginhalinan',
 
 # Login and logout pages
-'remembermypassword' => "Tandaan ang akun nga ''log-in'' sa dya nga ''browser'' (kang maximum nga $1 {{PLURAL:$1|ka adlaw|ka mga adlaw}})",
+'remembermypassword' => "Tandaan ang akun nga ''log-in'' sa dya nga ''computer'' (for a maximum of $1 {{PLURAL:$1|day|days}})",
 'nologinlink' => "Himo ka sangka ''account''",
 'createaccount' => "Himo ka ''account''",
 
@@ -255,7 +256,7 @@ Lantawa sa [[Special:Version|version kang page]].',
 # Special:ListUsers
 'listusers-submit' => 'Ipakita',
 
-# Email user
+# E-mail user
 'emailmessage' => 'Mensahe',
 
 # Delete
@@ -267,7 +268,7 @@ Lantawa sa [[Special:Version|version kang page]].',
 # Undelete
 'undelete-search-submit' => 'Sagap',
 
-'sp-contributions-talk' => 'wakal',
+'sp-contributions-talk' => 'Wakal',
 'sp-contributions-submit' => 'Sagap',
 
 # What links here
