@@ -1,5 +1,5 @@
 <?php
-/** Neapolitan (Nnapulitano)
+/** Neapolitan (Napulitano)
  *
  * See MessagesQqq.php for message documentation incl. usage of parameters
  * To improve a translation please visit http://translatewiki.net
@@ -95,16 +95,16 @@ $messages = array(
 'may_long' => 'màjo',
 'june' => 'giùgno',
 'july' => 'luglio',
-'august' => 'aústo',
+'august' => 'aùsto',
 'september' => 'settembre',
-'october' => 'ottobbre',
+'october' => 'ottovre',
 'november' => 'nuvembre',
 'december' => 'dicèmbre',
 'january-gen' => 'jennaro',
 'february-gen' => 'frevaro',
 'march-gen' => 'màrzo',
 'april-gen' => 'abbrile',
-'may-gen' => 'maggio',
+'may-gen' => 'majo',
 'june-gen' => 'giùgno',
 'july-gen' => 'luglio',
 'august-gen' => 'aùsto',
@@ -124,6 +124,18 @@ $messages = array(
 'oct' => 'ott',
 'nov' => 'nuv',
 'dec' => 'dic',
+'january-date' => '$1 jennaro',
+'february-date' => '$1 frevaro',
+'march-date' => '$1 màrzo',
+'april-date' => '$1 abbrile',
+'may-date' => '$1 majo',
+'june-date' => '$1 giùgno',
+'july-date' => '$1 luglio',
+'august-date' => '$1 aùsto',
+'september-date' => '$1 settembre',
+'october-date' => '$1 ottovre',
+'november-date' => '$1 nuvembre',
+'december-date' => '$1 dicembre',
 
 # Categories related messages
 'pagecategories' => '{{PLURAL:$1|Categurìa|Categurìe}}',
@@ -134,29 +146,39 @@ $messages = array(
 'category-subcat-count' => "{{PLURAL:$2|Chesta categurìa cuntene n'unneca sottocategurìa, nzignata 'e seguito.|Chesta categurìa cuntene {{PLURAL:$1|'a sottocategurìa nzignata|'e $1 sottocategurìe nzignate}} 'e seguito, 'a nu totale 'e $2.}}",
 'category-article-count' => "{{PLURAL:$2|Chesta categurìa cuntiene un'unneca paggena, nzignata ccà sotto.|Chesta categurìa cuntiene {{PLURAL:$1|'a paggena nzignata|'e $1 paggene nzignate}} ccà sotto, faccenno nu totale 'e $2.}}",
 'listingcontinuesabbrev' => 'cont.',
+'index-category' => 'Paggene ennecezzate',
+'noindex-category' => 'Paggene nun ennecezzate',
+'broken-file-category' => "Paggene cca 'ncludono file 'nesistente",
 
 'about' => 'Nfromma',
 'article' => 'Articulo',
 'newwindow' => "(s'arape n'ata fenèsta)",
 'cancel' => 'Scancèlla',
 'moredotdotdot' => 'Cchiù...',
+'morenotlisted' => 'Atro...',
 'mypage' => 'Paggena',
 'mytalk' => "'E mmie chiàcchieriate",
 'anontalk' => 'Chiacchierate pe chisto IP',
 'navigation' => 'Navigazzione',
+'and' => '&#32;e',
 
 # Cologne Blue skin
 'qbfind' => 'Truòva',
+'qbbrowse' => 'Sfoglia',
 'qbedit' => 'Càgna',
 'qbpageoptions' => 'Chesta paggena',
 'qbmyoptions' => "'E ppaggene mie",
 'qbspecialpages' => 'Pàggene speciàle',
 'faq' => 'FAQ',
+'faqpage' => 'Project:Domanne frequente',
 
 # Vector skin
+'vector-action-addsection' => 'Aggiunge chiacchierata',
 'vector-action-delete' => 'Scancèlla',
 'vector-action-move' => 'Spusta',
 'vector-action-protect' => 'Prutegge',
+'vector-action-undelete' => 'Ripristina',
+'vector-action-unprotect' => 'Càgna prutezzione',
 'vector-view-create' => 'Cria',
 'vector-view-edit' => 'Càgna',
 'vector-view-history' => 'Vere cronologgia',
@@ -166,6 +188,7 @@ $messages = array(
 'namespaces' => 'Namespace',
 'variants' => 'Variante',
 
+'navigation-heading' => "Menu 'e navigazzione",
 'errorpagetitle' => 'Sbaglio',
 'returnto' => 'Torna a $1.',
 'tagline' => 'Dda {{SITENAME}}.',
@@ -176,15 +199,19 @@ $messages = array(
 'searcharticle' => 'Vàje',
 'history' => "Verziune 'e primma",
 'history_short' => 'Cronologgia',
+'updatedmarker' => "cagnamiénte 'e mija urdema visita",
 'printableversion' => "Verzione pe' stampa",
 'permalink' => 'Jonta permanente',
+'print' => 'Stampà',
+'view' => 'Vere',
 'edit' => 'Càgna',
 'create' => 'Cria',
 'editthispage' => 'Càgna chesta paggena',
 'create-this-page' => 'Cria sta paggena',
 'delete' => 'Scancèlla',
 'deletethispage' => 'Scancèlla chésta paggena',
-'protect' => 'Ferma',
+'undeletethispage' => 'Ripristina chista paggena',
+'protect' => 'Prutegge',
 'protect_change' => 'càgna',
 'protectthispage' => 'Ferma chesta paggena',
 'unprotect' => 'Càgna prutezzione',
@@ -200,29 +227,38 @@ $messages = array(
 'views' => 'Visite',
 'toolbox' => 'Strumiente',
 'userpage' => 'Vere a paggena utente',
+'projectpage' => "Vere a paggena 'e servizio",
 'imagepage' => 'Vere a paggena ddo file',
-'otherlanguages' => 'Ate léngue',
+'mediawikipage' => "Vere 'a mmasciata",
+'templatepage' => "Vere 'o template",
+'viewhelppage' => "Vere 'a paggena 'e ajùto",
+'categorypage' => "Vere 'a categurìa",
+'viewtalkpage' => "Vere 'a paggena 'e chiàcchierate",
+'otherlanguages' => 'Ate lengue',
 'redirectedfrom' => "(Redirect 'a $1)",
+'redirectpagesub' => "Paggena 'e redirect",
 'lastmodifiedat' => "Urdema cagnamiénto pe' a paggena: $2, $1.",
 'viewcount' => 'Chesta paggena è stata lètta {{PLURAL:$1|una vòta|$1 vòte}}.',
 'protectedpage' => 'Paggena prutetta',
 'jumpto' => 'Vaje a:',
 'jumptonavigation' => 'navigazione',
 'jumptosearch' => 'truova',
+'pool-errorunknown' => 'Errore scanusciuto',
 
-# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
+# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage).
 'aboutsite' => "'Nfrummazione ncòpp'a {{SITENAME}}",
 'aboutpage' => "Project:'Nfrummazione",
+'copyright' => "Cuntenuti suggietti a licienza 'e uso $1.",
 'copyrightpage' => '{{ns:project}}:Copyrights',
 'currentevents' => 'Novità',
 'currentevents-url' => 'Project:Novità',
 'disclaimers' => 'Avvertimiènte',
 'disclaimerpage' => 'Project:Avvertimiènte generale',
 'edithelp' => 'Guida',
-'edithelppage' => 'Help:Càgna',
 'helppage' => 'Help:Ajùto',
 'mainpage' => 'Paggena prencepale',
 'mainpage-description' => 'Paggena prencepale',
+'policy-url' => 'Project:Policy',
 'portal' => "Porta d''a cummunetà",
 'portal-url' => "Project:Porta d''a cummunetà",
 'privacy' => "'Nformazzione ppe a privacy",
@@ -230,21 +266,27 @@ $messages = array(
 
 'badaccess' => "Nun haje 'e premmesse abbastante.",
 
+'ok' => 'OK',
 'retrievedfrom' => 'Estratto \'e "$1"',
 'youhavenewmessages' => 'Haje $1 ($2).',
-'newmessageslink' => "nuove 'mmasciàte",
+'newmessageslink' => "nove 'mmasciàte",
 'newmessagesdifflink' => "differenze cu 'a revisione precedente",
 'youhavenewmessagesmulti' => 'Tiene nuove mmasciate $1',
 'editsection' => 'càgna',
 'editold' => 'càgna',
+'viewsourceold' => 'vere sorgente',
 'editlink' => 'càgna',
 'viewsourcelink' => 'Vere sorgente',
 'editsectionhint' => 'Modifica a sezzione $1',
 'toc' => 'Énnece',
 'showtoc' => 'faje vedé',
 'hidetoc' => 'annascunne',
+'collapsible-expand' => 'faje vede',
+'thisisdeleted' => 'Vere o ripristina $1?',
 'viewdeleted' => 'Vire $1?',
+'feedlinks' => 'Feed:',
 'site-atom-feed' => "Feed Atom 'e $1",
+'page-atom-feed' => 'Feed Atom ppe "$1"',
 'red-link-title' => '$1 (a paggena nun esiste)',
 
 # Short words for each namespace, by default used in the namespace tab in monobook
@@ -252,17 +294,21 @@ $messages = array(
 'nstab-user' => 'Paggena utente',
 'nstab-special' => 'Paggena speciale',
 'nstab-project' => "Paggena 'e servizio",
-'nstab-image' => 'Fiura',
+'nstab-image' => 'Fiùra',
 'nstab-mediawiki' => "'Mmasciata",
 'nstab-template' => 'Modello',
 'nstab-help' => 'Ajùto',
 'nstab-category' => 'Categurìa',
 
 # General errors
+'missingarticle-rev' => "(nummero 'e verzione: $1)",
+'internalerror' => "Errore 'nterno",
+'internalerror_info' => "Errore 'nterno: $1",
 'filedeleteerror' => 'Nun se pô scancellà \'o file "$1"',
 'cannotdelete' => "Nun è possibbele scassà 'a paggena o 'a fiura addamannata. (Putria éssere stato già scancellato.)",
 'badtitle' => "'O nnomme nun è jùsto",
 'viewsource' => 'Vere sorgente',
+'viewsource-title' => "Vere surgente 'e $1",
 'exception-nologin' => 'Acciesso nun affettuato',
 
 # Login and logout pages
@@ -271,41 +317,77 @@ $messages = array(
 Putite cuntinuà a ausà {{SITENAME}} comme n'utente senza nomme, o si nò putite trasì n'ata vota, cu 'o stesso nomme o cu n'ato nomme.",
 'welcomeuser' => 'Bemmenuto, $1!',
 'yourname' => 'Nomme utente',
+'userlogin-yourname' => 'Nomme utente',
+'userlogin-yourname-ph' => "'Nserisce 'o tujo nomme utente",
+'createacct-another-username-ph' => "'Nserisce 'o nomme utente",
 'yourpassword' => 'Password:',
+'userlogin-yourpassword' => 'Password',
+'userlogin-yourpassword-ph' => "'Nserisce 'a toja password",
+'createacct-yourpassword-ph' => "'Nserisce 'na password",
+'yourpasswordagain' => "Ripete 'a password:",
+'createacct-yourpasswordagain' => 'Cunferma password',
+'createacct-yourpasswordagain-ph' => "'Nserisce 'e novo 'a password",
 'remembermypassword' => 'Allicuordate d"a password (for a maximum of $1 {{PLURAL:$1|day|days}})',
+'userlogin-remembermypassword' => 'Mantienime cullegato',
 'yourdomainname' => "Spiecà 'o dumminio",
 'login' => 'Tràse',
-'nav-login-createaccount' => "Tràse o cria n'acciesso nuovo",
-'userlogin' => "Tràse o cria n'acciesso nuovo",
+'nav-login-createaccount' => "Tràse o cria n'acciesso novo",
+'userlogin' => "Tràse o cria n'acciesso novo",
 'userloginnocreate' => 'Tràse',
 'logout' => 'Jèsce',
 'userlogout' => 'Jèsce',
 'notloggedin' => 'Acciesso nun affettuato',
+'userlogin-noaccount' => "Nun haje ancora n'acciesso?",
 'nologin' => "Nun haje ancora n'acciesso? '''$1'''.",
 'nologinlink' => 'Crialo mmo',
-'createaccount' => 'Cria nu cunto nuovo',
+'createaccount' => 'Cria nu cunto novo',
 'gotaccount' => "Tiene già nu cunto? '''$1'''.",
 'gotaccountlink' => 'Tràse',
+'userlogin-resetlink' => "Haje dimenticato 'e toje date 'e acciesso?",
+'createaccountreason' => 'Mutivo:',
+'createacct-reason' => 'Mutivo',
+'createacct-submit' => "Cria 'a toja utenza",
+'createacct-another-submit' => "Cria 'n atro account",
+'createacct-benefit-heading' => "{{SITENAME}} è fatta 'e perzone comme te.",
+'createacct-benefit-body1' => '{{PLURAL:$1|càgnamiento|càgnamiente}}',
+'createacct-benefit-body2' => '{{PLURAL:$1|paggena|paggene}}',
 'loginerror' => "Probblema 'e accièsso",
 'loginsuccesstitle' => 'Acciesso affettuato',
+'loginsuccess' => "'''Si stato cunnesso ô server 'e {{SITENAME}} cu 'o nomme utente 'e \"\$1\".'''",
 'nosuchusershort' => 'Nun ce stanno utente cu o nòmme "$1". Cuntrolla si scrivìste buòno.',
 'nouserspecified' => "Tiene 'a dìcere nu nomme pricìso.",
 'acct_creation_throttle_hit' => 'Ce dispiace, haje già criato $1 utente. Nun ne pô crià ate.',
 'accountcreated' => 'Cunto criato',
 'loginlanguagelabel' => 'Lengua: $1',
 
+# Change password dialog
+'resetpass' => 'Càgna password',
+'resetpass-submit-cancel' => 'Canciella',
+
+# Special:PasswordReset
+'passwordreset-username' => 'Nomme utente:',
+'passwordreset-domain' => 'Duminio:',
+
+# Special:ChangeEmail
+'changeemail-none' => '(nisciuno)',
+'changeemail-cancel' => 'Canciella',
+
 # Edit page toolbar
+'bold_sample' => 'Grassetto',
+'bold_tip' => 'Grassetto',
 'italic_sample' => 'Corsivo',
 'italic_tip' => 'Corsivo',
 'link_sample' => 'Titulo ddo cullegamente',
+'link_tip' => 'Jonte nterne',
 'extlink_sample' => 'http://www.example.com titulo ddo cullegamente',
 'headline_sample' => 'Testate',
 'headline_tip' => "Testate 'e 2° livello",
 'image_sample' => 'Essempio.jpg',
-'image_tip' => 'Fiura ncuorporata',
+'image_tip' => 'Fiùra ncuorporata',
 'media_tip' => 'Cullegamente a file multimediale',
 
 # Edit pages
+'summary' => 'Énnece',
 'minoredit' => 'Chisto è nu cagnamiénto piccerillo',
 'watchthis' => "Tiene d'uocchio chesta paggena",
 'savearticle' => "Sarva 'a paggena",
@@ -320,9 +402,13 @@ Putite cuntinuà a ausà {{SITENAME}} comme n'utente senza nomme, o si nò putit
 'newarticle' => '(Novo)',
 'previewnote' => "'''Chesta è sola n'anteprimma; 'e cagnamiénte â paggena nun songo ancora sarvate!'''",
 'editing' => "Cagnamiento 'e $1",
-'editingsection' => 'Cagnamiénto di $1 (sezzione)',
+'editingsection' => "Cagnamiénto 'e $1 (sezzione)",
 'templatesused' => "{{PLURAL:$1|Template|Templates}} ausate 'a chesta paggena:",
 'template-protected' => '(prutetto)',
+'template-semiprotected' => '(semi-prutetto)',
+
+# Content models
+'content-model-css' => 'CSS',
 
 # "Undo" feature
 'undo-summary' => "Canciella 'o cagnamiento $1 'e [[Special:Contributions/$2|$2]] ([[User talk:$2|Chiàcchiera]])",
@@ -331,15 +417,24 @@ Putite cuntinuà a ausà {{SITENAME}} comme n'utente senza nomme, o si nò putit
 'currentrev' => "Verzione 'e mmo",
 'currentrev-asof' => 'Vversione attuale dde $1',
 'revisionasof' => 'Vversione delle $1',
+'previousrevision' => "← Verzione 'e primma",
 'nextrevision' => 'Vversione cchiù recente →',
+'currentrevisionlink' => "Verzione 'e mmo",
 'cur' => 'corr',
 'last' => 'prec',
+'history-show-deleted' => 'Solo chille canciellate',
+'histfirst' => 'primma',
+'histlast' => 'urdema',
 
 # Revision feed
 'history-feed-item-nocomment' => "$1 'o $2",
 
 # Revision deletion
 'rev-delundel' => 'faje vedé/annascunne',
+'rev-showdeleted' => 'faje vedé',
+'revdelete-show-file-submit' => 'Sì',
+'revdelete-radio-set' => 'Sì',
+'revdelete-radio-unset' => 'No',
 'revdel-restore' => 'càgna visiblità',
 
 # Diffs
@@ -359,7 +454,6 @@ Putite cuntinuà a ausà {{SITENAME}} comme n'utente senza nomme, o si nò putit
 'shown-title' => "Fa vere {{PLURAL:$1|'nu risultato|$1 risultate}} ppe paggena",
 'viewprevnext' => 'Vere($1 {{int:pipe-separator}} $2) ($3).',
 'searchmenu-new' => "'''Cria a paggena \"[[:\$1]]\" ncopp'â chisto wiki!'''",
-'searchhelp-url' => 'Help:Ajùto',
 'searchprofile-articles' => "Paggene 'e contenute",
 'searchprofile-project' => "Paggene 'e ajùto e relative 'o prugietto",
 'searchprofile-images' => 'Multimedia',
@@ -372,7 +466,10 @@ Putite cuntinuà a ausà {{SITENAME}} comme n'utente senza nomme, o si nò putit
 'search-result-size' => "$1 ({{PLURAL:$2|'na parola|$2 parole}})",
 'search-redirect' => '(redirect $1)',
 'search-section' => '(sezzione $1)',
+'search-suggest' => 'Prova chisto: $1',
+'search-interwiki-caption' => 'Prugiette frate',
 'searchall' => 'Tutte',
+'search-nonefound' => "'A ricerca nun ha produtto risultate.",
 'powersearch' => 'Truova',
 
 # Preferences page
@@ -380,10 +477,13 @@ Putite cuntinuà a ausà {{SITENAME}} comme n'utente senza nomme, o si nò putit
 'changepassword' => 'Cagna password',
 'prefs-rc' => 'Urdeme nove',
 'prefs-watchlist' => 'Asservate speciale',
+'saveprefs' => 'Sarva',
 'columns' => 'Culonne:',
+'searchresultshead' => 'Truova',
 'timezoneregion-africa' => 'Afreca',
 'youremail' => 'E-mail:',
-'username' => 'Nomme utente',
+'username' => '{{GENDER:$1|Nomme utente}}:',
+'yourrealname' => 'Nomme vero',
 'yourlanguage' => 'Lengua:',
 
 # Associated actions - in the sentence "You do not have permission to X"
@@ -391,9 +491,11 @@ Putite cuntinuà a ausà {{SITENAME}} comme n'utente senza nomme, o si nò putit
 
 # Recent changes
 'recentchanges' => 'Urdeme nove',
+'recentchanges-legend' => 'Opzione urdeme cagnamiénte',
 'recentchanges-summary' => "Ncoppa chesta paggena song' appresentate ll'urdeme cagnamiente fatto ê cuntenute d\"o sito.",
 'recentchanges-label-newpage' => "Chista modifica ha criato 'na nova paggena",
 'recentchanges-label-minor' => 'Chisto è nu cagnamiénto piccerillo',
+'recentchanges-label-unpatrolled' => "Chista modifica nun è stata 'ncora verificata",
 'rcnote' => "Ccà sotto nce songo ll'urdeme {{PLURAL:$1|cangiamiento|'''$1''' cangiamiente}} 'e ll'urdeme {{PLURAL:$2|juorno|'''$2''' juorne}}, agghiuornate alle $5 ddo $4.",
 'rclistfrom' => "Faje vedé 'e cagnamiénte fatte a partì 'a $1",
 'rcshowhideminor' => "$1 'e cagnamiénte piccerille",
@@ -410,15 +512,19 @@ Putite cuntinuà a ausà {{SITENAME}} comme n'utente senza nomme, o si nò putit
 'newpageletter' => 'N',
 'boteditletter' => 'b',
 'rc_categories_any' => 'Qualònca',
+'rc-enhanced-expand' => 'Fa vede dettaglie (richiede JavaScript)',
+'rc-enhanced-hide' => 'Annascunne dettaglie',
 
 # Recent changes linked
 'recentchangeslinked' => 'Cagnamiénte cullegate',
 'recentchangeslinked-feed' => 'Cagnamiénte cullegate',
 'recentchangeslinked-toolbox' => 'Cagnamiénte cullegate',
+'recentchangeslinked-title' => 'Cagnamiénte cullegate a "$1"',
 'recentchangeslinked-page' => 'Nomme dda paggena',
 
 # Upload
 'upload' => 'Careca file',
+'filedesc' => 'Énnece',
 'uploadedimage' => 'ha carecato "[[$1]]"',
 
 'license' => 'Licenze:',
@@ -428,7 +534,9 @@ Putite cuntinuà a ausà {{SITENAME}} comme n'utente senza nomme, o si nò putit
 'listfiles_name' => 'Nomme',
 
 # File description page
-'file-anchor-link' => 'Fiura',
+'file-anchor-link' => 'Fiùra',
+'filehist' => 'Cronologgia d"o file',
+'filehist-revert' => 'ripristina',
 'filehist-current' => 'attuale',
 'filehist-datetime' => 'Data/Ora',
 'filehist-thumb' => 'Miniature',
@@ -438,19 +546,18 @@ Putite cuntinuà a ausà {{SITENAME}} comme n'utente senza nomme, o si nò putit
 
 # Random page
 'randompage' => 'Na paggena qualsiase',
-'randompage-nopages' => 'Nessuna pagina nel namespace selezionato.',
+'randompage-nopages' => "Nun gè song paggene {{PLURAL:$2|dint'ô seguente namespace|dint'ê seguenti namespace}}: $1.",
 
 # Statistics
 'statistics' => 'Statistiche',
 
-'disambiguations' => "Paggene 'e disambigua",
-
 'doubleredirects' => 'Redirect duppie',
 
 # Miscellaneous special pages
 'nbytes' => '$1 {{PLURAL:$1|byte|byte}}',
 'ncategories' => '$1 {{PLURAL:$1|categoria|categorie}}',
 'nlinks' => '$1 {{PLURAL:$1|cullegamiento|cullegamiente}}',
+'nmembers' => '$1 {{PLURAL:$1|elemento|elemente}}',
 'popularpages' => "Paggene cchiù 'speziunate",
 'wantedpages' => 'Paggene cchiù addemannate',
 'shortpages' => 'Paggene curte',
@@ -459,8 +566,10 @@ Putite cuntinuà a ausà {{SITENAME}} comme n'utente senza nomme, o si nò putit
 'newpages' => 'Paggene cchiù frische',
 'move' => 'Spusta',
 'movethispage' => 'Spusta chesta paggena',
+'pager-older-n' => '{{PLURAL:$1|1 cchiù viecchio|$1 cchiù viecchie}}',
 
 # Book sources
+'booksources' => 'Funte libbrarie',
 'booksources-go' => 'Vàje',
 
 # Special:Log
@@ -481,6 +590,10 @@ Also see [[Special:WantedCategories|wanted categories]].",
 
 # Special:LinkSearch
 'linksearch-ok' => 'Truova',
+'linksearch-line' => "$1 presente dint'â paggena $2",
+
+# Email user
+'emailuser' => 'Email chisto utente',
 
 # Watchlist
 'mywatchlist' => 'osservate speciale',
@@ -509,6 +622,7 @@ Also see [[Special:WantedCategories|wanted categories]].",
 'revertpage' => "Cangiaje 'e cagnamiénte 'e [[Special:Contributions/$2|$2]] ([[User talk:$2|discussione]]), cu â verzione 'e pprimma 'e  [[User:$1|$1]]",
 
 # Protect
+'protectedarticle' => 'ha prutetto "[[$1]]"',
 'prot_1movedto2' => 'ha spustato [[$1]] a [[$2]]',
 'protect-expiry-options' => '2 ore:2 hours,1 juorno:1 day,3 juorne:3 days,1 semmana:1 week,2 semmane:2 weeks,1 mise:1 month,3 mese:3 months,6 mese:6 months,1 anno:1 year,infinito:infinite',
 
@@ -524,9 +638,16 @@ Also see [[Special:WantedCategories|wanted categories]].",
 # Contributions
 'contributions' => 'Contribbute {{GENDER:$1|utente}}',
 'mycontris' => "'E ffatiche d''e mmeje",
-'uctop' => '(ultima ppe a paggena)',
+'contribsub2' => 'Ppe $1 ($2)',
+'uctop' => '(attuale)',
+'month' => 'D"o mese (e primma):',
+'year' => "'E ll'anno (e primma):",
 
+'sp-contributions-newbies' => "Mosta solo 'e contribbute dde nove utente",
+'sp-contributions-blocklog' => 'blocche',
+'sp-contributions-logs' => 'registre',
 'sp-contributions-talk' => 'Chiàcchiera',
+'sp-contributions-username' => 'Nnerizzo IP o nomme utente',
 'sp-contributions-submit' => 'Truova',
 
 # What links here
@@ -534,17 +655,25 @@ Also see [[Special:WantedCategories|wanted categories]].",
 'whatlinkshere-title' => 'Paggene ca cullegano a $1',
 'whatlinkshere-page' => 'Paggena:',
 'nolinkshere' => "Nisciuna paggena cuntene jonte ca mpuntano a '''[[:$1]]'''.",
+'isredirect' => 'redirect a paggena',
+'istemplate' => "'nclusione",
+'isimage' => 'Cullegamente a file multimediale',
 'whatlinkshere-links' => '← jonte',
 'whatlinkshere-hideredirs' => '$1 redirects',
+'whatlinkshere-hidetrans' => "$1 'nclusione",
+'whatlinkshere-hidelinks' => '$1 jonte',
 'whatlinkshere-hideimages' => '$1 links ddo file',
+'whatlinkshere-filters' => 'Filtre',
 
 # Block/unblock
 'blockip' => 'Ferma utelizzatóre',
 'ipadressorusername' => 'Nnerizzo IP o nomme utente',
 'ipboptions' => '2 ore:2 hours,1 juorno:1 day,3 juorne:3 days,1 semmana:1 week,2 semmane:2 weeks,1 mise:1 month,3 mese:3 months,6 mese:6 months,1 anno:1 year,infinito:infinite',
 'blockipsuccesssub' => 'Blocco aseguito',
+'ipblocklist' => 'Utenti bloccate',
 'blocklink' => 'ferma',
 'unblocklink' => 'sblocca',
+'change-blocklink' => 'càgna blocco',
 'contribslink' => 'contribuzzione',
 'blocklogpage' => 'Blocche',
 'blocklogentry' => 'ha fermato "[[$1]]" pe\' nu mumento \'e $2 $3',
@@ -581,13 +710,19 @@ Also see [[Special:WantedCategories|wanted categories]].",
 'import-logentry-upload' => 'ha mpurtato [[$1]] trammeto upload',
 
 # Tooltip help for the actions
+'tooltip-pt-userpage' => 'A toja paggena utente',
+'tooltip-pt-mytalk' => "A toja paggena 'e discussione",
+'tooltip-pt-preferences' => "Preferenze d''e mmeje",
 'tooltip-pt-mycontris' => 'Elenco dde tuje contributte',
-'tooltip-pt-login' => 'A reggistrazione e consegliata',
+'tooltip-pt-login' => 'A reggistrazione è cunsigliata',
 'tooltip-pt-logout' => 'Jésce (logout)',
+'tooltip-ca-talk' => 'Vede e discussione rilative a chista paggena',
 'tooltip-ca-edit' => "Puo modifica chista paggena. Ppe favore usa 'o pulsante 'e anteprimma primma 'e salva",
 'tooltip-ca-addsection' => "Cummincia 'na nova sezzione",
 'tooltip-ca-viewsource' => "Chista paggena è prutetta, ma puo vere 'o codice sorgente",
 'tooltip-ca-history' => "Vversione precedente 'e chista paggena",
+'tooltip-ca-protect' => 'Prutegge chesta paggena',
+'tooltip-ca-delete' => 'Scancèlla chista paggena',
 'tooltip-ca-move' => 'Spusta chista paggena',
 'tooltip-search' => "Truova dint'ô {{SITENAME}}",
 'tooltip-search-fulltext' => "Ascià 'o testo indicato dint'e paggene",
@@ -598,13 +733,21 @@ Also see [[Special:WantedCategories|wanted categories]].",
 'tooltip-n-recentchanges' => 'Ennece dde urdeme cagnamiénte ddo sito',
 'tooltip-n-randompage' => 'Na paggena qualsiase',
 'tooltip-n-help' => "Paggena 'e ajùto",
+'tooltip-t-whatlinkshere' => "'Na lista 'e tutte e paggene ca song cullegate a chista",
 'tooltip-t-recentchangeslinked' => 'Urdeme cagnamiénte dde paggene ca cullegano a chesta',
+'tooltip-t-contributions' => "Lista dde contributte 'e chisto utente",
+'tooltip-t-emailuser' => "Manna 'nu email a chisto utente",
 'tooltip-t-upload' => 'Careca file',
 'tooltip-t-specialpages' => "Lista 'e tutte e paggene speciale",
 'tooltip-t-print' => "Vversione pe' stampa 'e chista paggena",
 'tooltip-t-permalink' => 'Jonta permanente a chista vversione dda paggena',
 'tooltip-ca-nstab-main' => 'Vere a paggena e contenuto',
+'tooltip-ca-nstab-user' => 'Vere a paggena utente',
+'tooltip-ca-nstab-special' => "Chista è 'na paggena speciale, nun può essere càgnata",
+'tooltip-ca-nstab-project' => "Vere a paggena 'e servizio",
+'tooltip-ca-nstab-image' => 'Vere a paggena ddo file',
 'tooltip-ca-nstab-template' => "Vere 'o modello",
+'tooltip-ca-nstab-category' => 'Vere a paggena d"a categurìa',
 'tooltip-minoredit' => 'Rénne chìsto cagnamiénto cchiù ppiccirìllo.',
 'tooltip-save' => "Sàrva 'e cagnamiénte.",
 'tooltip-preview' => "Primma 'e sarvà, vìre primma chille ca hê cagnàte!",
@@ -613,6 +756,10 @@ Also see [[Special:WantedCategories|wanted categories]].",
 # Attribution
 'others' => 'ate',
 
+# Browsing diffs
+'previousdiff' => '← Càgnamiento cchiù viecchio',
+'nextdiff' => 'Cagnamiénte successivo →',
+
 # Media information
 'file-info-size' => '$1 × $2 pixel, dimenzione ddo file: $3, tipo MIME: $4',
 'show-big-image' => 'Vversione ad ata risoluzione',
@@ -659,6 +806,9 @@ Also see [[Special:WantedCategories|wanted categories]].",
 # Special:SpecialPages
 'specialpages' => 'Paggene speciale',
 
+# Special:Tags
+'tag-filter' => 'Filtra ppe [[Special:Tags|etichetta]]:',
+
 # New logging system
 'rightsnone' => '(nisciuno)',
 
