@@ -7,6 +7,7 @@
  * @ingroup Language
  * @file
  *
+ * @author Kuailong
  * @author PhiLiP
  * @author Shizhao
  * @author Wong128hk
@@ -172,19 +173,8 @@ $specialPageAliases = array(
 );
 
 $messages = array(
-# User preference toggles
-'tog-norollbackdiff' => '進行回退後略過差異比較',
-
-# Edit pages
-'editing' => '正在编辑 $1',
-
-# Move page
-'move-redirect-suppressed' => '已禁止重新定向',
-
 /*
 Short names for language variants used for language conversion links.
-To disable showing a particular link, set it to 'disable', e.g.
-'variantname-zh-sg' => 'disable',
 Variants for Chinese language
 */
 'variantname-zh-hans' => '简体',
