@@ -21,8 +21,7 @@
  * @ingroup Maintenance
  */
 
-
-require_once( __DIR__ . '/Maintenance.php' );
+require_once __DIR__ . '/Maintenance.php';
 
 /**
  * Maintenance script to check that database usernames are actually valid.
@@ -37,25 +36,34 @@ class CheckUsernames extends Maintenance {
 	public function __construct() {
 		parent::__construct();
 		$this->mDescription = "Verify that database usernames are actually valid";
+		$this->setBatchSize( 1000 );
 	}
 
 	function execute() {
 		$dbr = wfGetDB( DB_SLAVE );
 
-		$res = $dbr->select( 'user',
-			array( 'user_id', 'user_name' ),
-			null,
-			__METHOD__
-		);
+		$maxUserId = 0;
+		do {
+			$res = $dbr->select( 'user',
+				array( 'user_id', 'user_name' ),
+				array( 'user_id > ' . $maxUserId ),
+				__METHOD__,
+				array(
+					'ORDER BY' => 'user_id',
+					'LIMIT' => $this->mBatchSize,
+				)
+			);
 
-		foreach ( $res as $row ) {
-			if ( ! User::isValidUserName( $row->user_name ) ) {
-				$this->error( sprintf( "%s: %6d: '%s'\n", wfWikiID(), $row->user_id, $row->user_name ) );
-				wfDebugLog( 'checkUsernames', $row->user_name );
+			foreach ( $res as $row ) {
+				if ( ! User::isValidUserName( $row->user_name ) ) {
+					$this->error( sprintf( "%s: %6d: '%s'\n", wfWikiID(), $row->user_id, $row->user_name ) );
+					wfDebugLog( 'checkUsernames', $row->user_name );
+				}
 			}
-		}
+			$maxUserId = $row->user_id;
+		} while ( $res->numRows() );
 	}
 }
 
 $maintClass = "CheckUsernames";
-require_once( RUN_MAINTENANCE_IF_MAIN );
+require_once RUN_MAINTENANCE_IF_MAIN;
