@@ -1,12 +1,12 @@
 <?php
 /**
- * Script to clean up broken, unparseable upload filenames.
+ * Clean up broken, unparseable upload filenames.
  *
  * Usage: php cleanupImages.php [--fix]
  * Options:
  *   --fix  Actually clean up titles; otherwise just checks for them
  *
- * Copyright (C) 2005-2006 Brion Vibber <brion@pobox.com>
+ * Copyright © 2005-2006 Brion Vibber <brion@pobox.com>
  * http://www.mediawiki.org/
  *
  * This program is free software; you can redistribute it and/or modify
@@ -29,8 +29,13 @@
  * @ingroup Maintenance
  */
 
-require_once( dirname( __FILE__ ) . '/cleanupTable.inc' );
+require_once __DIR__ . '/cleanupTable.inc';
 
+/**
+ * Maintenance script to clean up broken, unparseable upload filenames.
+ *
+ * @ingroup Maintenance
+ */
 class ImageCleanup extends TableCleanup {
 	protected $defaultParams = array(
 		'table' => 'image',
@@ -73,8 +78,9 @@ class ImageCleanup extends TableCleanup {
 		if ( is_null( $title ) ) {
 			$this->output( "page $source ($cleaned) is illegal.\n" );
 			$safe = $this->buildSafeTitle( $cleaned );
-			if ( $safe === false )
+			if ( $safe === false ) {
 				return $this->progress( 0 );
+			}
 			$this->pokeFile( $source, $safe );
 			return $this->progress( 1 );
 		}
@@ -86,9 +92,12 @@ class ImageCleanup extends TableCleanup {
 			return $this->progress( 1 );
 		}
 
-		$this->progress( 0 );
+		return $this->progress( 0 );
 	}
 
+	/**
+	 * @param $name string
+	 */
 	private function killRow( $name ) {
 		if ( $this->dryrun ) {
 			$this->output( "DRY RUN: would delete bogus row '$name'\n" );
@@ -120,7 +129,8 @@ class ImageCleanup extends TableCleanup {
 		$path = $this->filePath( $orig );
 		if ( !file_exists( $path ) ) {
 			$this->output( "missing file: $path\n" );
-			return $this->killRow( $orig );
+			$this->killRow( $orig );
+			return;
 		}
 
 		$db = wfGetDB( DB_MASTER );
@@ -135,7 +145,7 @@ class ImageCleanup extends TableCleanup {
 		$version = 0;
 		$final = $new;
 		$conflict = ( $this->imageExists( $final, $db ) ||
-				  ( $this->pageExists( $orig, $db ) && $this->pageExists( $final, $db ) ) );
+				( $this->pageExists( $orig, $db ) && $this->pageExists( $final, $db ) ) );
 
 		while ( $conflict ) {
 			$this->output( "Rename conflicts with '$final'...\n" );
@@ -151,7 +161,7 @@ class ImageCleanup extends TableCleanup {
 		} else {
 			$this->output( "renaming $path to $finalPath\n" );
 			// @todo FIXME: Should this use File::move()?
-			$db->begin();
+			$db->begin( __METHOD__ );
 			$db->update( 'image',
 				array( 'img_name' => $final ),
 				array( 'img_name' => $orig ),
@@ -166,17 +176,17 @@ class ImageCleanup extends TableCleanup {
 				__METHOD__ );
 			$dir = dirname( $finalPath );
 			if ( !file_exists( $dir ) ) {
-				if ( !wfMkdirParents( $dir ) ) {
-					$this->log( "RENAME FAILED, COULD NOT CREATE $dir" );
-					$db->rollback();
+				if ( !wfMkdirParents( $dir, null, __METHOD__ ) ) {
+					$this->output( "RENAME FAILED, COULD NOT CREATE $dir" );
+					$db->rollback( __METHOD__ );
 					return;
 				}
 			}
 			if ( rename( $path, $finalPath ) ) {
-				$db->commit();
+				$db->commit( __METHOD__ );
 			} else {
 				$this->error( "RENAME FAILED" );
-				$db->rollback();
+				$db->rollback( __METHOD__ );
 			}
 		}
 	}
@@ -187,9 +197,8 @@ class ImageCleanup extends TableCleanup {
 	}
 
 	private function buildSafeTitle( $name ) {
-		global $wgLegalTitleChars;
 		$x = preg_replace_callback(
-			"/([^$wgLegalTitleChars]|~)/",
+			'/([^' . Title::legalChars() . ']|~)/',
 			array( $this, 'hexChar' ),
 			$name );
 
@@ -204,4 +213,4 @@ class ImageCleanup extends TableCleanup {
 }
 
 $maintClass = "ImageCleanup";
-require_once( RUN_MAINTENANCE_IF_MAIN );
+require_once RUN_MAINTENANCE_IF_MAIN;
