@@ -29,7 +29,7 @@
  * @ingroup Maintenance
  */
 
-require_once( __DIR__ . '/cleanupTable.inc' );
+require_once __DIR__ . '/cleanupTable.inc';
 
 /**
  * Maintenance script to clean up broken, unparseable titles.
@@ -42,6 +42,9 @@ class TitleCleanup extends TableCleanup {
 		$this->mDescription = "Script to clean up broken, unparseable titles";
 	}
 
+	/**
+	 * @param object $row
+	 */
 	protected function processRow( $row ) {
 		global $wgContLang;
 		$display = Title::makeName( $row->page_namespace, $row->page_title );
@@ -51,40 +54,54 @@ class TitleCleanup extends TableCleanup {
 		if ( !is_null( $title )
 			&& $title->canExist()
 			&& $title->getNamespace() == $row->page_namespace
-			&& $title->getDBkey() === $row->page_title )
-		{
-			return $this->progress( 0 );  // all is fine
+			&& $title->getDBkey() === $row->page_title
+		) {
+			$this->progress( 0 ); // all is fine
+
+			return;
 		}
 
 		if ( $row->page_namespace == NS_FILE && $this->fileExists( $row->page_title ) ) {
 			$this->output( "file $row->page_title needs cleanup, please run cleanupImages.php.\n" );
-			return $this->progress( 0 );
+			$this->progress( 0 );
 		} elseif ( is_null( $title ) ) {
 			$this->output( "page $row->page_id ($display) is illegal.\n" );
 			$this->moveIllegalPage( $row );
-			return $this->progress( 1 );
+			$this->progress( 1 );
 		} else {
 			$this->output( "page $row->page_id ($display) doesn't match self.\n" );
 			$this->moveInconsistentPage( $row, $title );
-			return $this->progress( 1 );
+			$this->progress( 1 );
 		}
 	}
 
+	/**
+	 * @param string $name
+	 * @return bool
+	 */
 	protected function fileExists( $name ) {
 		// XXX: Doesn't actually check for file existence, just presence of image record.
 		// This is reasonable, since cleanupImages.php only iterates over the image table.
 		$dbr = wfGetDB( DB_SLAVE );
 		$row = $dbr->selectRow( 'image', array( 'img_name' ), array( 'img_name' => $name ), __METHOD__ );
+
 		return $row !== false;
 	}
 
+	/**
+	 * @param object $row
+	 */
 	protected function moveIllegalPage( $row ) {
 		$legal = 'A-Za-z0-9_/\\\\-';
 		$legalized = preg_replace_callback( "!([^$legal])!",
 			array( &$this, 'hexChar' ),
 			$row->page_title );
-		if ( $legalized == '.' ) $legalized = '(dot)';
-		if ( $legalized == '_' ) $legalized = '(space)';
+		if ( $legalized == '.' ) {
+			$legalized = '(dot)';
+		}
+		if ( $legalized == '_' ) {
+			$legalized = '(space)';
+		}
 		$legalized = 'Broken/' . $legalized;
 
 		$title = Title::newFromText( $legalized );
@@ -100,9 +117,11 @@ class TitleCleanup extends TableCleanup {
 
 		$dest = $title->getDBkey();
 		if ( $this->dryrun ) {
-			$this->output( "DRY RUN: would rename $row->page_id ($row->page_namespace,'$row->page_title') to ($row->page_namespace,'$dest')\n" );
+			$this->output( "DRY RUN: would rename $row->page_id ($row->page_namespace," .
+				"'$row->page_title') to ($row->page_namespace,'$dest')\n" );
 		} else {
-			$this->output( "renaming $row->page_id ($row->page_namespace,'$row->page_title') to ($row->page_namespace,'$dest')\n" );
+			$this->output( "renaming $row->page_id ($row->page_namespace," .
+				"'$row->page_title') to ($row->page_namespace,'$dest')\n" );
 			$dbw = wfGetDB( DB_MASTER );
 			$dbw->update( 'page',
 				array( 'page_title' => $dest ),
@@ -111,6 +130,10 @@ class TitleCleanup extends TableCleanup {
 		}
 	}
 
+	/**
+	 * @param object $row
+	 * @param Title $title
+	 */
 	protected function moveInconsistentPage( $row, $title ) {
 		if ( $title->exists() || $title->getInterwiki() || !$title->canExist() ) {
 			if ( $title->getInterwiki() || !$title->canExist() ) {
@@ -121,7 +144,9 @@ class TitleCleanup extends TableCleanup {
 
 			# Old cleanupTitles could move articles there. See bug 23147.
 			$ns = $row->page_namespace;
-			if ( $ns < 0 ) $ns = 0;
+			if ( $ns < 0 ) {
+				$ns = 0;
+			}
 
 			$clean = 'Broken/' . $prior;
 			$verified = Title::makeTitleSafe( $ns, $clean );
@@ -139,9 +164,11 @@ class TitleCleanup extends TableCleanup {
 		$dest = $title->getDBkey();
 
 		if ( $this->dryrun ) {
-			$this->output( "DRY RUN: would rename $row->page_id ($row->page_namespace,'$row->page_title') to ($ns,'$dest')\n" );
+			$this->output( "DRY RUN: would rename $row->page_id ($row->page_namespace," .
+				"'$row->page_title') to ($ns,'$dest')\n" );
 		} else {
-			$this->output( "renaming $row->page_id ($row->page_namespace,'$row->page_title') to ($ns,'$dest')\n" );
+			$this->output( "renaming $row->page_id ($row->page_namespace," .
+				"'$row->page_title') to ($ns,'$dest')\n" );
 			$dbw = wfGetDB( DB_MASTER );
 			$dbw->update( 'page',
 				array(
@@ -156,4 +183,4 @@ class TitleCleanup extends TableCleanup {
 }
 
 $maintClass = "TitleCleanup";
-require_once( RUN_MAINTENANCE_IF_MAIN );
+require_once RUN_MAINTENANCE_IF_MAIN;
