@@ -26,7 +26,7 @@
  * @ingroup Maintenance
  */
 
-require_once( __DIR__ . '/Maintenance.php' );
+require_once __DIR__ . '/Maintenance.php';
 
 /**
  * Base class for interating over a dump.
@@ -47,13 +47,13 @@ abstract class DumpIterator extends Maintenance {
 	}
 
 	public function execute() {
-		if (! ( $this->hasOption('file') ^ $this->hasOption('dump') ) ) {
-			$this->error("You must provide a file or dump", true);
+		if ( !( $this->hasOption( 'file' ) ^ $this->hasOption( 'dump' ) ) ) {
+			$this->error( "You must provide a file or dump", true );
 		}
 
 		$this->checkOptions();
 
-		if ( $this->hasOption('file') ) {
+		if ( $this->hasOption( 'file' ) ) {
 			$revision = new WikiRevision;
 
 			$revision->setText( file_get_contents( $this->getOption( 'file' ) ) );
@@ -64,10 +64,10 @@ abstract class DumpIterator extends Maintenance {
 
 		$this->startTime = microtime( true );
 
-		if ( $this->getOption('dump') == '-' ) {
+		if ( $this->getOption( 'dump' ) == '-' ) {
 			$source = new ImportStreamSource( $this->getStdin() );
 		} else {
-			$this->error("Sorry, I don't support dump filenames yet. Use - and provide it on stdin on the meantime.", true);
+			$this->error( "Sorry, I don't support dump filenames yet. Use - and provide it on stdin on the meantime.", true );
 		}
 		$importer = new WikiImporter( $source );
 
@@ -81,9 +81,10 @@ abstract class DumpIterator extends Maintenance {
 		$this->conclusions();
 
 		$delta = microtime( true ) - $this->startTime;
-		$this->error( "Done {$this->count} revisions in " . round($delta, 2) . " seconds " );
-		if ($delta > 0)
-			$this->error( round($this->count / $delta, 2) . " pages/sec" );
+		$this->error( "Done {$this->count} revisions in " . round( $delta, 2 ) . " seconds " );
+		if ( $delta > 0 ) {
+			$this->error( round( $this->count / $delta, 2 ) . " pages/sec" );
+		}
 
 		# Perform the memory_get_peak_usage() when all the other data has been output so there's no damage if it dies.
 		# It is only available since 5.2.0 (since 5.2.1 if you haven't compiled with --enable-memory-limit)
@@ -96,7 +97,7 @@ abstract class DumpIterator extends Maintenance {
 		if ( $this->getDbType() == Maintenance::DB_NONE ) {
 			global $wgUseDatabaseMessages, $wgLocalisationCacheConf, $wgHooks;
 			$wgUseDatabaseMessages = false;
-			$wgLocalisationCacheConf['storeClass'] =  'LCStore_Null';
+			$wgLocalisationCacheConf['storeClass'] = 'LCStore_Null';
 			$wgHooks['InterwikiLoadPrefix'][] = 'DumpIterator::disableInterwikis';
 		}
 	}
@@ -122,9 +123,10 @@ abstract class DumpIterator extends Maintenance {
 
 		$this->count++;
 		if ( isset( $this->from ) ) {
-			if ( $this->from != $title )
+			if ( $this->from != $title ) {
 				return;
-			$this->output( "Skipped " . ($this->count - 1) . " pages\n" );
+			}
+			$this->output( "Skipped " . ( $this->count - 1 ) . " pages\n" );
 
 			$this->count = 1;
 			$this->from = null;
@@ -175,4 +177,4 @@ class SearchDump extends DumpIterator {
 }
 
 $maintClass = "SearchDump";
-require_once( RUN_MAINTENANCE_IF_MAIN );
+require_once RUN_MAINTENANCE_IF_MAIN;
