@@ -18,26 +18,40 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  * http://www.gnu.org/copyleft/gpl.html
  *
+ * @file
  * @ingroup Maintenance
  */
 
-require_once( dirname( __FILE__ ) . '/Maintenance.php' );
-
-class PopulateLogSearch extends Maintenance {
-
-	const LOG_SEARCH_BATCH_SIZE = 100;
+require_once __DIR__ . '/Maintenance.php';
 
+/**
+ * Maintenance script that makes the required database updates for populating the
+ * log_search table retroactively
+ *
+ * @ingroup Maintenance
+ */
+class PopulateLogSearch extends LoggedUpdateMaintenance {
 	static $tableMap = array( 'rev' => 'revision', 'fa' => 'filearchive', 'oi' => 'oldimage', 'ar' => 'archive' );
 
 	public function __construct() {
 		parent::__construct();
 		$this->mDescription = "Migrate log params to new table and index for searching";
+		$this->setBatchSize( 100 );
 	}
 
-	public function execute() {
+	protected function getUpdateKey() {
+		return 'populate log_search';
+	}
+
+	protected function updateSkippedMessage() {
+		return 'log_search table already populated.';
+	}
+
+	protected function doDBUpdates() {
 		$db = $this->getDB( DB_MASTER );
 		if ( !$db->tableExists( 'log_search' ) ) {
-			$this->error( "log_search does not exist", true );
+			$this->error( "log_search does not exist" );
+			return false;
 		}
 		$start = $db->selectField( 'logging', 'MIN(log_id)', false, __FUNCTION__ );
 		if ( !$start ) {
@@ -47,9 +61,9 @@ class PopulateLogSearch extends Maintenance {
 		$end = $db->selectField( 'logging', 'MAX(log_id)', false, __FUNCTION__ );
 
 		# Do remaining chunk
-		$end += self::LOG_SEARCH_BATCH_SIZE - 1;
+		$end += $this->mBatchSize - 1;
 		$blockStart = $start;
-		$blockEnd = $start + self::LOG_SEARCH_BATCH_SIZE - 1;
+		$blockEnd = $start + $this->mBatchSize - 1;
 
 		$delTypes = array( 'delete', 'suppress' ); // revisiondelete types
 		while ( $blockEnd <= $end ) {
@@ -61,7 +75,9 @@ class PopulateLogSearch extends Maintenance {
 				if ( LogEventsList::typeAction( $row, $delTypes, 'revision' ) ) {
 					$params = LogPage::extractParams( $row->log_params );
 					// Param format: <urlparam> <item CSV> [<ofield> <nfield>]
-					if ( count( $params ) < 2 ) continue; // bad row?
+					if ( count( $params ) < 2 ) {
+						continue; // bad row?
+					}
 					$field = RevisionDeleter::getRelationType( $params[0] );
 					// B/C, the params may start with a title key (<title> <urlparam> <CSV>)
 					if ( $field == null ) {
@@ -83,8 +99,9 @@ class PopulateLogSearch extends Maintenance {
 					$log->addRelations( $field, $items, $row->log_id );
 					// Determine what table to query...
 					$prefix = substr( $field, 0, strpos( $field, '_' ) ); // db prefix
-					if ( !isset( self::$tableMap[$prefix] ) )
+					if ( !isset( self::$tableMap[$prefix] ) ) {
 						continue; // bad row?
+					}
 					$table = self::$tableMap[$prefix];
 					$userField = $prefix . '_user';
 					$userTextField = $prefix . '_user_text';
@@ -95,10 +112,11 @@ class PopulateLogSearch extends Maintenance {
 						array( $field => $items )
 					);
 					foreach ( $sres as $srow ) {
-						if ( $srow->$userField > 0 )
+						if ( $srow->$userField > 0 ) {
 							$userIds[] = intval( $srow->$userField );
-						elseif ( $srow->$userTextField != '' )
+						} elseif ( $srow->$userTextField != '' ) {
 							$userIPs[] = $srow->$userTextField;
+						}
 					}
 					// Add item author relations...
 					$log->addRelations( 'target_author_id', $userIds, $row->log_id );
@@ -107,7 +125,9 @@ class PopulateLogSearch extends Maintenance {
 				} elseif ( LogEventsList::typeAction( $row, $delTypes, 'event' ) ) {
 					$params = LogPage::extractParams( $row->log_params );
 					// Param format: <item CSV> [<ofield> <nfield>]
-					if ( count( $params ) < 1 ) continue; // bad row
+					if ( count( $params ) < 1 ) {
+						continue; // bad row
+					}
 					$items = explode( ',', $params[0] );
 					$log = new LogPage( $row->log_type );
 					// Add item relations...
@@ -119,34 +139,24 @@ class PopulateLogSearch extends Maintenance {
 						array( 'log_id' => $items )
 					);
 					foreach ( $sres as $srow ) {
-						if ( $srow->log_user > 0 )
+						if ( $srow->log_user > 0 ) {
 							$userIds[] = intval( $srow->log_user );
-						elseif ( IP::isIPAddress( $srow->log_user_text ) )
+						} elseif ( IP::isIPAddress( $srow->log_user_text ) ) {
 							$userIPs[] = $srow->log_user_text;
+						}
 					}
 					$log->addRelations( 'target_author_id', $userIds, $row->log_id );
 					$log->addRelations( 'target_author_ip', $userIPs, $row->log_id );
 				}
 			}
-			$blockStart += self::LOG_SEARCH_BATCH_SIZE;
-			$blockEnd += self::LOG_SEARCH_BATCH_SIZE;
+			$blockStart += $this->mBatchSize;
+			$blockEnd += $this->mBatchSize;
 			wfWaitForSlaves();
 		}
-		if ( $db->insert(
-				'updatelog',
-				array( 'ul_key' => 'populate log_search' ),
-				__FUNCTION__,
-				'IGNORE'
-			)
-		) {
-			$this->output( "log_search population complete.\n" );
-			return true;
-		} else {
-			$this->output( "Could not insert log_search population row.\n" );
-			return false;
-		}
+		$this->output( "Done populating log_search table.\n" );
+		return true;
 	}
 }
 
 $maintClass = "PopulateLogSearch";
-require_once( RUN_MAINTENANCE_IF_MAIN );
+require_once RUN_MAINTENANCE_IF_MAIN;
