@@ -23,7 +23,7 @@
  * @todo Document
  */
 
-require_once( __DIR__ . '/Maintenance.php' );
+require_once __DIR__ . '/Maintenance.php';
 
 /**
  * Maintenance script that rebuilds recent changes from scratch.
@@ -61,9 +61,9 @@ class RebuildRecentchanges extends Maintenance {
 		$this->output( '$wgRCMaxAge=' . $wgRCMaxAge );
 		$days = $wgRCMaxAge / 24 / 3600;
 		if ( intval( $days ) == $days ) {
-				$this->output( " (" . $days . " days)\n" );
+			$this->output( " (" . $days . " days)\n" );
 		} else {
-				$this->output( " (approx. " .  intval( $days ) . " days)\n" );
+			$this->output( " (approx. " . intval( $days ) . " days)\n" );
 		}
 
 		$cutoff = time() - $wgRCMaxAge;
@@ -99,13 +99,13 @@ class RebuildRecentchanges extends Maintenance {
 	 */
 	private function rebuildRecentChangesTablePass2() {
 		$dbw = wfGetDB( DB_MASTER );
-		list ( $recentchanges, $revision ) = $dbw->tableNamesN( 'recentchanges', 'revision' );
+		list( $recentchanges, $revision ) = $dbw->tableNamesN( 'recentchanges', 'revision' );
 
 		$this->output( "Updating links and size differences...\n" );
 
 		# Fill in the rc_last_oldid field, which points to the previous edit
 		$sql = "SELECT rc_cur_id,rc_this_oldid,rc_timestamp FROM $recentchanges " .
-		  "ORDER BY rc_cur_id,rc_timestamp";
+			"ORDER BY rc_cur_id,rc_timestamp";
 		$res = $dbw->query( $sql, DB_MASTER );
 
 		$lastCurId = 0;
@@ -142,12 +142,12 @@ class RebuildRecentchanges extends Maintenance {
 				$dbw->update( 'recentchanges',
 					array(
 						'rc_last_oldid' => $lastOldId,
-						'rc_new'        => $new,
-						'rc_type'       => $new,
-						'rc_old_len'    => $lastSize,
-						'rc_new_len'    => $size,
+						'rc_new' => $new,
+						'rc_type' => $new,
+						'rc_old_len' => $lastSize,
+						'rc_new_len' => $size,
 					), array(
-						'rc_cur_id'     => $lastCurId,
+						'rc_cur_id' => $lastCurId,
 						'rc_this_oldid' => $obj->rc_this_oldid,
 					),
 					__METHOD__
@@ -292,4 +292,4 @@ class RebuildRecentchanges extends Maintenance {
 }
 
 $maintClass = "RebuildRecentchanges";
-require_once( RUN_MAINTENANCE_IF_MAIN );
+require_once RUN_MAINTENANCE_IF_MAIN;
