@@ -25,7 +25,7 @@
  * @author Antoine Musso
  */
 
-require_once( __DIR__ . '/Maintenance.php' );
+require_once __DIR__ . '/Maintenance.php';
 
 /**
  * Maintenance script that reports the number of jobs currently waiting
@@ -38,17 +38,33 @@ class ShowJobs extends Maintenance {
 		parent::__construct();
 		$this->mDescription = "Show number of jobs waiting in master database";
 		$this->addOption( 'group', 'Show number of jobs per job type' );
+		$this->addOption( 'list', 'Show a complete list of all jobs in a machine-readable format, instead of statistics' );
 	}
 
 	public function execute() {
 		$group = JobQueueGroup::singleton();
-		if ( $this->hasOption( 'group' ) ) {
+		if ( $this->hasOption( 'list' ) ) {
 			foreach ( $group->getQueueTypes() as $type ) {
-				$queue   = $group->get( $type );
+				$queue = $group->get( $type );
+				foreach ( $queue->getAllQueuedJobs() as $job ) {
+					$this->output( $job->toString() . " status=unclaimed\n" );
+				}
+				foreach ( $queue->getAllDelayedJobs() as $job ) {
+					$this->output( $job->toString() . " status=delayed\n" );
+				}
+			}
+		} elseif ( $this->hasOption( 'group' ) ) {
+			foreach ( $group->getQueueTypes() as $type ) {
+				$queue = $group->get( $type );
 				$pending = $queue->getSize();
 				$claimed = $queue->getAcquiredCount();
+				$abandoned = $queue->getAbandonedCount();
+				$active = max( 0, $claimed - $abandoned );
 				if ( ( $pending + $claimed ) > 0 ) {
-					$this->output( "{$type}: $pending queued; $claimed acquired\n" );
+					$this->output(
+						"{$type}: $pending queued; " .
+						"$claimed claimed ($active active, $abandoned abandoned)\n"
+					);
 				}
 			}
 		} else {
@@ -62,4 +78,4 @@ class ShowJobs extends Maintenance {
 }
 
 $maintClass = "ShowJobs";
-require_once( RUN_MAINTENANCE_IF_MAIN );
+require_once RUN_MAINTENANCE_IF_MAIN;
