@@ -20,7 +20,7 @@
  * @file
  */
 
-if( !defined( 'MEDIAWIKI' ) ) {
+if ( !defined( 'MEDIAWIKI' ) ) {
 	die( 'Not an entry point.' );
 }
 
@@ -60,14 +60,11 @@ return array(
 	 *
 	 * See Vector for an example.
 	 */
-
-	'skins.chick' => array(
-		'styles' => array( 'chick/main.css' => array( 'media' => 'screen, handheld' ) ),
-		'remoteBasePath' => $GLOBALS['wgStylePath'],
-		'localBasePath' => $GLOBALS['wgStyleDirectory'],
-	),
 	'skins.cologneblue' => array(
-		'styles' => array( 'cologneblue/screen.css' => array( 'media' => 'screen' ) ),
+		'styles' => array(
+			'cologneblue/screen.css' => array( 'media' => 'screen' ),
+			'cologneblue/print.css' => array( 'media' => 'print' ),
+		),
 		'remoteBasePath' => $GLOBALS['wgStylePath'],
 		'localBasePath' => $GLOBALS['wgStyleDirectory'],
 	),
@@ -89,38 +86,54 @@ return array(
 		'remoteBasePath' => $GLOBALS['wgStylePath'],
 		'localBasePath' => $GLOBALS['wgStyleDirectory'],
 	),
-	'skins.nostalgia' => array(
-		'styles' => array( 'nostalgia/screen.css' => array( 'media' => 'screen' ) ),
-		'remoteBasePath' => $GLOBALS['wgStylePath'],
-		'localBasePath' => $GLOBALS['wgStyleDirectory'],
-	),
-	'skins.simple' => array(
-		'styles' => array( 'simple/main.css' => array( 'media' => 'screen' ) ),
-		'remoteBasePath' => $GLOBALS['wgStylePath'],
-		'localBasePath' => $GLOBALS['wgStyleDirectory'],
-	),
-	'skins.standard' => array(
-		'styles' => array( 'standard/main.css' => array( 'media' => 'screen' ) ),
-		'remoteBasePath' => $GLOBALS['wgStylePath'],
-		'localBasePath' => $GLOBALS['wgStyleDirectory'],
-	),
 	'skins.vector' => array(
-		// Keep in sync with WebInstallerOutput::getCSS()
+		// Used in the web installer. Test it after modifying this definition!
 		'styles' => array(
 			'common/commonElements.css' => array( 'media' => 'screen' ),
 			'common/commonContent.css' => array( 'media' => 'screen' ),
 			'common/commonInterface.css' => array( 'media' => 'screen' ),
-			'vector/screen.css' => array( 'media' => 'screen' ),
-			'vector/screen-hd.css' => array( 'media' => 'screen and (min-width: 982px)' ),
+			'vector/styles.less',
+		),
+		'remoteBasePath' => $GLOBALS['wgStylePath'],
+		'localBasePath' => $GLOBALS['wgStyleDirectory'],
+	),
+	'skins.vector.beta' => array(
+		// Keep in sync with skins.vector
+		'styles' => array(
+			'common/commonElements.css' => array( 'media' => 'screen' ),
+			'common/commonContent.css' => array( 'media' => 'screen' ),
+			'common/commonInterface.css' => array( 'media' => 'screen' ),
+			'vector/styles-beta.less',
 		),
 		'remoteBasePath' => $GLOBALS['wgStylePath'],
 		'localBasePath' => $GLOBALS['wgStyleDirectory'],
 	),
 	'skins.vector.js' => array(
-		'scripts' => 'vector/vector.js',
+		'scripts' => array(
+			'vector/collapsibleTabs.js',
+			'vector/vector.js',
+		),
+		'position' => 'top',
+		'dependencies' => 'jquery.delayedBind',
 		'remoteBasePath' => $GLOBALS['wgStylePath'],
 		'localBasePath' => $GLOBALS['wgStyleDirectory'],
 	),
+	'skins.vector.collapsibleNav' => array(
+		'scripts' => array(
+			'vector/collapsibleNav.js',
+		),
+		'messages' => array(
+			'vector-collapsiblenav-more',
+		),
+		'dependencies' => array(
+			'jquery.client',
+			'jquery.cookie',
+			'jquery.tabIndex',
+		),
+		'remoteBasePath' => $GLOBALS['wgStylePath'],
+		'localBasePath' => $GLOBALS['wgStyleDirectory'],
+		'position' => 'bottom',
+	),
 
 	/* jQuery */
 
@@ -153,6 +166,7 @@ return array(
 	),
 	'jquery.byteLength' => array(
 		'scripts' => 'resources/jquery/jquery.byteLength.js',
+		'targets' => array( 'desktop', 'mobile' ),
 	),
 	'jquery.byteLimit' => array(
 		'scripts' => 'resources/jquery/jquery.byteLimit.js',
@@ -160,6 +174,11 @@ return array(
 	),
 	'jquery.checkboxShiftClick' => array(
 		'scripts' => 'resources/jquery/jquery.checkboxShiftClick.js',
+		'targets' => array( 'desktop', 'mobile' ),
+	),
+	'jquery.chosen' => array(
+		'scripts' => 'resources/jquery.chosen/chosen.jquery.js',
+		'styles' => 'resources/jquery.chosen/chosen.css',
 	),
 	'jquery.client' => array(
 		'scripts' => 'resources/jquery/jquery.client.js',
@@ -197,6 +216,7 @@ return array(
 	),
 	'jquery.getAttrs' => array(
 		'scripts' => 'resources/jquery/jquery.getAttrs.js',
+		'targets' => array( 'desktop', 'mobile' ),
 	),
 	'jquery.hidpi' => array(
 		'scripts' => 'resources/jquery/jquery.hidpi.js',
@@ -220,12 +240,14 @@ return array(
 		'scripts' => 'resources/jquery/jquery.makeCollapsible.js',
 		'styles' => 'resources/jquery/jquery.makeCollapsible.css',
 		'messages' => array( 'collapsible-expand', 'collapsible-collapse' ),
+		'targets' => array( 'desktop', 'mobile' ),
 	),
 	'jquery.mockjax' => array(
 		'scripts' => 'resources/jquery/jquery.mockjax.js',
 	),
 	'jquery.mw-jump' => array(
 		'scripts' => 'resources/jquery/jquery.mw-jump.js',
+		'targets' => array( 'desktop', 'mobile' ),
 	),
 	'jquery.mwExtension' => array(
 		'scripts' => 'resources/jquery/jquery.mwExtension.js',
@@ -233,15 +255,18 @@ return array(
 	),
 	'jquery.placeholder' => array(
 		'scripts' => 'resources/jquery/jquery.placeholder.js',
+		'targets' => array( 'desktop', 'mobile' ),
 	),
 	'jquery.qunit' => array(
 		'scripts' => 'resources/jquery/jquery.qunit.js',
 		'styles' => 'resources/jquery/jquery.qunit.css',
 		'position' => 'top',
+		'targets' => array( 'desktop', 'mobile' ),
 	),
 	'jquery.qunit.completenessTest' => array(
 		'scripts' => 'resources/jquery/jquery.qunit.completenessTest.js',
 		'dependencies' => 'jquery.qunit',
+		'targets' => array( 'desktop', 'mobile' ),
 	),
 	'jquery.spinner' => array(
 		'scripts' => 'resources/jquery/jquery.spinner.js',
@@ -263,7 +288,10 @@ return array(
 		'scripts' => 'resources/jquery/jquery.tablesorter.js',
 		'styles' => 'resources/jquery/jquery.tablesorter.css',
 		'messages' => array( 'sort-descending', 'sort-ascending' ),
-		'dependencies' => 'jquery.mwExtension',
+		'dependencies' => array(
+			'jquery.mwExtension',
+			'mediawiki.language.months',
+		),
 	),
 	'jquery.textSelection' => array(
 		'scripts' => 'resources/jquery/jquery.textSelection.js',
@@ -592,6 +620,12 @@ return array(
 			'mediawiki.Title',
 		),
 	),
+	'mediawiki.api.login' => array(
+		'scripts' => 'resources/mediawiki.api/mediawiki.api.login.js',
+		'dependencies' => array(
+			'mediawiki.api',
+		),
+	),
 	'mediawiki.api.parse' => array(
 		'scripts' => 'resources/mediawiki.api/mediawiki.api.parse.js',
 		'dependencies' => 'mediawiki.api',
@@ -603,6 +637,9 @@ return array(
 			'user.tokens',
 		),
 	),
+	'mediawiki.icon' => array(
+		'styles' => 'resources/mediawiki/mediawiki.icon.css',
+	),
 	'mediawiki.debug' => array(
 		'scripts' => 'resources/mediawiki/mediawiki.debug.js',
 		'styles' => 'resources/mediawiki/mediawiki.debug.css',
@@ -616,6 +653,14 @@ return array(
 		// must be loaded on the bottom
 		'position' => 'bottom',
 	),
+	'mediawiki.inspect' => array(
+		'scripts' => 'resources/mediawiki/mediawiki.inspect.js',
+		'dependencies' => array(
+			'jquery.byteLength',
+			'jquery.json',
+		),
+		'targets' => array( 'desktop', 'mobile' ),
+	),
 	'mediawiki.feedback' => array(
 		'scripts' => 'resources/mediawiki/mediawiki.feedback.js',
 		'styles' => 'resources/mediawiki/mediawiki.feedback.css',
@@ -650,6 +695,7 @@ return array(
 	),
 	'mediawiki.htmlform' => array(
 		'scripts' => 'resources/mediawiki/mediawiki.htmlform.js',
+		'messages' => array( 'htmlform-chosen-placeholder' ),
 	),
 	'mediawiki.notification' => array(
 		'styles' => 'resources/mediawiki/mediawiki.notification.css',
@@ -674,11 +720,15 @@ return array(
 			'jquery.client',
 			'jquery.placeholder',
 			'jquery.suggestions',
+			'mediawiki.api',
 		),
 	),
 	'mediawiki.Title' => array(
 		'scripts' => 'resources/mediawiki/mediawiki.Title.js',
-		'dependencies' => 'mediawiki.util',
+		'dependencies' => array(
+			'jquery.byteLength',
+			'mediawiki.util',
+		),
 	),
 	'mediawiki.Uri' => array(
 		'scripts' => 'resources/mediawiki/mediawiki.Uri.js',
@@ -710,16 +760,30 @@ return array(
 	'mediawiki.action.edit' => array(
 		'scripts' => 'resources/mediawiki.action/mediawiki.action.edit.js',
 		'dependencies' => array(
+			'mediawiki.action.edit.styles',
 			'jquery.textSelection',
 			'jquery.byteLimit',
 		),
 		'position' => 'top',
 	),
+	'mediawiki.action.edit.styles' => array(
+		'styles' => 'resources/mediawiki.action/mediawiki.action.edit.styles.css',
+		'position' => 'top',
+	),
+	'mediawiki.action.edit.collapsibleFooter' => array(
+		'scripts' => 'resources/mediawiki.action/mediawiki.action.edit.collapsibleFooter.js',
+		'styles' => 'resources/mediawiki.action/mediawiki.action.edit.collapsibleFooter.css',
+		'dependencies' => array(
+			'jquery.makeCollapsible',
+			'mediawiki.icon',
+		),
+	),
 	'mediawiki.action.edit.preview' => array(
 		'scripts' => 'resources/mediawiki.action/mediawiki.action.edit.preview.js',
 		'dependencies' => array(
 			'jquery.form',
 			'jquery.spinner',
+			'mediawiki.action.history.diff',
 		),
 	),
 	'mediawiki.action.history' => array(
@@ -746,11 +810,24 @@ return array(
 	),
 	'mediawiki.action.view.postEdit' => array(
 		'scripts' => 'resources/mediawiki.action/mediawiki.action.view.postEdit.js',
-		'dependencies' => 'jquery.cookie'
+		'styles' => 'resources/mediawiki.action/mediawiki.action.view.postEdit.css',
+		'dependencies' => array(
+			'jquery.cookie',
+			'mediawiki.jqueryMsg'
+		),
+		'messages' => array(
+			'postedit-confirmation',
+		),
 	),
 	'mediawiki.action.view.rightClickEdit' => array(
 		'scripts' => 'resources/mediawiki.action/mediawiki.action.view.rightClickEdit.js',
 	),
+	'mediawiki.action.edit.editWarning' => array(
+		'scripts' => 'resources/mediawiki.action/mediawiki.action.edit.editWarning.js',
+		'messages' => array(
+			'editwarning-warning',
+		),
+	),
 	// Alias for backwards compatibility
 	'mediawiki.action.watch.ajax' => array(
 		'dependencies' => 'mediawiki.page.watch.ajax'
@@ -812,6 +889,16 @@ return array(
 		'targets' => array( 'desktop', 'mobile' ),
 	),
 
+	'mediawiki.language.months' => array(
+		'scripts' => 'resources/mediawiki.language/mediawiki.language.months.js',
+		'dependencies' => 'mediawiki.language',
+		'messages' => array_merge(
+			Language::$mMonthMsgs,
+			Language::$mMonthGenMsgs,
+			Language::$mMonthAbbrevMsgs
+		)
+	),
+
 	/* MediaWiki Libs */
 
 	'mediawiki.libs.jpegmeta' => array(
@@ -820,6 +907,9 @@ return array(
 
 	/* MediaWiki Page */
 
+	'mediawiki.page.gallery' => array(
+		'scripts' => 'resources/mediawiki.page/mediawiki.page.gallery.js',
+	),
 	'mediawiki.page.ready' => array(
 		'scripts' => 'resources/mediawiki.page/mediawiki.page.ready.js',
 		'dependencies' => array(
@@ -829,6 +919,7 @@ return array(
 			'jquery.mw-jump',
 			'mediawiki.util',
 		),
+		'targets' => array( 'desktop', 'mobile' ),
 	),
 	'mediawiki.page.startup' => array(
 		'scripts' => 'resources/mediawiki.page/mediawiki.page.startup.js',
@@ -837,6 +928,7 @@ return array(
 			'mediawiki.util',
 		),
 		'position' => 'top',
+		'targets' => array( 'desktop', 'mobile' ),
 	),
 	'mediawiki.page.patrol.ajax' => array(
 		'scripts' => 'resources/mediawiki.page/mediawiki.page.patrol.ajax.js',
@@ -874,6 +966,10 @@ return array(
 			'watcherrortext',
 		),
 	),
+	'mediawiki.page.image.pagination' => array(
+		'scripts' => 'resources/mediawiki.page/mediawiki.page.image.pagination.js',
+		'dependencies' => array( 'jquery.spinner' )
+	),
 
 	/* MediaWiki Special pages */
 
@@ -900,15 +996,21 @@ return array(
 	),
 	'mediawiki.special.changeslist' => array(
 		'styles' => 'resources/mediawiki.special/mediawiki.special.changeslist.css',
-		'dependencies' => array( 'jquery.makeCollapsible' ),
+	),
+	'mediawiki.special.changeslist.enhanced' => array(
+		'styles' => 'resources/mediawiki.special/mediawiki.special.changeslist.enhanced.css',
 	),
 	'mediawiki.special.movePage' => array(
 		'scripts' => 'resources/mediawiki.special/mediawiki.special.movePage.js',
 		'dependencies' => 'jquery.byteLimit',
 	),
+	'mediawiki.special.pagesWithProp' => array(
+		'styles' => 'resources/mediawiki.special/mediawiki.special.pagesWithProp.css',
+	),
 	'mediawiki.special.preferences' => array(
 		'scripts' => 'resources/mediawiki.special/mediawiki.special.preferences.js',
-		'styles'  => 'resources/mediawiki.special/mediawiki.special.preferences.css',
+		'styles' => 'resources/mediawiki.special/mediawiki.special.preferences.css',
+		'position' => 'top',
 	),
 	'mediawiki.special.recentchanges' => array(
 		'scripts' => 'resources/mediawiki.special/mediawiki.special.recentchanges.js',
@@ -928,7 +1030,7 @@ return array(
 		'scripts' => 'resources/mediawiki.special/mediawiki.special.undelete.js',
 	),
 	'mediawiki.special.upload' => array(
-		// @TODO: merge in remainder of mediawiki.legacy.upload
+		// @todo merge in remainder of mediawiki.legacy.upload
 		'scripts' => 'resources/mediawiki.special/mediawiki.special.upload.js',
 		'messages' => array(
 			'widthheight',
@@ -938,10 +1040,33 @@ return array(
 			'size-gigabytes',
 			'largefileserver',
 		),
-		'dependencies' => array( 'mediawiki.libs.jpegmeta', 'mediawiki.util' ),
+		'dependencies' => array(
+			'mediawiki.libs.jpegmeta',
+			'mediawiki.util',
+		),
 	),
-	'mediawiki.special.userlogin.signup' => array(
-		'scripts' => 'resources/mediawiki.special/mediawiki.special.userLogin.signup.js',
+	'mediawiki.special.userlogin' => array(
+		'styles' => array(
+			'resources/mediawiki.special/mediawiki.special.vforms.css',
+			'resources/mediawiki.special/mediawiki.special.userLogin.css',
+		),
+		'position' => 'top',
+	),
+	'mediawiki.special.createaccount' => array(
+		'styles' => array(
+			'resources/mediawiki.special/mediawiki.special.vforms.css',
+			'resources/mediawiki.special/mediawiki.special.createAccount.css',
+		),
+	),
+	'mediawiki.special.createaccount.js' => array(
+		'scripts' => 'resources/mediawiki.special/mediawiki.special.createAccount.js',
+		'messages' => array(
+			'createacct-captcha',
+			'createacct-emailrequired',
+			'createacct-imgcaptcha-ph'
+		),
+		'dependencies' => 'mediawiki.jqueryMsg',
+		'position' => 'top',
 	),
 	'mediawiki.special.javaScriptTest' => array(
 		'scripts' => 'resources/mediawiki.special/mediawiki.special.javaScriptTest.js',
@@ -951,6 +1076,7 @@ return array(
 		) ),
 		'dependencies' => array( 'jquery.qunit' ),
 		'position' => 'top',
+		'targets' => array( 'desktop', 'mobile' ),
 	),
 
 	/* MediaWiki Tests */
@@ -965,6 +1091,7 @@ return array(
 			'mediawiki.page.ready',
 		),
 		'position' => 'top',
+		'targets' => array( 'desktop', 'mobile' ),
 	),
 
 	/* MediaWiki Legacy */
@@ -985,14 +1112,9 @@ return array(
 		'localBasePath' => $GLOBALS['wgStyleDirectory'],
 	),
 	'mediawiki.legacy.config' => array(
+		// Used in the web installer. Test it after modifying this definition!
 		'scripts' => 'common/config.js',
-		'styles' => array( 'common/config.css', 'common/config-cc.css' ),
-		'remoteBasePath' => $GLOBALS['wgStylePath'],
-		'localBasePath' => $GLOBALS['wgStyleDirectory'],
-		'dependencies' => 'mediawiki.legacy.wikibits',
-	),
-	'mediawiki.legacy.IEFixes' => array(
-		'scripts' => 'common/IEFixes.js',
+		'styles' => array( 'common/config.css' ),
 		'remoteBasePath' => $GLOBALS['wgStylePath'],
 		'localBasePath' => $GLOBALS['wgStyleDirectory'],
 		'dependencies' => 'mediawiki.legacy.wikibits',
@@ -1002,12 +1124,12 @@ return array(
 		'remoteBasePath' => $GLOBALS['wgStylePath'],
 		'localBasePath' => $GLOBALS['wgStyleDirectory'],
 		'dependencies' => array(
-			'mediawiki.legacy.wikibits',
 			'jquery.byteLimit',
 		),
 		'position' => 'top',
 	),
 	'mediawiki.legacy.shared' => array(
+		// Used in the web installer. Test it after modifying this definition!
 		'styles' => array( 'common/shared.css' => array( 'media' => 'screen' ) ),
 		'remoteBasePath' => $GLOBALS['wgStylePath'],
 		'localBasePath' => $GLOBALS['wgStyleDirectory'],
@@ -1022,7 +1144,9 @@ return array(
 		'remoteBasePath' => $GLOBALS['wgStylePath'],
 		'localBasePath' => $GLOBALS['wgStyleDirectory'],
 		'dependencies' => array(
-			'mediawiki.legacy.wikibits',
+			'jquery.spinner',
+			'mediawiki.api',
+			'mediawiki.Title',
 			'mediawiki.util',
 		),
 	),
@@ -1035,9 +1159,11 @@ return array(
 		),
 		'position' => 'top',
 	),
-	'mediawiki.legacy.wikiprintable' => array(
-		'styles' => array( 'common/wikiprintable.css' => array( 'media' => 'print' ) ),
-		'remoteBasePath' => $GLOBALS['wgStylePath'],
-		'localBasePath' => $GLOBALS['wgStyleDirectory'],
+	'mediawiki.ui' => array(
+		'skinStyles' => array(
+			'default' => 'resources/mediawiki.ui/mediawiki.ui.default.css',
+			'vector' => 'resources/mediawiki.ui/mediawiki.ui.vector.css',
+		),
+		'position' => 'top',
 	),
 );
