@@ -15,11 +15,17 @@
 		$box.click( function ( e ) {
 			// And one has been clicked before...
 			if ( prevCheckbox !== null && e.shiftKey ) {
-				// Check or uncheck this one and all in-between checkboxes
-				$box.slice(
-					Math.min( $box.index( prevCheckbox ), $box.index( e.target ) ),
-					Math.max( $box.index( prevCheckbox ), $box.index( e.target ) ) + 1
-				).prop( 'checked', !!e.target.checked );
+				// Check or uncheck this one and all in-between checkboxes,
+				// except for disabled ones
+				$box
+					.slice(
+						Math.min( $box.index( prevCheckbox ), $box.index( e.target ) ),
+						Math.max( $box.index( prevCheckbox ), $box.index( e.target ) ) + 1
+					)
+					.filter( function () {
+						return !this.disabled;
+					} )
+					.prop( 'checked', !!e.target.checked );
 			}
 			// Either way, update the prevCheckbox variable to the one clicked now
 			prevCheckbox = e.target;
