@@ -89,7 +89,7 @@
 			 * Ported from skins/common/edit.js by Trevor Parscal
 			 * (c) 2009 Wikimedia Foundation (GPLv2) - http://www.wikimedia.org
 			 *
-			 * Inserts text at the begining and end of a text selection, optionally
+			 * Inserts text at the beginning and end of a text selection, optionally
 			 * inserting text at the caret when selection is empty.
 			 *
 			 * @fixme document the options parameters
@@ -257,7 +257,7 @@
 			 * Some code copied from
 			 * http://www.dedestruct.com/2008/03/22/howto-cross-browser-cursor-position-in-textareas/
 			 *
-			 * Get the position (in resolution of bytes not nessecarily characters)
+			 * Get the position (in resolution of bytes not necessarily characters)
 			 * in a textarea
 			 *
 			 * Will focus the textarea in some browsers (IE/Opera)
@@ -293,7 +293,7 @@
 						postFinished = false;
 						periRange = document.selection.createRange().duplicate();
 
-						preRange = rangeForElementIE( e ),
+						preRange = rangeForElementIE( e );
 						// Move the end where we need it
 						preRange.setEndPoint( 'EndToStart', periRange );
 
